Coverage for /root/GitHubProjects/impacket/impacket/mapi_constants.py: 100%

# Coverage for /root/GitHubProjects/impacket/impacket/mapi_constants.py : 100%

## 127 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1# SECUREAUTH LABS. Copyright 2020 SecureAuth Corporation. All rights reserved.

2# This software is provided under a slightly modified version

3# of the Apache Software License. See the accompanying LICENSE file

4# for more information.

5#

6# Authors:

7# Arseniy Sharoglazov <mohemiv@gmail.com> / Positive Technologies (https://www.ptsecurity.com/)

8#

9# Error codes taken from:

10# [MS-OXCDATA]

11# http://www.eventid.net/display-eventid-2115-source-MSExchangeDSAccess-eventno-4469-phase-1.htm

12#

13# MAPI properties taken from:

14# https://gist.github.com/mohemiv/76c265ac92ca026a10b7756899b5f8d5 (MIT)

15#

16

17 ERROR_MESSAGES = {

18 0x80004002: ("MAPI_E_INTERFACE_NO_SUPPORT"),

19 0x80004005: ("MAPI_E_CALL_FAILED"),

20 0x80040102: ("MAPI_E_NO_SUPPORT"),

21 0x80040103: ("MAPI_E_BAD_CHARWIDTH"),

22 0x80040105: ("MAPI_E_STRING_TOO_LONG"),

23 0x80040106: ("MAPI_E_UNKNOWN_FLAGS"),

24 0x80040107: ("MAPI_E_INVALID_ENTRYID"),

25 0x80040108: ("MAPI_E_INVALID_OBJECT"),

26 0x80040109: ("MAPI_E_OBJECT_CHANGED"),

27 0x8004010A: ("MAPI_E_OBJECT_DELETED"),

28 0x8004010B: ("MAPI_E_BUSY"),

29 0x8004010D: ("MAPI_E_NOT_ENOUGH_DISK"),

30 0x8004010E: ("MAPI_E_NOT_ENOUGH_RESOURCES"),

31 0x8004010F: ("MAPI_E_NOT_FOUND"),

32 0x80040110: ("MAPI_E_VERSION"),

33 0x80040111: ("MAPI_E_LOGON_FAILED"),

34 0x80040112: ("MAPI_E_SESSION_LIMIT"),

35 0x80040113: ("MAPI_E_USER_CANCEL"),

36 0x80040114: ("MAPI_E_UNABLE_TO_ABORT"),

37 0x80040115: ("MAPI_E_NETWORK_ERROR"),

38 0x80040116: ("MAPI_E_DISK_ERROR"),

39 0x80040117: ("MAPI_E_TOO_COMPLEX"),

40 0x80040118: ("MAPI_E_BAD_COLUMN"),

41 0x80040119: ("MAPI_E_EXTENDED_ERROR"),

42 0x8004011A: ("MAPI_E_COMPUTED"),

43 0x8004011B: ("MAPI_E_CORRUPT_DATA"),

44 0x8004011C: ("MAPI_E_UNCONFIGURED"),

45 0x8004011D: ("MAPI_E_FAILONEPROVIDER"),

46 0x8004011E: ("MAPI_E_UNKNOWN_CPID"),

47 0x8004011F: ("MAPI_E_UNKNOWN_LCID"),

48 0x80040120: ("MAPI_E_PASSWORD_CHANGE_REQUIRED"),

49 0x80040121: ("MAPI_E_PASSWORD_EXPIRED"),

50 0x80040122: ("MAPI_E_INVALID_WORKSTATION_ACCOUNT"),

51 0x80040123: ("MAPI_E_INVALID_ACCESS_TIME"),

52 0x80040124: ("MAPI_E_ACCOUNT_DISABLED"),

53 0x80040200: ("MAPI_E_END_OF_SESSION"),

54 0x80040201: ("MAPI_E_UNKNOWN_ENTRYID"),

55 0x80040202: ("MAPI_E_MISSING_REQUIRED_COLUMN"),

56 0x00040203: ("MAPI_W_NO_SERVICE"),

57 0x80040301: ("MAPI_E_BAD_VALUE"),

58 0x80040302: ("MAPI_E_INVALID_TYPE"),

59 0x80040303: ("MAPI_E_TYPE_NO_SUPPORT"),

60 0x80040304: ("MAPI_E_UNEXPECTED_TYPE"),

61 0x80040305: ("MAPI_E_TOO_BIG"),

62 0x80040306: ("MAPI_E_DECLINE_COPY"),

63 0x80040307: ("MAPI_E_UNEXPECTED_ID"),

64 0x00040380: ("MAPI_W_ERRORS_RETURNED"),

65 0x80040400: ("MAPI_E_UNABLE_TO_COMPLETE"),

66 0x80040401: ("MAPI_E_TIMEOUT"),

67 0x80040402: ("MAPI_E_TABLE_EMPTY"),

68 0x80040403: ("MAPI_E_TABLE_TOO_BIG"),

69 0x80040405: ("MAPI_E_INVALID_BOOKMARK"),

70 0x00040481: ("MAPI_W_POSITION_CHANGED"),

71 0x00040482: ("MAPI_W_APPROX_COUNT"),

72 0x80040500: ("MAPI_E_WAIT"),

73 0x80040501: ("MAPI_E_CANCEL"),

74 0x80040502: ("MAPI_E_NOT_ME"),

75 0x00040580: ("MAPI_W_CANCEL_MESSAGE"),

76 0x80040600: ("MAPI_E_CORRUPT_STORE"),

77 0x80040601: ("MAPI_E_NOT_IN_QUEUE"),

78 0x80040602: ("MAPI_E_NO_SUPPRESS"),

79 0x80040604: ("MAPI_E_COLLISION"),

80 0x80040605: ("MAPI_E_NOT_INITIALIZED"),

81 0x80040606: ("MAPI_E_NON_STANDARD"),

82 0x80040607: ("MAPI_E_NO_RECIPIENTS"),

83 0x80040608: ("MAPI_E_SUBMITTED"),

84 0x80040609: ("MAPI_E_HAS_FOLDERS"),

85 0x8004060A: ("MAPI_E_HAS_MESAGES"),

86 0x8004060B: ("MAPI_E_FOLDER_CYCLE"),

87 0x8004060D: ("MAPI_E_LOCKID_LIMIT"),

88 0x00040680: ("MAPI_W_PARTIAL_COMPLETION"),

89 0x80040700: ("MAPI_E_AMBIGUOUS_RECIP"),

90 0x80040800: ("SYNC_E_OBJECT_DELETED"),

91 0x80040801: ("SYNC_E_IGNORE"),

92 0x80040802: ("SYNC_E_CONFLICT"),

93 0x80040803: ("SYNC_E_NO_PARENT"),

94 0x80040804: ("SYNC_E_CYCLE_DETECTED"),

95 0x80040805: ("SYNC_E_UNSYNCHRONIZED"),

96 0x00040820: ("SYNC_W_PROGRESS"),

97 0x00040821: ("SYNC_W_CLIENT_CHANGE_NEWER"),

98 0x80040900: ("MAPI_E_NAMED_PROP_QUOTA_EXCEEDED"),

99 0x80040FFF: ("MAPI_E_NOT_IMPLEMENTED"),

100 0x80070005: ("MAPI_E_NO_ACCESS"),

101 0x8007000E: ("MAPI_E_NOT_ENOUGH_MEMORY"),

102 0x80070057: ("MAPI_E_INVALID_PARAMETER"),

103

104 0x80040920: ("LDAP_NO_SUCH_OBJECT"),

105 0x80040951: ("LDAP_SERVER_DOWN"),

106 0x80040952: ("LDAP_LOCAL_ERROR"),

107}

108

109 MAPI_E_INTERFACE_NO_SUPPORT = 0x80004002

110 MAPI_E_CALL_FAILED = 0x80004005

111 MAPI_E_NO_SUPPORT = 0x80040102

112 MAPI_E_BAD_CHARWIDTH = 0x80040103

113 MAPI_E_STRING_TOO_LONG = 0x80040105

114 MAPI_E_UNKNOWN_FLAGS = 0x80040106

115 MAPI_E_INVALID_ENTRYID = 0x80040107

116 MAPI_E_INVALID_OBJECT = 0x80040108

117 MAPI_E_OBJECT_CHANGED = 0x80040109

118 MAPI_E_OBJECT_DELETED = 0x8004010A

119 MAPI_E_BUSY = 0x8004010B

120 MAPI_E_NOT_ENOUGH_DISK = 0x8004010D

121 MAPI_E_NOT_ENOUGH_RESOURCES = 0x8004010E

122 MAPI_E_NOT_FOUND = 0x8004010F

123 MAPI_E_VERSION = 0x80040110

124 MAPI_E_LOGON_FAILED = 0x80040111

125 MAPI_E_SESSION_LIMIT = 0x80040112

126 MAPI_E_USER_CANCEL = 0x80040113

127 MAPI_E_UNABLE_TO_ABORT = 0x80040114

128 MAPI_E_NETWORK_ERROR = 0x80040115

129 MAPI_E_DISK_ERROR = 0x80040116

130 MAPI_E_TOO_COMPLEX = 0x80040117

131 MAPI_E_BAD_COLUMN = 0x80040118

132 MAPI_E_EXTENDED_ERROR = 0x80040119

133 MAPI_E_COMPUTED = 0x8004011A

134 MAPI_E_CORRUPT_DATA = 0x8004011B

135 MAPI_E_UNCONFIGURED = 0x8004011C

136 MAPI_E_FAILONEPROVIDER = 0x8004011D

137 MAPI_E_UNKNOWN_CPID = 0x8004011E

138 MAPI_E_UNKNOWN_LCID = 0x8004011F

139 MAPI_E_PASSWORD_CHANGE_REQUIRED = 0x80040120

140 MAPI_E_PASSWORD_EXPIRED = 0x80040121

141 MAPI_E_INVALID_WORKSTATION_ACCOUNT = 0x80040122

142 MAPI_E_INVALID_ACCESS_TIME = 0x80040123

143 MAPI_E_ACCOUNT_DISABLED = 0x80040124

144 MAPI_E_END_OF_SESSION = 0x80040200

145 MAPI_E_UNKNOWN_ENTRYID = 0x80040201

146 MAPI_E_MISSING_REQUIRED_COLUMN = 0x80040202

147 MAPI_W_NO_SERVICE = 0x00040203

148 MAPI_E_BAD_VALUE = 0x80040301

149 MAPI_E_INVALID_TYPE = 0x80040302

150 MAPI_E_TYPE_NO_SUPPORT = 0x80040303

151 MAPI_E_UNEXPECTED_TYPE = 0x80040304

152 MAPI_E_TOO_BIG = 0x80040305

153 MAPI_E_DECLINE_COPY = 0x80040306

154 MAPI_E_UNEXPECTED_ID = 0x80040307

155 MAPI_W_ERRORS_RETURNED = 0x00040380

156 MAPI_E_UNABLE_TO_COMPLETE = 0x80040400

157 MAPI_E_TIMEOUT = 0x80040401

158 MAPI_E_TABLE_EMPTY = 0x80040402

159 MAPI_E_TABLE_TOO_BIG = 0x80040403

160 MAPI_E_INVALID_BOOKMARK = 0x80040405

161 MAPI_W_POSITION_CHANGED = 0x00040481

162 MAPI_W_APPROX_COUNT = 0x00040482

163 MAPI_E_WAIT = 0x80040500

164 MAPI_E_CANCEL = 0x80040501

165 MAPI_E_NOT_ME = 0x80040502

166 MAPI_W_CANCEL_MESSAGE = 0x00040580

167 MAPI_E_CORRUPT_STORE = 0x80040600

168 MAPI_E_NOT_IN_QUEUE = 0x80040601

169 MAPI_E_NO_SUPPRESS = 0x80040602

170 MAPI_E_COLLISION = 0x80040604

171 MAPI_E_NOT_INITIALIZED = 0x80040605

172 MAPI_E_NON_STANDARD = 0x80040606

173 MAPI_E_NO_RECIPIENTS = 0x80040607

174 MAPI_E_SUBMITTED = 0x80040608

175 MAPI_E_HAS_FOLDERS = 0x80040609

176 MAPI_E_HAS_MESAGES = 0x8004060A

177 MAPI_E_FOLDER_CYCLE = 0x8004060B

178 MAPI_E_LOCKID_LIMIT = 0x8004060D

179 MAPI_W_PARTIAL_COMPLETION = 0x00040680

180 MAPI_E_AMBIGUOUS_RECIP = 0x80040700

181 SYNC_E_OBJECT_DELETED = 0x80040800

182 SYNC_E_IGNORE = 0x80040801

183 SYNC_E_CONFLICT = 0x80040802

184 SYNC_E_NO_PARENT = 0x80040803

185 SYNC_E_CYCLE_DETECTED = 0x80040804

186 SYNC_E_UNSYNCHRONIZED = 0x80040805

187 SYNC_W_PROGRESS = 0x00040820

188 SYNC_W_CLIENT_CHANGE_NEWER = 0x00040821

189 MAPI_E_NAMED_PROP_QUOTA_EXCEEDED = 0x80040900

190 MAPI_E_NOT_IMPLEMENTED = 0x80040FFF

191 MAPI_E_NO_ACCESS = 0x80070005

192 MAPI_E_NOT_ENOUGH_MEMORY = 0x8007000E

193 MAPI_E_INVALID_PARAMETER = 0x80070057

194

195 LDAP_NO_SUCH_OBJECT = 0x80040920

196 LDAP_SERVER_DOWN = 0x80040951

197 LDAP_LOCAL_ERROR = 0x80040952

198

199

200# PR_DISPLAY_TYPE

201# For address book contents tables

202 DT_MAILUSER = 0x00000000

203 DT_DISTLIST = 0x00000001

204 DT_FORUM = 0x00000002

205 DT_AGENT = 0x00000003

206 DT_ORGANIZATION = 0x00000004

207 DT_PRIVATE_DISTLIST = 0x00000005

208 DT_REMOTE_MAILUSER = 0x00000006

209# For address book hierarchy tables

210 DT_MODIFIABLE = 0x00010000

211 DT_GLOBAL = 0x00020000

212 DT_LOCAL = 0x00030000

213 DT_WAN = 0x00040000

214 DT_NOT_SPECIFIC = 0x00050000

215# For folder hierarchy tables *

216 DT_FOLDER = 0x01000000

217 DT_FOLDER_LINK = 0x02000000

218 DT_FOLDER_SPECIAL = 0x04000000

219

220 PR_DISPLAY_TYPE_VALUES = {

221 0x00000000: "DT_MAILUSER",

222 0x00000001: "DT_DISTLIST",

223 0x00000002: "DT_FORUM",

224 0x00000003: "DT_AGENT",

225 0x00000004: "DT_ORGANIZATION",

226 0x00000005: "DT_PRIVATE_DISTLIST",

227 0x00000006: "DT_REMOTE_MAILUSER",

228 0x00010000: "DT_MODIFIABLE",

229 0x00020000: "DT_GLOBAL",

230 0x00030000: "DT_LOCAL",

231 0x00040000: "DT_WAN",

232 0x00050000: "DT_NOT_SPECIFIC",

233 0x01000000: "DT_FOLDER",

234 0x02000000: "DT_FOLDER_LINK",

235 0x04000000: "DT_FOLDER_SPECIAL"

236}

237

238# PR_OBJECT_TYPE

239 MAPI_STORE = 0x1

240 MAPI_ADDRBOOK = 0x2

241 MAPI_FOLDER = 0x3

242 MAPI_ABCONT = 0x4

243 MAPI_MESSAGE = 0x5

244 MAPI_MAILUSER = 0x6

245 MAPI_ATTACH = 0x7

246 MAPI_DISTLIST = 0x8

247 MAPI_PROFSECT = 0x9

248 MAPI_STATUS = 0xA

249 MAPI_SESSION = 0xB

250 MAPI_FORMINFO = 0xC

251

252 PR_OBJECT_TYPE_VALUES = {

253 0x1: "MAPI_STORE",

254 0x2: "MAPI_ADDRBOOK",

255 0x3: "MAPI_FOLDER",

256 0x4: "MAPI_ABCONT",

257 0x5: "MAPI_MESSAGE",

258 0x6: "MAPI_MAILUSER",

259 0x7: "MAPI_ATTACH",

260 0x8: "MAPI_DISTLIST",

261 0x9: "MAPI_PROFSECT",

262 0xA: "MAPI_STATUS",

263 0xB: "MAPI_SESSION",

264 0xC: "MAPI_FORMINFO"

265}

266

267# PR_CONTAINER_FLAGS

268 AB_RECIPIENTS = 0x00000001

269 AB_SUBCONTAINERS = 0x00000002

270 AB_MODIFIABLE = 0x00000004

271 AB_UNMODIFIABLE = 0x00000008

272 AB_FIND_ON_OPEN = 0x00000010

273 AB_NOT_DEFAULT = 0x00000020

274 AB_CONF_ROOMS = 0x00000200

275

276 PR_CONTAINER_FLAGS_VALUES = {

277 0x00000001: "AB_RECIPIENTS",

278 0x00000002: "AB_SUBCONTAINERS",

279 0x00000004: "AB_MODIFIABLE",

280 0x00000008: "AB_UNMODIFIABLE",

281 0x00000010: "AB_FIND_ON_OPEN",

282 0x00000020: "AB_NOT_DEFAULT",

283 0x00000200: "AB_CONF_ROOMS"

284}

285

286 MAPI_PROPERTIES = {

287 # Field_1: (Field_2, Field_3, Field_4, Field_5, Field_6, Field_7, Field_8),

288 #

289 # Field_1 is PropertyId

290 # Field_2 is PropertyType (unicode when possible)

291 # Field_3 is Active Directory LDAP-Display-Name

292 # Field_4 is Active Directory CN

293 # Field_5:

294 # 1 when Is-Member-Of-Partial-Attribute-Set is TRUE

295 # 2 when Is-Member-Of-Partial-Attribute-Set is FALSE

296 # 3 when Is-Member-Of-Partial-Attribute-Set does not exist

297 # 4 when it's not an Active Directory property

298 #

299 # Field_6 is MS-OXPROPS Canonical Name

300 # Field_7 is MS-OXPROPS First Alternate Name (usually the shortest one which starts from PR_)

301 # Field_8 is internal Exchange name

302 0x0806: (0x101f, "msExchResourceSearchProperties", "ms-Exch-Resource-Search-Properties", 1, None, None, None),

303 0x0807: (0x0003, "msExchResourceCapacity", "ms-Exch-Resource-Capacity", 1, "PidTagAddressBookRoomCapacity", "PR_EMS_AB_ROOM_CAPACITY", None),

304 0x0808: (0x101f, "msExchResourceMetaData", "ms-Exch-Resource-Meta-Data", 1, None, None, None),

305 0x0809: (0x001f, "msExchResourceDisplay", "ms-Exch-Resource-Display", 1, "PidTagAddressBookRoomDescription", "PR_EMS_AB_ROOM_DESCRIPTION", None),

306 0x3004: (0x001f, "info", "Comment", 1, "PidTagComment", "PR_COMMENT", "Comment"),

307 0x3007: (0x0040, "whenCreated", "When-Created", 1, "PidTagCreationTime", "PR_CREATION_TIME", "CreationTime"),

308 0x3008: (0x0040, "whenChanged", "When-Changed", 1, "PidTagLastModificationTime", "PR_LAST_MODIFICATION_TIME", "LastModificationTime"),

309 0x3905: (0x0003, "msExchRecipientDisplayType", "ms-Exch-Recipient-Display-Type", 1, "PidTagDisplayTypeEx", "PR_DISPLAY_TYPE_EX", "DisplayTypeEx"),

310 0x39fe: (0x001f, "mail", "E-mail-Addresses", 1, "PidTagSmtpAddress", "PR_SMTP_ADDRESS", "SmtpAddress"),

311 0x39ff: (0x001f, "displayNamePrintable", "Display-Name-Printable", 1, "PidTagAddressBookDisplayNamePrintable", "PR_EMS_AB_DISPLAY_NAME_PRINTABLE", "SimpleDisplayName"),

312 0x3a00: (0x001f, "mailNickname", "ms-Exch-Mail-Nickname", 1, "PidTagAccount", "PR_ACCOUNT", "Account"),

313 0x3a06: (0x001f, "givenName", "Given-Name", 1, "PidTagGivenName", "PR_GIVEN_NAME", "GivenName"),

314 0x3a08: (0x001f, "telephoneNumber", "Telephone-Number", 1, "PidTagBusinessTelephoneNumber", "PR_BUSINESS_TELEPHONE_NUMBER", "BusinessTelephoneNumber"),

315 0x3a09: (0x001f, "homePhone", "Phone-Home-Primary", 1, "PidTagHomeTelephoneNumber", "PR_HOME_TELEPHONE_NUMBER", "HomeTelephoneNumber"),

316 0x3a0a: (0x001f, "initials", "Initials", 1, "PidTagInitials", "PR_INITIALS", "Initials"),

317 0x3a0f: (0x001f, "cn", "Common-Name", 1, "PidTagMessageHandlingSystemCommonName", "PR_MHS_COMMON_NAME", "MhsCommonName"),

318 0x3a11: (0x001f, "sn", "Surname", 1, "PidTagSurname", "PR_SURNAME", "Surname"),

319 0x3a16: (0x001f, "company", "Company", 1, "PidTagCompanyName", "PR_COMPANY_NAME", "CompanyName"),

320 0x3a17: (0x001f, "title", "Title", 1, "PidTagTitle", "PR_TITLE", "Title"),

321 0x3a18: (0x001f, "department", "Department", 1, "PidTagDepartmentName", "PR_DEPARTMENT_NAME", "DepartmentName"),

322 0x3a19: (0x001f, "physicalDeliveryOfficeName", "Physical-Delivery-Office-Name", 1, "PidTagOfficeLocation", "PR_OFFICE_LOCATION", "OfficeLocation"),

323 0x3a1b: (0x101f, "otherTelephone", "Phone-Office-Other", 1, "PidTagBusiness2TelephoneNumbers", "PR_BUSINESS2_TELEPHONE_NUMBER_A_MV", "Business2TelephoneNumber"),

324 0x3a1c: (0x001f, "mobile", "Phone-Mobile-Primary", 1, "PidTagMobileTelephoneNumber", "PR_MOBILE_TELEPHONE_NUMBER", "MobileTelephoneNumber"),

325 0x3a21: (0x001f, "pager", "Phone-Pager-Primary", 1, "PidTagPagerTelephoneNumber", "PR_PAGER_TELEPHONE_NUMBER", "PagerTelephoneNumber"),

326 0x3a22: (0x0102, "userCert", "User-Cert", 1, "PidTagUserCertificate", "PR_USER_CERTIFICATE", "UserCertificate"),

327 0x3a23: (0x001f, "facsimileTelephoneNumber", "Facsimile-Telephone-Number", 1, "PidTagPrimaryFaxNumber", "PR_PRIMARY_FAX_NUMBER", "PrimaryFaxNumber"),

328 0x3a26: (0x001f, "co", "Text-Country", 1, "PidTagCountry", "PR_COUNTRY", "Country"),

329 0x3a27: (0x001f, "l", "Locality-Name", 1, "PidTagLocality", "PR_LOCALITY", "Locality"),

330 0x3a28: (0x001f, "st", "State-Or-Province-Name", 1, "PidTagStateOrProvince", "PR_STATE_OR_PROVINCE", "StateOrProvince"),

331 0x3a29: (0x001f, "streetAddress", "Address", 1, "PidTagStreetAddress", "PR_STREET_ADDRESS", "StreetAddress"),

332 0x3a2a: (0x001f, "postalCode", "Postal-Code", 1, "PidTagPostalCode", "PR_POSTAL_CODE", "PostalCode"),

333 0x3a2b: (0x101f, "postOfficeBox", "Post-Office-Box", 1, "PidTagPostOfficeBox", "PR_POST_OFFICE_BOX", "PostOfficeBox"),

334 0x3a2c: (0x1102, "telexNumber", "Telex-Number", 3, "PidTagTelexNumber", "PR_TELEX_NUMBER", "TelexNumber"),

335 0x3a2e: (0x001f, "telephoneAssistant", "ms-Exch-Telephone-Assistant", 1, "PidTagAssistantTelephoneNumber", "PR_ASSISTANT_TELEPHONE_NUMBER", "AssistantTelephoneNumber"),

336 0x3a2f: (0x101f, "otherHomePhone", "Phone-Home-Other", 1, "PidTagHome2TelephoneNumbers", "PR_HOME2_TELEPHONE_NUMBER_A_MV", "Home2TelephoneNumber"),

337 0x3a30: (0x001f, "msExchAssistantName", "ms-Exch-Assistant-Name", 1, "PidTagAssistant", "PR_ASSISTANT", "Assistant"),

338 0x3a40: (0x000b, "mAPIRecipient", "ms-Exch-MAPI-Recipient", 1, "PidTagSendRichInfo", "PR_SEND_RICH_INFO", "SendRichInfo"),

339 0x3a5d: (0x001f, "homePostalAddress", "Address-Home", 1, "PidTagHomeAddressStreet", "PR_HOME_ADDRESS_STREET", "HomeAddressStreet"),

340 0x3a70: (0x1102, "userSMIMECertificate", "User-SMIME-Certificate", 1, "PidTagUserX509Certificate", "PR_USER_X509_CERTIFICATE", "UserSMimeCertificate"),

341 0x3a71: (0x0003, "internetEncoding", "ms-Exch-Internet-Encoding", 1, "PidTagSendInternetEncoding", "PR_SEND_INTERNET_ENCODING", "SendInternetEncoding"),

342 0x8003: (0x1102, "cACertificate", "CA-Certificate", 1, None, None, None),

343 0x8004: (0x001f, "folderPathname", "ms-Exch-Folder-Pathname", 1, "PidTagAddressBookFolderPathname", "PR_EMS_AB_FOLDER_PATHNAME", None),

344 0x8005: (0x000d, "manager", "Manager", 1, "PidTagAddressBookManagerDistinguishedName", "PR_EMS_AB_MANAGER_T", None),

345 0x8006: (0x000d, "homeMDB", "ms-Exch-Home-MDB", 1, "PidTagAddressBookHomeMessageDatabase", "PR_EMS_AB_HOME_MDB", "HomeMdb"),

346 0x8007: (0x001f, "homeMTA", "ms-Exch-Home-MTA", 1, "PidLidContactItemData", "dispidContactItemData", None),

347 0x8008: (0x000d, "memberOf", "Is-Member-Of-DL", 3, "PidTagAddressBookIsMemberOfDistributionList", "PR_EMS_AB_IS_MEMBER_OF_DL", "MemberOf"),

348 0x8009: (0x000d, "member", "Member", 1, "PidTagAddressBookMember", "PR_EMS_AB_MEMBER", "Members"),

349 0x800a: (0x001f, "autoReplyMessage", "ms-Exch-AutoReply-Message", 2, None, None, None),

350 0x800b: (0x000b, "autoReply", "ms-Exch-AutoReply", 1, None, None, None),

351 0x800c: (0x000d, "managedBy", "Managed-By", 1, "PidTagAddressBookOwner", "PR_EMS_AB_OWNER_O", "ManagedBy"),

352 0x800d: (0x001f, "kMServer", "ms-Exch-KM-Server", 2, None, None, None),

353 0x800e: (0x000d, "directReports", "Reports", 3, "PidTagAddressBookReports", "PR_EMS_AB_REPORTS", None),

354 0x800f: (0x101f, "proxyAddresses", "Proxy-Addresses", 1, "PidTagAddressBookProxyAddresses", "PR_EMS_AB_PROXY_ADDRESSES", "ProxyAddresses"),

355 0x8010: (0x0102, "helpData32", "Help-Data32", 3, "PidLidDepartment", "dispidDepartment", "TemplateInfoHelpFileContents"),

356 0x8011: (0x001f, "targetAddress", "ms-Exch-Target-Address", 1, "PidTagAddressBookTargetAddress", "PR_EMS_AB_TARGET_ADDRESS", None),

357 0x8014: (0x000d, "homeMDBBL", "ms-Exch-Home-MDB-BL", 1, None, None, None),

358 0x8015: (0x000d, "publicDelegates", "ms-Exch-Public-Delegates", 1, "PidTagAddressBookPublicDelegates", "PR_EMS_AB_PUBLIC_DELEGATES", "GrantSendOnBehalfTo"),

359 0x8016: (0x0102, "certificateRevocationList", "Certificate-Revocation-List", 3, None, None, None),

360 0x8017: (0x0102, "addressEntryDisplayTable", "Address-Entry-Display-Table", 3, None, None, "TemplateInfoTemplate"),

361 0x8018: (0x0102, "addressSyntax", "Address-Syntax", 3, None, None, "TemplateInfoScript"),

362 0x8023: (0x0102, "businessRoles", "ms-Exch-Business-Roles", 2, "PidLidContactCharacterSet", "dispidContactCharSet", None),

363 0x8024: (0x000d, "managedObjects", "Managed-Objects", 3, "PidTagAddressBookOwnerBackLink", "PR_EMS_AB_OWNER_BL_O", None),

364 0x8025: (0x1102, "crossCertificatePair", "Cross-Certificate-Pair", 3, "PidLidAutoLog", "dispidAutoLog", None),

365 0x8026: (0x1102, "authorityRevocationList", "Authority-Revocation-List", 3, "PidLidFileUnderList", "dispidFileUnderList", None),

366 0x8027: (0x0102, "objectSid", "Object-Sid", 1, None, None, None),

367 0x8028: (0x0040, "expirationTime", "ms-Exch-Expiration-Time", 2, "PidLidAddressBookProviderEmailList", "dispidABPEmailList", None),

368 0x8029: (0x0003, "uSNChanged", "USN-Changed", 1, "PidLidAddressBookProviderArrayType", "dispidABPArrayType", None),

369 0x802d: (0x001f, "extensionAttribute1", "ms-Exch-Extension-Attribute-1", 1, "PidTagAddressBookExtensionAttribute1", "PR_EMS_AB_EXTENSION_ATTRIBUTE_1", None),

370 0x802e: (0x001f, "extensionAttribute2", "ms-Exch-Extension-Attribute-2", 1, "PidTagAddressBookExtensionAttribute2", "PR_EMS_AB_EXTENSION_ATTRIBUTE_2", None),

371 0x802f: (0x001f, "extensionAttribute3", "ms-Exch-Extension-Attribute-3", 1, "PidTagAddressBookExtensionAttribute3", "PR_EMS_AB_EXTENSION_ATTRIBUTE_3", None),

372 0x8030: (0x001f, "extensionAttribute4", "ms-Exch-Extension-Attribute-4", 1, "PidTagAddressBookExtensionAttribute4", "PR_EMS_AB_EXTENSION_ATTRIBUTE_4", None),

373 0x8031: (0x001f, "extensionAttribute5", "ms-Exch-Extension-Attribute-5", 1, "PidTagAddressBookExtensionAttribute5", "PR_EMS_AB_EXTENSION_ATTRIBUTE_5", None),

374 0x8032: (0x001f, "extensionAttribute6", "ms-Exch-Extension-Attribute-6", 1, "PidTagAddressBookExtensionAttribute6", "PR_EMS_AB_EXTENSION_ATTRIBUTE_6", None),

375 0x8033: (0x001f, "extensionAttribute7", "ms-Exch-Extension-Attribute-7", 1, "PidTagAddressBookExtensionAttribute7", "PR_EMS_AB_EXTENSION_ATTRIBUTE_7", None),

376 0x8034: (0x001f, "extensionAttribute8", "ms-Exch-Extension-Attribute-8", 1, "PidTagAddressBookExtensionAttribute8", "PR_EMS_AB_EXTENSION_ATTRIBUTE_8", None),

377 0x8035: (0x001f, "extensionAttribute9", "ms-Exch-Extension-Attribute-9", 1, "PidTagAddressBookExtensionAttribute9", "PR_EMS_AB_EXTENSION_ATTRIBUTE_9", None),

378 0x8036: (0x001f, "extensionAttribute10", "ms-Exch-Extension-Attribute-10", 1, "PidTagAddressBookExtensionAttribute10", "PR_EMS_AB_EXTENSION_ATTRIBUTE_10", None),

379 0x8037: (0x1102, "securityProtocol", "ms-Exch-Security-Protocol", 1, None, None, None),

380 0x8038: (0x101f, "pFContacts", "ms-Exch-PF-Contacts", 1, None, None, "PfContacts"),

381 0x803a: (0x0102, "helpData16", "Help-Data16", 3, None, None, None),

382 0x803b: (0x001f, "helpFileName", "Help-File-Name", 3, None, None, "TemplateInfoHelpFileName"),

383 0x803c: (0x001f, "distinguishedName", "Obj-Dist-Name", 1, "PidTagAddressBookObjectDistinguishedName", "PR_EMS_AB_OBJ_DIST_NAME", "ObjectDistinguishedName"),

384 0x803d: (0x001f, "encryptAlgSelectedOther", "ms-Exch-Encrypt-Alg-Selected-Other", 2, None, None, None),

385 0x8040: (0x101f, "encryptAlgListNA", "ms-Exch-Encrypt-Alg-List-NA", 2, "PidLidBusinessCardDisplayDefinition", "dispidBCDisplayDefinition", None),

386 0x8041: (0x101f, "encryptAlgListOther", "ms-Exch-Encrypt-Alg-List-Other", 2, "PidLidBusinessCardCardPicture", "dispidBCCardPicture", None),

387 0x8042: (0x001f, "importedFrom", "ms-Exch-Imported-From", 1, None, None, None),

388 0x8043: (0x001f, "encryptAlgSelectedNA", "ms-Exch-Encrypt-Alg-Selected-NA", 2, None, None, None),

389 0x8045: (0x0102, "activationSchedule", "ms-Exch-Activation-Schedule", 2, "PidLidWorkAddressStreet", "dispidWorkAddressStreet", None),

390 0x8046: (0x0003, "activationStyle", "ms-Exch-Activation-Style", 2, "PidLidWorkAddressCity", "dispidWorkAddressCity", None),

391 0x8047: (0x0102, "addressEntryDisplayTableMSDOS", "Address-Entry-Display-Table-MSDOS", 3, "PidLidWorkAddressState", "dispidWorkAddressState", None),

392 0x8048: (0x001f, "addressType", "Address-Type", 3, "PidLidWorkAddressPostalCode", "dispidWorkAddressPostalCode", "TemplateInfoEmailType"),

393 0x8049: (0x001f, "aDMD", "ms-Exch-ADMD", 2, "PidLidWorkAddressCountry", "dispidWorkAddressCountry", None),

394 0x804a: (0x001f, "adminDescription", "Admin-Description", 3, "PidLidWorkAddressPostOfficeBox", "dispidWorkAddressPostOfficeBox", None),

395 0x804b: (0x001f, "adminDisplayName", "Admin-Display-Name", 1, None, None, None),

396 0x804c: (0x001f, "adminExtensionDLL", "ms-Exch-Admin-Extension-DLL", 2, "PidLidDistributionListChecksum", "dispidDLChecksum", None),

397 0x804e: (0x000d, "altRecipient", "ms-Exch-Alt-Recipient", 1, "PidLidAnniversaryEventEntryId", "dispidAnniversaryEventEID", None),

398 0x804f: (0x000d, "altRecipientBL", "ms-Exch-Alt-Recipient-BL", 2, "PidLidContactUserField1", "dispidContactUserField1", None),

399 0x8051: (0x000d, "assocRemoteDXA", "ms-Exch-Assoc-Remote-DXA", 2, "PidLidContactUserField3", "dispidContactUserField3", None),

400 0x8052: (0x0003, "associationLifetime", "ms-Exch-Association-Lifetime", 2, "PidLidContactUserField4", "dispidContactUserField4", None),

401 0x8053: (0x000d, "authOrigBL", "ms-Exch-Auth-Orig-BL", 1, "PidLidDistributionListName", "dispidDLName", None),

402 0x8054: (0x001f, "authorizedDomain", "ms-Exch-Authorized-Domain", 2, "PidLidDistributionListOneOffMembers", "dispidDLOneOffMembers", None),

403 0x8055: (0x0102, "authorizedPassword", "ms-Exch-Authorized-Password", 2, "PidLidDistributionListMembers", "dispidDLMembers", None),

404 0x8056: (0x001f, "authorizedUser", "ms-Exch-Authorized-User", 2, None, None, None),

405 0x8057: (0x101f, "businessCategory", "Business-Category", 3, None, None, None),

406 0x8060: (0x000b, "canPreserveDNs", "ms-Exch-Can-Preserve-DNs", 2, None, None, None),

407 0x8061: (0x0003, "clockAlertOffset", "ms-Exch-Clock-Alert-Offset", 2, None, None, None),

408 0x8062: (0x000b, "clockAlertRepair", "ms-Exch-Clock-Alert-Repair", 2, "PidLidInstantMessagingAddress", "dispidInstMsg", None),

409 0x8063: (0x0003, "clockWarningOffset", "ms-Exch-Clock-Warning-Offset", 2, None, None, None),

410 0x8064: (0x000b, "clockWarningRepair", "ms-Exch-Clock-Warning-Repair", 2, "PidLidDistributionListStream", "dispidDLStream", None),

411 0x8065: (0x001f, "computerName", "ms-Exch-Computer-Name", 2, None, None, None),

412 0x8066: (0x101f, "connectedDomains", "ms-Exch-Connected-Domains", 2, None, None, None),

413 0x8067: (0x0003, "containerInfo", "ms-Exch-Container-Info", 2, None, None, None),

414 0x8068: (0x0003, "cost", "Cost", 3, None, None, None),

415 0x8069: (0x001f, "c", "Country-Name", 1, None, None, None),

416 0x806a: (0x0003, "delivContLength", "ms-Exch-Deliv-Cont-Length", 1, "PidTagAddressBookDeliveryContentLength", "PR_EMS_AB_DELIV_CONT_LENGTH", None),

417 0x806b: (0x1102, "delivEITs", "ms-Exch-Deliv-EITs", 2, None, None, None),

418 0x806c: (0x1102, "delivExtContTypes", "ms-Exch-Deliv-Ext-Cont-Types", 1, None, None, None),

419 0x806d: (0x000b, "deliverAndRedirect", "ms-Exch-Deliver-And-Redirect", 1, None, None, None),

420 0x806e: (0x0003, "deliveryMechanism", "ms-Exch-Delivery-Mechanism", 1, None, None, None),

421 0x806f: (0x101f, "description", "Description", 1, None, None, None),

422 0x8070: (0x101f, "destinationIndicator", "Destination-Indicator", 3, None, None, None),

423 0x8071: (0x001f, "diagnosticRegKey", "ms-Exch-Diagnostic-Reg-Key", 2, None, None, None),

424 0x8072: (0x000d, "dLMemRejectPermsBL", "ms-Exch-DL-Mem-Reject-Perms-BL", 1, None, None, None),

425 0x8073: (0x000d, "dLMemSubmitPermsBL", "ms-Exch-DL-Mem-Submit-Perms-BL", 1, "PidTagAddressBookDistributionListMemberSubmitAccepted", "PR_EMS_AB_DL_MEM_SUBMIT_PERMS_BL_O", None),

426 0x8074: (0x1102, "dLMemberRule", "ms-Exch-DL-Member-Rule", 1, None, None, None),

427 0x8075: (0x001f, "domainDefAltRecip", "ms-Exch-Domain-Def-Alt-Recip", 2, None, None, None),

428 0x8076: (0x001f, "domainName", "ms-Exch-Domain-Name", 2, None, None, None),

429 0x8077: (0x0102, "dSASignature", "DSA-Signature", 3, None, None, None),

430 0x8078: (0x000b, "dXAAdminCopy", "ms-Exch-DXA-Admin-Copy", 2, None, None, None),

431 0x8079: (0x000b, "dXAAdminForward", "ms-Exch-DXA-Admin-Forward", 2, None, None, None),

432 0x807a: (0x0003, "dXAAdminUpdate", "ms-Exch-DXA-Admin-Update", 2, None, None, None),

433 0x807b: (0x000b, "dXAAppendReqCN", "ms-Exch-DXA-Append-ReqCN", 2, None, None, None),

434 0x807c: (0x101f, "dXAConfContainerList", "ms-Exch-DXA-Conf-Container-List", 2, None, None, None),

435 0x807d: (0x0040, "dXAConfReqTime", "ms-Exch-DXA-Conf-Req-Time", 2, None, None, None),

436 0x807e: (0x001f, "dXAConfSeq", "ms-Exch-DXA-Conf-Seq", 2, None, None, None),

437 0x807f: (0x0003, "dXAConfSeqUSN", "ms-Exch-DXA-Conf-Seq-USN", 2, None, None, None),

438 0x8080: (0x0003, "dXAExchangeOptions", "ms-Exch-DXA-Exchange-Options", 2, "PidLidEmail1DisplayName", "dispidEmail1DisplayName", None),

439 0x8081: (0x000b, "dXAExportNow", "ms-Exch-DXA-Export-Now", 2, None, None, None),

440 0x8082: (0x0003, "deletedItemFlags", "ms-Exch-Deleted-Item-Flags", 1, "PidLidEmail1AddressType", "dispidEmail1AddrType", None),

441 0x8083: (0x001f, "dXAImpSeq", "ms-Exch-DXA-Imp-Seq", 2, "PidLidEmail1EmailAddress", "dispidEmail1EmailAddress", None),

442 0x8084: (0x0040, "dXAImpSeqTime", "ms-Exch-DXA-Imp-Seq-Time", 2, "PidLidEmail1OriginalDisplayName", "dispidEmail1OriginalDisplayName", None),

443 0x8085: (0x0003, "dXAImpSeqUSN", "ms-Exch-DXA-Imp-Seq-USN", 2, "PidLidEmail1OriginalEntryId", "dispidEmail1OriginalEntryID", None),

444 0x8086: (0x000b, "dXAImportNow", "ms-Exch-DXA-Import-Now", 2, None, None, None),

445 0x8087: (0x101f, "dXAInTemplateMap", "ms-Exch-DXA-In-Template-Map", 2, None, None, None),

446 0x8088: (0x001f, "dXALocalAdmin", "ms-Exch-DXA-Local-Admin", 2, None, None, None),

447 0x808a: (0x001f, "dXANativeAddressType", "ms-Exch-DXA-Native-Address-Type", 2, None, None, None),

448 0x808b: (0x101f, "dXAOutTemplateMap", "ms-Exch-DXA-Out-Template-Map", 2, None, None, None),

449 0x808c: (0x001f, "dXAPassword", "ms-Exch-DXA-Password", 2, None, None, None),

450 0x808d: (0x0003, "dXAPrevExchangeOptions", "ms-Exch-DXA-Prev-Exchange-Options", 2, None, None, None),

451 0x808e: (0x000b, "dXAPrevExportNativeOnly", "ms-Exch-DXA-Prev-Export-Native-Only", 2, None, None, None),

452 0x808f: (0x0003, "dXAPrevInExchangeSensitivity", "ms-Exch-DXA-Prev-In-Exchange-Sensitivity", 2, None, None, None),

453 0x8090: (0x001f, "dXAPrevRemoteEntries", "ms-Exch-DXA-Prev-Remote-Entries", 2, "PidLidEmail2DisplayName", "dispidEmail2DisplayName", None),

454 0x8091: (0x0003, "dXAPrevReplicationSensitivity", "ms-Exch-DXA-Prev-Replication-Sensitivity", 2, None, None, None),

455 0x8092: (0x0003, "dXAPrevTemplateOptions", "ms-Exch-DXA-Prev-Template-Options", 2, "PidLidEmail2AddressType", "dispidEmail2AddrType", None),

456 0x8093: (0x0003, "dXAPrevTypes", "ms-Exch-DXA-Prev-Types", 2, "PidLidEmail2EmailAddress", "dispidEmail2EmailAddress", None),

457 0x8094: (0x001f, "dXARecipientCP", "ms-Exch-DXA-Recipient-CP", 2, "PidLidEmail2OriginalDisplayName", "dispidEmail2OriginalDisplayName", None),

458 0x8095: (0x001f, "dXARemoteClient", "ms-Exch-DXA-Remote-Client", 2, "PidLidEmail2OriginalEntryId", "dispidEmail2OriginalEntryID", None),

459 0x8096: (0x001f, "dXAReqSeq", "ms-Exch-DXA-Req-Seq", 2, None, None, None),

460 0x8097: (0x0040, "dXAReqSeqTime", "ms-Exch-DXA-Req-Seq-Time", 2, None, None, None),

461 0x8098: (0x0003, "dXAReqSeqUSN", "ms-Exch-DXA-Req-Seq-USN", 2, None, None, None),

462 0x8099: (0x001f, "dXAReqName", "ms-Exch-DXA-ReqName", 2, None, None, None),

463 0x809a: (0x001f, "dXASvrSeq", "ms-Exch-DXA-Svr-Seq", 2, None, None, None),

464 0x809b: (0x0040, "dXASvrSeqTime", "ms-Exch-DXA-Svr-Seq-Time", 2, None, None, None),

465 0x809c: (0x0003, "dXASvrSeqUSN", "ms-Exch-DXA-Svr-Seq-USN", 2, None, None, None),

466 0x809d: (0x0003, "messageSizeLimit", "ms-Exch-Message-Size-Limit", 2, None, None, None),

467 0x809e: (0x0003, "dXATemplateOptions", "ms-Exch-DXA-Template-Options", 2, None, None, None),

468 0x809f: (0x0040, "dXATemplateTimeStamp", "ms-Exch-DXA-Template-TimeStamp", 2, None, None, None),

469 0x80a0: (0x0003, "dXATypes", "ms-Exch-DXA-Types", 2, "PidLidEmail3DisplayName", "dispidEmail3DisplayName", None),

470 0x80a1: (0x101f, "dXAUnConfContainerList", "ms-Exch-DXA-UnConf-Container-List", 2, None, None, None),

471 0x80a2: (0x0003, "encapsulationMethod", "ms-Exch-Encapsulation-Method", 2, "PidLidEmail3AddressType", "dispidEmail3AddrType", None),

472 0x80a3: (0x000b, "encrypt", "ms-Exch-Encrypt", 2, "PidLidEmail3EmailAddress", "dispidEmail3EmailAddress", None),

473 0x80a4: (0x000b, "expandDLsLocally", "ms-Exch-Expand-DLs-Locally", 2, "PidLidEmail3OriginalDisplayName", "dispidEmail3OriginalDisplayName", None),

474 0x80a5: (0x101f, "exportContainers", "ms-Exch-Export-Containers", 2, "PidLidEmail3OriginalEntryId", "dispidEmail3OriginalEntryID", None),

475 0x80a6: (0x000b, "exportCustomRecipients", "ms-Exch-Export-Custom-Recipients", 2, None, None, None),

476 0x80a7: (0x000b, "extendedCharsAllowed", "Extended-Chars-Allowed", 3, None, None, None),

477 0x80a8: (0x1102, "extensionData", "ms-Exch-Extension-Data", 2, None, None, None),

478 0x80a9: (0x101f, "extensionName", "Extension-Name", 3, None, None, None),

479 0x80ac: (0x0102, "fileVersion", "ms-Exch-File-Version", 2, None, None, None),

480 0x80ad: (0x000b, "filterLocalAddresses", "ms-Exch-Filter-Local-Addresses", 2, None, None, None),

481 0x80af: (0x0003, "garbageCollPeriod", "Garbage-Coll-Period", 1, None, None, None),

482 0x80b0: (0x001f, "gatewayLocalCred", "ms-Exch-Gateway-Local-Cred", 2, None, None, None),

483 0x80b1: (0x001f, "gatewayLocalDesig", "ms-Exch-Gateway-Local-Desig", 2, None, None, None),

484 0x80b2: (0x101f, "gatewayProxy", "ms-Exch-Gateway-Proxy", 2, "PidLidFax1AddressType", "dispidFax1AddrType", None),

485 0x80b3: (0x0102, "gatewayRoutingTree", "ms-Exch-Gateway-Routing-Tree", 2, "PidLidFax1EmailAddress", "dispidFax1EmailAddress", None),

486 0x80b4: (0x0040, "gWARTLastModified", "ms-Exch-GWART-Last-Modified", 2, "PidLidFax1OriginalDisplayName", "dispidFax1OriginalDisplayName", None),

487 0x80b5: (0x000d, "hasPartialReplicaNCs", "Has-Partial-Replica-NCs", 3, "PidLidFax1OriginalEntryId", "dispidFax1OriginalEntryID", None),

488 0x80b6: (0x000d, "hasMasterNCs", "Has-Master-NCs", 3, None, None, None),

489 0x80b7: (0x0003, "heuristics", "ms-Exch-Heuristics", 1, None, None, None),

490 0x80b8: (0x000b, "hideDLMembership", "ms-Exch-Hide-DL-Membership", 1, None, None, "HideDLMembership"),

491 0x80ba: (0x001f, "importContainer", "ms-Exch-Import-Container", 2, None, None, None),

492 0x80bc: (0x101f, "inboundSites", "ms-Exch-Inbound-Sites", 2, None, None, None),

493 0x80bd: (0x0003, "instanceType", "Instance-Type", 1, None, None, None),

494 0x80be: (0x101f, "internationalISDNNumber", "International-ISDN-Number", 3, None, None, None),

495 0x80bf: (0x0102, "invocationId", "Invocation-Id", 3, None, None, None),

496 0x80c0: (0x000b, "isDeleted", "Is-Deleted", 1, None, None, None),

497 0x80c1: (0x000b, "isSingleValued", "Is-Single-Valued", 3, None, None, None),

498 0x80c2: (0x1102, "kCCStatus", "ms-Exch-KCC-Status", 2, "PidLidFax2AddressType", "dispidFax2AddrType", None),

499 0x80c3: (0x101f, "knowledgeInformation", "Knowledge-Information", 3, "PidLidFax2EmailAddress", "dispidFax2EmailAddress", None),

500 0x80c4: (0x0003, "lineWrap", "ms-Exch-Line-Wrap", 2, "PidLidFax2OriginalDisplayName", "dispidFax2OriginalDisplayName", None),

501 0x80c5: (0x0003, "linkID", "Link-ID", 3, "PidLidFax2OriginalEntryId", "dispidFax2OriginalEntryID", None),

502 0x80c6: (0x001f, "localBridgeHead", "ms-Exch-Local-Bridge-Head", 2, None, None, None),

503 0x80c7: (0x001f, "localBridgeHeadAddress", "ms-Exch-Local-Bridge-Head-Address", 2, None, None, None),

504 0x80c8: (0x000b, "localInitialTurn", "ms-Exch-Local-Initial-Turn", 2, None, None, None),

505 0x80ca: (0x001f, "logFilename", "ms-Exch-Log-Filename", 2, None, None, None),

506 0x80cb: (0x0003, "logRolloverInterval", "ms-Exch-Log-Rollover-Interval", 2, None, None, None),

507 0x80ce: (0x0003, "mAPIID", "MAPI-ID", 3, None, None, None),

508 0x80cf: (0x0003, "mDBBackoffInterval", "ms-Exch-MDB-Backoff-Interval", 2, None, None, None),

509 0x80d0: (0x0003, "mDBMsgTimeOutPeriod", "ms-Exch-MDB-Msg-Time-Out-Period", 2, None, None, None),

510 0x80d1: (0x0003, "mDBOverQuotaLimit", "ms-Exch-MDB-Over-Quota-Limit", 1, None, None, None),

511 0x80d2: (0x0003, "mDBStorageQuota", "ms-Exch-MDB-Storage-Quota", 1, "PidLidFax3AddressType", "dispidFax3AddrType", None),

512 0x80d3: (0x0003, "mDBUnreadLimit", "ms-Exch-MDB-Unread-Limit", 2, "PidLidFax3EmailAddress", "dispidFax3EmailAddress", None),

513 0x80d4: (0x000b, "mDBUseDefaults", "ms-Exch-MDB-Use-Defaults", 1, "PidLidFax3OriginalDisplayName", "dispidFax3OriginalDisplayName", None),

514 0x80d5: (0x000b, "messageTrackingEnabled", "ms-Exch-Message-Tracking-Enabled", 2, "PidLidFax3OriginalEntryId", "dispidFax3OriginalEntryID", None),

515 0x80d6: (0x000b, "monitorClock", "ms-Exch-Monitor-Clock", 2, None, None, None),

516 0x80d7: (0x000b, "monitorServers", "ms-Exch-Monitor-Servers", 2, None, None, None),

517 0x80d8: (0x000b, "monitorServices", "ms-Exch-Monitor-Services", 2, "PidLidFreeBusyLocation", "dispidFreeBusyLocation", None),

518 0x80d9: (0x101f, "monitoredConfigurations", "ms-Exch-Monitored-Configurations", 2, None, None, None),

519 0x80da: (0x101f, "monitoredServers", "ms-Exch-Monitored-Servers", 2, "PidLidHomeAddressCountryCode", "dispidHomeAddressCountryCode", None),

520 0x80db: (0x101f, "monitoredServices", "ms-Exch-Monitored-Services", 2, "PidLidWorkAddressCountryCode", "dispidWorkAddressCountryCode", None),

521 0x80dc: (0x0003, "monitoringAlertDelay", "ms-Exch-Monitoring-Alert-Delay", 2, "PidLidOtherAddressCountryCode", "dispidOtherAddressCountryCode", None),

522 0x80dd: (0x0003, "monitoringAlertUnits", "ms-Exch-Monitoring-Alert-Units", 2, "PidLidAddressCountryCode", "dispidAddressCountryCode", None),

523 0x80de: (0x0003, "monitoringAvailabilityStyle", "ms-Exch-Monitoring-Availability-Style", 2, "PidLidBirthdayLocal", "dispidApptBirthdayLocal", None),

524 0x80df: (0x0102, "monitoringAvailabilityWindow", "ms-Exch-Monitoring-Availability-Window", 2, "PidLidWeddingAnniversaryLocal", "dispidApptAnniversaryLocal", None),

525 0x80e0: (0x101f, "monitoringCachedViaMail", "ms-Exch-Monitoring-Cached-Via-Mail", 2, "PidLidIsContactLinked", "dispidIsContactLinked", None),

526 0x80e1: (0x101f, "monitoringCachedViaRPC", "ms-Exch-Monitoring-Cached-Via-RPC", 2, None, None, None),

527 0x80e2: (0x1102, "monitoringEscalationProcedure", "ms-Exch-Monitoring-Escalation-Procedure", 2, "PidLidContactLinkedGlobalAddressListEntryId", "dispidContactLinkedGALEntryID", None),

528 0x80e3: (0x0003, "monitoringHotsitePollInterval", "ms-Exch-Monitoring-Hotsite-Poll-Interval", 2, "PidLidContactLinkSMTPAddressCache", "dispidContactLinkSMTPAddressCache", None),

529 0x80e4: (0x0003, "monitoringHotsitePollUnits", "ms-Exch-Monitoring-Hotsite-Poll-Units", 2, None, None, None),

530 0x80e5: (0x0003, "monitoringMailUpdateInterval", "ms-Exch-Monitoring-Mail-Update-Interval", 2, "PidLidContactLinkLinkRejectHistory", "dispidContactLinkLinkRejectHistory", None),

531 0x80e6: (0x0003, "monitoringMailUpdateUnits", "ms-Exch-Monitoring-Mail-Update-Units", 2, "PidLidContactLinkGlobalAddressListLinkState", "dispidContactLinkGALLinkState", None),

532 0x80e7: (0x0003, "monitoringNormalPollInterval", "ms-Exch-Monitoring-Normal-Poll-Interval", 2, None, None, None),

533 0x80e8: (0x0003, "monitoringNormalPollUnits", "ms-Exch-Monitoring-Normal-Poll-Units", 2, "PidLidContactLinkGlobalAddressListLinkId", "dispidContactLinkGALLinkID", None),

534 0x80e9: (0x101f, "monitoringRecipients", "ms-Exch-Monitoring-Recipients", 2, None, None, None),

535 0x80ea: (0x101f, "monitoringRecipientsNDR", "ms-Exch-Monitoring-Recipients-NDR", 2, None, None, None),

536 0x80eb: (0x0003, "monitoringRPCUpdateInterval", "ms-Exch-Monitoring-RPC-Update-Interval", 2, None, None, None),

537 0x80ec: (0x0003, "monitoringRPCUpdateUnits", "ms-Exch-Monitoring-RPC-Update-Units", 2, None, None, None),

538 0x80ed: (0x0003, "monitoringWarningDelay", "ms-Exch-Monitoring-Warning-Delay", 2, None, None, None),

539 0x80ee: (0x0003, "monitoringWarningUnits", "ms-Exch-Monitoring-Warning-Units", 2, None, None, None),

540 0x80ef: (0x001f, "mTALocalCred", "ms-Exch-MTA-Local-Cred", 2, None, None, None),

541 0x80f0: (0x001f, "mTALocalDesig", "ms-Exch-MTA-Local-Desig", 2, None, None, None),

542 0x80f1: (0x0102, "nAddress", "ms-Exch-N-Address", 2, None, None, None),

543 0x80f2: (0x0003, "nAddressType", "ms-Exch-N-Address-Type", 2, None, None, None),

544 0x80f4: (0x0003, "numOfOpenRetries", "ms-Exch-Num-Of-Open-Retries", 2, None, None, None),

545 0x80f5: (0x0003, "numOfTransferRetries", "ms-Exch-Num-Of-Transfer-Retries", 2, None, None, None),

546 0x80f6: (0x0003, "objectClassCategory", "Object-Class-Category", 3, None, None, None),

547 0x80f7: (0x0003, "objectVersion", "Object-Version", 3, None, None, None),

548 0x80f8: (0x101f, "offLineABContainers", "ms-Exch-Off-Line-AB-Containers", 2, None, None, None),

549 0x80f9: (0x0102, "offLineABSchedule", "ms-Exch-Off-Line-AB-Schedule", 2, None, None, None),

550 0x80fa: (0x001f, "offLineABServer", "ms-Exch-Off-Line-AB-Server", 2, None, None, None),

551 0x80fb: (0x0003, "offLineABStyle", "ms-Exch-Off-Line-AB-Style", 2, None, None, None),

552 0x80fd: (0x0102, "oMObjectClass", "OM-Object-Class", 3, None, None, None),

553 0x80fe: (0x0003, "oMSyntax", "OM-Syntax", 1, None, None, None),

554 0x80ff: (0x000b, "oOFReplyToOriginator", "ms-Exch-OOF-Reply-To-Originator", 1, None, None, None),

555 0x8100: (0x0003, "openRetryInterval", "ms-Exch-Open-Retry-Interval", 2, None, None, None),

556 0x8101: (0x101f, "o", "Organization-Name", 1, "PidLidTaskStatus", "dispidTaskStatus", None),

557 0x8102: (0x101f, "ou", "Organizational-Unit-Name", 1, "PidLidPercentComplete", "dispidPercentComplete", None),

558 0x8103: (0x0102, "originalDisplayTable", "Original-Display-Table", 3, "PidLidTeamTask", "dispidTeamTask", None),

559 0x8104: (0x0102, "originalDisplayTableMSDOS", "Original-Display-Table-MSDOS", 3, "PidLidTaskStartDate", "dispidTaskStartDate", None),

560 0x8105: (0x101f, "outboundSites", "ms-Exch-Outbound-Sites", 2, "PidLidTaskDueDate", "dispidTaskDueDate", None),

561 0x8106: (0x0102, "pSelector", "ms-Exch-P-Selector", 2, None, None, None),

562 0x8107: (0x0102, "pSelectorInbound", "ms-Exch-P-Selector-Inbound", 2, "PidLidTaskResetReminder", "dispidTaskResetReminder", None),

563 0x8108: (0x0102, "perMsgDialogDisplayTable", "Per-Msg-Dialog-Display-Table", 3, "PidLidTaskAccepted", "dispidTaskAccepted", None),

564 0x8109: (0x0102, "perRecipDialogDisplayTable", "Per-Recip-Dialog-Display-Table", 3, "PidLidTaskDeadOccurrence", "dispidTaskDeadOccur", None),

565 0x810c: (0x101f, "postalAddress", "Postal-Address", 3, None, None, None),

566 0x810e: (0x001f, "pRMD", "ms-Exch-PRMD", 2, None, None, None),

567 0x810f: (0x001f, "proxyGeneratorDLL", "ms-Exch-Proxy-Generator-DLL", 2, "PidLidTaskDateCompleted", "dispidTaskDateCompleted", None),

568 0x8110: (0x000d, "publicDelegatesBL", "ms-Exch-Public-Delegates-BL", 2, "PidLidTaskActualEffort", "dispidTaskActualEffort", None),

569 0x8111: (0x0102, "quotaNotificationSchedule", "ms-Exch-Quota-Notification-Schedule", 2, "PidLidTaskEstimatedEffort", "dispidTaskEstimatedEffort", None),

570 0x8112: (0x0003, "quotaNotificationStyle", "ms-Exch-Quota-Notification-Style", 2, "PidLidTaskVersion", "dispidTaskVersion", None),

571 0x8113: (0x0003, "rangeLower", "Range-Lower", 1, "PidLidTaskState", "dispidTaskState", None),

572 0x8114: (0x0003, "rangeUpper", "Range-Upper", 1, None, None, None),

573 0x8115: (0x001f, "rASCallbackNumber", "ms-Exch-RAS-Callback-Number", 2, "PidLidTaskLastUpdate", "dispidTaskLastUpdate", None),

574 0x8116: (0x001f, "rASPhoneNumber", "ms-Exch-RAS-Phone-Number", 2, "PidLidTaskRecurrence", "dispidTaskRecur", None),

575 0x8117: (0x001f, "rASPhonebookEntryName", "ms-Exch-RAS-Phonebook-Entry-Name", 2, "PidLidTaskAssigners", "dispidTaskMyDelegators", None),

576 0x8118: (0x001f, "rASRemoteSRVRName", "ms-Exch-RAS-Remote-SRVR-Name", 2, None, None, None),

577 0x8119: (0x1102, "registeredAddress", "Registered-Address", 3, "PidLidTaskStatusOnComplete", "dispidTaskSOC", None),

578 0x811a: (0x001f, "remoteBridgeHead", "ms-Exch-Remote-Bridge-Head", 2, "PidLidTaskHistory", "dispidTaskHistory", None),

579 0x811b: (0x001f, "remoteBridgeHeadAddress", "ms-Exch-Remote-Bridge-Head-Address", 2, "PidLidTaskUpdates", "dispidTaskUpdates", None),

580 0x811d: (0x001f, "remoteSite", "ms-Exch-Remote-Site", 2, None, None, None),

581 0x811e: (0x0003, "replicationSensitivity", "ms-Exch-Replication-Sensitivity", 2, "PidLidTaskFCreator", "dispidTaskFCreator", None),

582 0x811f: (0x0003, "replicationStagger", "ms-Exch-Replication-Stagger", 2, "PidLidTaskOwner", "dispidTaskOwner", None),

583 0x8120: (0x000b, "reportToOriginator", "ms-Exch-Report-To-Originator", 1, "PidLidTaskMultipleRecipients", "dispidTaskMultRecips", None),

584 0x8121: (0x000b, "reportToOwner", "ms-Exch-Report-To-Owner", 1, "PidLidTaskAssigner", "dispidTaskDelegator", None),

585 0x8122: (0x0003, "reqSeq", "ms-Exch-Req-Seq", 2, "PidLidTaskLastUser", "dispidTaskLastUser", None),

586 0x8123: (0x000d, "responsibleLocalDXA", "ms-Exch-Responsible-Local-DXA", 2, "PidLidTaskOrdinal", "dispidTaskOrdinal", None),

587 0x8124: (0x001f, "ridServer", "ms-Exch-Rid-Server", 2, "PidLidTaskNoCompute", "dispidTaskNoCompute", None),

588 0x8125: (0x101f, "roleOccupant", "Role-Occupant", 3, "PidLidTaskLastDelegate", "dispidTaskLastDelegate", None),

589 0x8126: (0x101f, "routingList", "ms-Exch-Routing-List", 2, "PidLidTaskFRecurring", "dispidTaskFRecur", None),

590 0x8127: (0x0003, "rTSCheckpointSize", "ms-Exch-RTS-Checkpoint-Size", 2, "PidLidTaskRole", "dispidTaskRole", None),

591 0x8128: (0x0003, "rTSRecoveryTimeout", "ms-Exch-RTS-Recovery-Timeout", 2, None, None, None),

592 0x8129: (0x0003, "rTSWindowSize", "ms-Exch-RTS-Window-Size", 2, "PidLidTaskOwnership", "dispidTaskOwnership", None),

593 0x812a: (0x101f, "runsOn", "ms-Exch-Runs-On", 2, "PidLidTaskAcceptanceState", "dispidTaskDelegValue", None),

594 0x812b: (0x0102, "sSelector", "ms-Exch-S-Selector", 1, None, None, None),

595 0x812c: (0x0102, "sSelectorInbound", "ms-Exch-S-Selector-Inbound", 1, "PidLidTaskFFixOffline", "dispidTaskFFixOffline", None),

596 0x812d: (0x0003, "searchFlags", "Search-Flags", 3, None, None, None),

597 0x812e: (0x1102, "searchGuide", "Search-Guide", 3, None, None, None),

598 0x812f: (0x101f, "seeAlso", "See-Also", 3, None, None, None),

599 0x8130: (0x101f, "serialNumber", "Serial-Number", 3, None, None, None),

600 0x8131: (0x0003, "serviceActionFirst", "ms-Exch-Service-Action-First", 2, None, None, None),

601 0x8132: (0x0003, "serviceActionOther", "ms-Exch-Service-Action-Other", 2, None, None, None),

602 0x8133: (0x0003, "serviceActionSecond", "ms-Exch-Service-Action-Second", 2, None, None, None),

603 0x8134: (0x0003, "serviceRestartDelay", "ms-Exch-Service-Restart-Delay", 2, None, None, None),

604 0x8135: (0x001f, "serviceRestartMessage", "ms-Exch-Service-Restart-Message", 2, None, None, None),

605 0x8136: (0x0003, "sessionDisconnectTimer", "ms-Exch-Session-Disconnect-Timer", 2, None, None, None),

606 0x8138: (0x101f, "siteProxySpace", "ms-Exch-Site-Proxy-Space", 2, None, None, None),

607 0x8139: (0x0040, "spaceLastComputed", "ms-Exch-Space-Last-Computed", 2, "PidLidTaskCustomFlags", "dispidTaskCustomFlags", None),

608 0x813a: (0x001f, "street", "Street-Address", 1, None, None, None),

609 0x813b: (0x101f, "subRefs", "Sub-Refs", 1, None, None, None),

610 0x813c: (0x0003, "submissionContLength", "ms-Exch-Submission-Cont-Length", 1, None, None, None),

611 0x813d: (0x1102, "supportedApplicationContext", "Supported-Application-Context", 3, None, None, None),

612 0x813e: (0x000d, "supportingStack", "ms-Exch-Supporting-Stack", 2, None, None, None),

613 0x813f: (0x000d, "supportingStackBL", "ms-Exch-Supporting-Stack-BL", 2, None, None, None),

614 0x8140: (0x0102, "tSelector", "ms-Exch-T-Selector", 2, None, None, None),

615 0x8142: (0x101f, "targetMTAs", "ms-Exch-Target-MTAs", 2, None, None, None),

616 0x8143: (0x1102, "teletexTerminalIdentifier", "Teletex-Terminal-Identifier", 3, None, None, None),

617 0x8144: (0x0003, "tempAssocThreshold", "ms-Exch-Temp-Assoc-Threshold", 2, None, None, None),

618 0x8145: (0x0003, "tombstoneLifetime", "Tombstone-Lifetime", 3, None, None, None),

619 0x8146: (0x001f, "trackingLogPathName", "ms-Exch-Tracking-Log-Path-Name", 2, None, None, None),

620 0x8147: (0x0003, "transRetryMins", "ms-Exch-Trans-Retry-Mins", 2, None, None, None),

621 0x8148: (0x0003, "transTimeoutMins", "ms-Exch-Trans-Timeout-Mins", 2, None, None, None),

622 0x8149: (0x0003, "transferRetryInterval", "ms-Exch-Transfer-Retry-Interval", 2, None, None, None),

623 0x814a: (0x0003, "transferTimeoutNonUrgent", "ms-Exch-Transfer-Timeout-Non-Urgent", 2, None, None, None),

624 0x814b: (0x0003, "transferTimeoutNormal", "ms-Exch-Transfer-Timeout-Normal", 2, None, None, None),

625 0x814c: (0x0003, "transferTimeoutUrgent", "ms-Exch-Transfer-Timeout-Urgent", 2, None, None, None),

626 0x814d: (0x0003, "translationTableUsed", "ms-Exch-Translation-Table-Used", 2, None, None, None),

627 0x814e: (0x000b, "transportExpeditedData", "ms-Exch-Transport-Expedited-Data", 2, None, None, None),

628 0x814f: (0x0003, "trustLevel", "ms-Exch-Trust-Level", 2, None, None, None),

629 0x8150: (0x0003, "turnRequestThreshold", "ms-Exch-Turn-Request-Threshold", 2, None, None, None),

630 0x8151: (0x000b, "twoWayAlternateFacility", "ms-Exch-Two-Way-Alternate-Facility", 2, None, None, None),

631 0x8152: (0x000d, "unauthOrigBL", "ms-Exch-Unauth-Orig-BL", 1, None, None, None),

632 0x8153: (0x1102, "userPassword", "User-Password", 3, None, None, None),

633 0x8154: (0x0003, "uSNCreated", "USN-Created", 1, None, None, None),

634 0x8155: (0x0003, "uSNDSALastObjRemoved", "USN-DSA-Last-Obj-Removed", 3, None, None, None),

635 0x8156: (0x0003, "uSNLastObjRem", "USN-Last-Obj-Rem", 1, None, None, None),

636 0x8157: (0x0003, "uSNSource", "USN-Source", 3, None, None, None),

637 0x8158: (0x101f, "x121Address", "X121-Address", 3, None, None, None),

638 0x8159: (0x0102, "x25CallUserDataIncoming", "ms-Exch-X25-Call-User-Data-Incoming", 2, None, None, None),

639 0x815a: (0x0102, "x25CallUserDataOutgoing", "ms-Exch-X25-Call-User-Data-Outgoing", 2, None, None, None),

640 0x815b: (0x0102, "x25FacilitiesDataIncoming", "ms-Exch-X25-Facilities-Data-Incoming", 2, None, None, None),

641 0x815c: (0x0102, "x25FacilitiesDataOutgoing", "ms-Exch-X25-Facilities-Data-Outgoing", 2, None, None, None),

642 0x815d: (0x0102, "x25LeasedLinePort", "ms-Exch-X25-Leased-Line-Port", 2, None, None, None),

643 0x815e: (0x000b, "x25LeasedOrSwitched", "ms-Exch-X25-Leased-Or-Switched", 2, None, None, None),

644 0x815f: (0x001f, "x25RemoteMTAPhone", "ms-Exch-X25-Remote-MTA-Phone", 2, None, None, None),

645 0x8160: (0x0102, "x400AttachmentType", "ms-Exch-X400-Attachment-Type", 2, None, None, None),

646 0x8161: (0x0003, "x400SelectorSyntax", "ms-Exch-X400-Selector-Syntax", 2, None, None, None),

647 0x8163: (0x0003, "xMITTimeoutNonUrgent", "ms-Exch-XMIT-Timeout-Non-Urgent", 2, None, None, None),

648 0x8164: (0x0003, "xMITTimeoutNormal", "ms-Exch-XMIT-Timeout-Normal", 2, None, None, None),

649 0x8165: (0x0003, "xMITTimeoutUrgent", "ms-Exch-XMIT-Timeout-Urgent", 2, None, None, None),

650 0x8166: (0x0102, "siteFolderGUID", "ms-Exch-Site-Folder-GUID", 2, None, None, None),

651 0x8167: (0x001f, "siteFolderServer", "ms-Exch-Site-Folder-Server", 2, None, None, None),

652 0x8168: (0x0003, "replicationMailMsgSize", "ms-Exch-Replication-Mail-Msg-Size", 2, None, None, None),

653 0x8169: (0x0102, "maximumObjectID", "ms-Exch-Maximum-Object-ID", 2, None, None, None),

654 0x8170: (0x101f, "networkAddress", "Network-Address", 1, "PidTagAddressBookNetworkAddress", "PR_EMS_AB_NETWORK_ADDRESS", "AbNetworkAddress"),

655 0x8171: (0x001f, "lDAPDisplayName", "LDAP-Display-Name", 1, None, None, None),

656 0x8174: (0x101f, "bridgeheadServers", "ms-Exch-Bridgehead-Servers", 2, None, None, None),

657 0x8175: (0x101f, "url", "WWW-Page-Other", 1, None, None, None),

658 0x8177: (0x001f, "pOPContentFormat", "ms-Exch-POP-Content-Format", 2, None, None, None),

659 0x8178: (0x0003, "languageCode", "ms-Exch-Language", 2, None, None, None),

660 0x8179: (0x001f, "pOPCharacterSet", "ms-Exch-POP-Character-Set", 2, None, None, None),

661 0x817a: (0x0003, "USNIntersite", "USN-Intersite", 3, None, None, None),

662 0x817f: (0x0003, "enabledProtocols", "ms-Exch-Enabled-Protocols", 1, None, None, None),

663 0x8180: (0x0102, "connectionListFilter", "ms-Exch-Connection-List-Filter", 2, None, None, None),

664 0x8181: (0x101f, "availableAuthorizationPackages", "ms-Exch-Available-Authorization-Packages", 2, None, None, None),

665 0x8182: (0x101f, "characterSetList", "ms-Exch-Character-Set-List", 2, None, None, None),

666 0x8183: (0x000b, "useSiteValues", "ms-Exch-Use-Site-Values", 2, None, None, None),

667 0x8184: (0x101f, "enabledAuthorizationPackages", "ms-Exch-Enabled-Authorization-Packages", 2, None, None, None),

668 0x8185: (0x001f, "characterSet", "ms-Exch-Character-Set", 2, None, None, None),

669 0x8186: (0x0003, "contentType", "ms-Exch-Content-Type", 2, None, None, None),

670 0x8187: (0x000b, "anonymousAccess", "ms-Exch-Anonymous-Access", 2, None, None, None),

671 0x8188: (0x0102, "controlMsgFolderID", "ms-Exch-Control-Msg-Folder-ID", 2, None, None, None),

672 0x8189: (0x001f, "usenetSiteName", "ms-Exch-Usenet-Site-Name", 2, None, None, None),

673 0x818a: (0x0102, "controlMsgRules", "ms-Exch-Control-Msg-Rules", 2, None, None, None),

674 0x818b: (0x001f, "availableDistributions", "ms-Exch-Available-Distributions", 2, None, None, None),

675 0x818f: (0x0003, "outgoingMsgSizeLimit", "ms-Exch-Outgoing-Msg-Size-Limit", 2, None, None, None),

676 0x8190: (0x0003, "incomingMsgSizeLimit", "ms-Exch-Incoming-Msg-Size-Limit", 2, None, None, None),

677 0x8191: (0x000b, "sendTNEF", "ms-Exch-Send-TNEF", 2, None, None, None),

678 0x819b: (0x000b, "hTTPPubGAL", "ms-Exch-HTTP-Pub-GAL", 2, None, None, None),

679 0x819c: (0x0003, "hTTPPubGALLimit", "ms-Exch-HTTP-Pub-GAL-Limit", 2, None, None, None),

680 0x819e: (0x1102, "hTTPPubPF", "ms-Exch-HTTP-Pub-PF", 2, None, None, None),

681 0x81a1: (0x001f, "x500RDN", "ms-Exch-X500-RDN", 2, None, None, None),

682 0x81a2: (0x001f, "dnQualifier", "ms-Exch-X500-NC", 2, None, None, None),

683 0x81a3: (0x101f, "referralList", "ms-Exch-Referral-List", 2, None, None, None),

684 0x81a8: (0x000b, "enabledProtocolCfg", "ms-Exch-Enabled-Protocol-Cfg", 2, None, None, None),

685 0x81a9: (0x101f, "hTTPPubABAttributes", "ms-Exch-HTTP-Pub-AB-Attributes", 2, None, None, None),

686 0x81ab: (0x101f, "hTTPServers", "ms-Exch-HTTP-Servers", 2, None, None, None),

687 0x81b1: (0x000b, "proxyGenerationEnabled", "Proxy-Generation-Enabled", 3, None, None, None),

688 0x81b2: (0x0102, "rootNewsgroupsFolderID", "ms-Exch-Root-Newsgroups-Folder-ID", 2, None, None, None),

689 0x81b4: (0x0003, "connectionListFilterType", "ms-Exch-Connection-List-Filter-Type", 2, None, None, None),

690 0x81b5: (0x0003, "portNumber", "ms-Exch-Port-Number", 2, None, None, None),

691 0x81b6: (0x101f, "protocolSettings", "ms-Exch-Protocol-Settings", 1, None, None, None),

692 0x81c2: (0x0040, "promoExpiration", "ms-Exch-Promo-Expiration", 1, None, None, None),

693 0x81c3: (0x101f, "disabledGatewayProxy", "ms-Exch-Disabled-Gateway-Proxy", 2, None, None, None),

694 0x81c4: (0x0102, "compromisedKeyList", "ms-Exch-Compromised-Key-List", 2, None, None, None),

695 0x81c5: (0x001f, "iNSAdmin", "ms-Exch-INSAdmin", 2, None, None, None),

696 0x81c7: (0x101f, "objViewContainers", "ms-Exch-Obj-View-Containers", 2, None, None, None),

697 0x8202: (0x001f, "name", "RDN", 1, "PidLidAppointmentSequenceTime", "dispidApptSeqTime", None),

698 0x8c1c: (0x0102, "msExchMimeTypes", "ms-Exch-Mime-Types", 2, None, None, None),

699 0x8c1d: (0x0003, "lDAPSearchCfg", "ms-Exch-LDAP-Search-Cfg", 2, None, None, None),

700 0x8c21: (0x000b, "Enabled", "Enabled", 3, None, None, None),

701 0x8c22: (0x000b, "preserveInternetContent", "ms-Exch-Preserve-Internet-Content", 2, None, None, None),

702 0x8c24: (0x000b, "clientAccessEnabled", "ms-Exch-Client-Access-Enabled", 2, None, None, None),

703 0x8c25: (0x000b, "requireSSL", "ms-Exch-Require-SSL", 2, None, None, None),

704 0x8c26: (0x001f, "anonymousAccount", "ms-Exch-Anonymous-Account", 2, None, None, None),

705 0x8c27: (0x0102, "certificateChainV3", "ms-Exch-Certificate-Chain-V3", 2, None, None, None),

706 0x8c28: (0x0102, "certificateRevocationListV3", "ms-Exch-Certificate-Revocation-List-V3", 2, None, None, None),

707 0x8c29: (0x0102, "certificateRevocationListV1", "ms-Exch-Certificate-Revocation-List-V1", 2, None, None, None),

708 0x8c30: (0x1102, "crossCertificateCRL", "ms-Exch-Cross-Certificate-CRL", 2, None, None, None),

709 0x8c31: (0x000b, "sendEMailMessage", "ms-Exch-Send-EMail-Message", 2, None, None, None),

710 0x8c32: (0x000b, "enableCompatibility", "ms-Exch-Enable-Compatibility", 2, None, None, None),

711 0x8c33: (0x101f, "sMIMEAlgListNA", "ms-Exch-SMIME-Alg-List-NA", 2, None, None, None),

712 0x8c34: (0x101f, "sMIMEAlgListOther", "ms-Exch-SMIME-Alg-List-Other", 2, None, None, None),

713 0x8c35: (0x001f, "sMIMEAlgSelectedNA", "ms-Exch-SMIME-Alg-Selected-NA", 2, None, None, None),

714 0x8c36: (0x001f, "sMIMEAlgSelectedOther", "ms-Exch-SMIME-Alg-Selected-Other", 2, None, None, None),

715 0x8c37: (0x000b, "defaultMessageFormat", "ms-Exch-Default-Message-Format", 2, None, None, None),

716 0x8c38: (0x001f, "type", "ms-Exch-Type", 1, None, None, None),

717 0x8c3a: (0x0003, "doOABVersion", "ms-Exch-Do-OAB-Version", 2, None, None, None),

718 0x8c45: (0x1102, "attributeCertificate", "ms-Exch-Attribute-Certificate", 1, None, None, None),

719 0x8c46: (0x1102, "deltaRevocationList", "Delta-Revocation-List", 3, None, None, None),

720 0x8c47: (0x1102, "securityPolicy", "ms-Exch-Security-Policy", 2, None, None, None),

721 0x8c48: (0x000b, "supportSMIMESignatures", "ms-Exch-Support-SMIME-Signatures", 2, None, None, None),

722 0x8c49: (0x000b, "delegateUser", "ms-Exch-Delegate-User", 2, None, None, None),

723 0x8c50: (0x000b, "listPublicFolders", "ms-Exch-List-Public-Folders", 2, None, None, None),

724 0x8c51: (0x101f, "msExchLabeledURI", "ms-Exch-LabeledURI", 1, None, None, None),

725 0x8c52: (0x000b, "returnExactMsgSize", "ms-Exch-Return-Exact-Msg-Size", 2, None, None, None),

726 0x8c53: (0x001f, "generationQualifier", "Generation-Qualifier", 3, None, None, None),

727 0x8c54: (0x001f, "msExchHouseIdentifier", "ms-Exch-House-Identifier", 3, None, None, None),

728 0x8c55: (0x0102, "supportedAlgorithms", "ms-Exch-Supported-Algorithms", 1, None, None, None),

729 0x8c56: (0x001f, "dmdName", "DMD-Name", 3, None, None, None),

730 0x8c57: (0x001f, "extensionAttribute11", "ms-Exch-Extension-Attribute-11", 1, "PidTagAddressBookExtensionAttribute11", "PR_EMS_AB_EXTENSION_ATTRIBUTE_11", None),

731 0x8c58: (0x001f, "extensionAttribute12", "ms-Exch-Extension-Attribute-12", 1, "PidTagAddressBookExtensionAttribute12", "PR_EMS_AB_EXTENSION_ATTRIBUTE_12", None),

732 0x8c59: (0x001f, "extensionAttribute13", "ms-Exch-Extension-Attribute-13", 1, "PidTagAddressBookExtensionAttribute13", "PR_EMS_AB_EXTENSION_ATTRIBUTE_13", None),

733 0x8c60: (0x001f, "extensionAttribute14", "ms-Exch-Extension-Attribute-14", 1, "PidTagAddressBookExtensionAttribute14", "PR_EMS_AB_EXTENSION_ATTRIBUTE_14", None),

734 0x8c61: (0x001f, "extensionAttribute15", "ms-Exch-Extension-Attribute-15", 1, "PidTagAddressBookExtensionAttribute15", "PR_EMS_AB_EXTENSION_ATTRIBUTE_15", None),

735 0x8c62: (0x0003, "replicatedObjectVersion", "ms-Exch-Replicated-Object-Version", 1, None, None, None),

736 0x8c64: (0x001f, "forwardingAddress", "ms-Exch-Forwarding-Address", 2, None, None, None),

737 0x8c65: (0x0102, "formData", "ms-Exch-Form-Data", 2, None, None, None),

738 0x8c66: (0x001f, "oWAServer", "ms-Exch-OWA-Server", 2, None, None, None),

739 0x8c67: (0x001f, "employeeNumber", "Employee-Number", 3, None, None, None),

740 0x8c68: (0x001f, "personalPager", "ms-Exch-Telephone-Personal-Pager", 2, None, None, None),

741 0x8c69: (0x001f, "employeeType", "Employee-Type", 3, None, None, None),

742 0x8c6a: (0x1102, "userCertificate", "X509-Cert", 1, "PidTagAddressBookX509Certificate", "PR_EMS_AB_X509_CERT", "Certificate"),

743 0x8c6b: (0x001f, "personalTitle", "Personal-Title", 3, None, None, None),

744 0x8c6c: (0x001f, "language", "ms-Exch-Language-ISO639", 2, None, None, None),

745 0x8c6d: (0x0102, "objectGUID", "Object-Guid", 1, "PidTagAddressBookObjectGuid", "PR_EMS_AB_OBJECT_GUID", "ObjectGuid"),

746 0x8c6e: (0x101f, "otherPager", "Phone-Pager-Other", 1, None, None, None),

747 0x8c73: (0x0102, "msExchMailboxGuid", "ms-Exch-Mailbox-Guid", 1, None, None, None),

748 0x8c75: (0x0102, "msExchMasterAccountSid", "ms-Exch-Master-Account-Sid", 1, None, None, None),

749 0x8c7e: (0x001f, "msExchFBURL", "ms-Exch-FB-URL", 1, None, None, None),

750 0x8c7f: (0x001f, "msExchMailboxUrl", "ms-Exch-Mailbox-Url", 1, None, None, None),

751 0x8c81: (0x001f, "textEncodedORAddress", "Text-Encoded-OR-Address", 1, None, None, None),

752 0x8c82: (0x001f, "msExchPfRootUrl", "ms-Exch-Pf-Root-Url", 1, None, None, None),

753 0x8c8e: (0x001f, "msDS-PhoneticFirstName", "ms-DS-Phonetic-First-Name", 1, "PidTagAddressBookPhoneticGivenName", "PR_EMS_AB_PHONETIC_GIVEN_NAME", None),

754 0x8c8f: (0x001f, "msDS-PhoneticLastName", "ms-DS-Phonetic-Last-Name", 1, "PidTagAddressBookPhoneticSurname", "PR_EMS_AB_PHONETIC_SURNAME", None),

755 0x8c90: (0x001f, "msDS-PhoneticDepartment", "ms-DS-Phonetic-Department", 1, "PidTagAddressBookPhoneticDepartmentName", "PR_EMS_AB_PHONETIC_DEPARTMENT_NAME", None),

756 0x8c91: (0x001f, "msDS-PhoneticCompanyName", "ms-DS-Phonetic-Company-Name", 1, "PidTagAddressBookPhoneticCompanyName", "PR_EMS_AB_PHONETIC_COMPANY_NAME", None),

757 0x8c92: (0x001f, "msDS-PhoneticDisplayName", "ms-DS-Phonetic-Display-Name", 1, "PidTagAddressBookPhoneticDisplayName", "PR_EMS_AB_PHONETIC_DISPLAY_NAME", None),

758 0x8c94: (0x000d, "msExchHABShowInDepartments", "ms-Exch-HAB-Show-In-Departments", 1, "PidTagAddressBookHierarchicalShowInDepartments", "PR_EMS_AB_HAB_SHOW_IN_DEPARTMENTS", None),

759 0x8c96: (0x101f, "msExchResourceAddressLists", "ms-Exch-Resource-Address-Lists", 1, "PidTagAddressBookRoomContainers", "PR_EMS_AB_ROOM_CONTAINERS", "AddressBookRoomContainers"),

760 0x8c97: (0x000d, "msExchHABShowInDepartmentsBL", "ms-Exch-HAB-Show-In-Departments-BL", 2, "PidTagAddressBookHierarchicalDepartmentMembers", "PR_EMS_AB_HAB_DEPARTMENT_MEMBERS", None),

761 0x8c98: (0x000d, "msExchHABRootDepartmentLink", "ms-Exch-HAB-Root-Department-Link", 1, "PidTagAddressBookHierarchicalRootDepartment", "PR_EMS_AB_HAB_ROOT_DEPARTMENT", None),

762 0x8c99: (0x000d, "msExchHABChildDepartmentsBL", "ms-Exch-HAB-Child-Departments-BL", 2, "PidTagAddressBookHierarchicalParentDepartment", "PR_EMS_AB_HAB_PARENT_DEPARTMENT", None),

763 0x8c9a: (0x000d, "msExchHABChildDepartmentsLink", "ms-Exch-HAB-Child-Departments-Link", 2, "PidTagAddressBookHierarchicalChildDepartments", "PR_EMS_AB_HAB_CHILD_DEPARTMENTS", None),

764 0x8c9b: (0x000d, "msExchHABRootDepartmentBL", "ms-Exch-HAB-Root-Department-BL", 2, None, None, None),

765 0x8c9e: (0x0102, "thumbnailPhoto", "Picture", 1, "PidTagThumbnailPhoto", "PR_EMS_AB_THUMBNAIL_PHOTO", "ThumbnailPhoto"),

766 0x8c9f: (0x001f, "msExchUserCulture", "ms-Exch-User-Culture", 1, None, None, None),

767 0x8ca0: (0x0003, "msDS-HABSeniorityIndex", "ms-DS-HAB-Seniority-Index", 1, "PidTagAddressBookSeniorityIndex", None, None),

768 0x8ca1: (0x000b, "msExchPhoneticSupport", "ms-Exch-Phonetic-Support", 2, None, None, None),

769 0x8ca2: (0x0003, "msExchMaxSafeSenders", "ms-Exch-Max-Safe-Senders", 1, None, None, None),

770 0x8ca3: (0x0003, "msExchMaxBlockedSenders", "ms-Exch-Max-Blocked-Senders", 1, None, None, None),

771 0x8ca5: (0x000d, "msExchConfigurationUnitLink", "ms-Exch-Configuration-Unit-Link", 2, None, None, None),

772 0x8ca6: (0x000d, "msExchConfigurationUnitBL", "ms-Exch-Configuration-Unit-BL", 1, None, None, None),

773 0x8ca7: (0x001f, "msExchCU", "ms-Exch-CU", 1, None, None, None),

774 0x8ca8: (0x001f, "msExchOURoot", "ms-Exch-OU-Root", 1, "PidTagAddressBookOrganizationalUnitRootDistinguishedName", "PR_EMS_AB_ORG_UNIT_ROOT_DN", None),

775 0x8ca9: (0x0003, "msExchSenderHintsEnabled", "ms-Exch-Sender-Hints-Enabled", 2, None, None, None),

776 0x8caa: (0x0003, "msExchSenderHintLargeAudienceThreshold", "ms-Exch-Sender-Hint-Large-Audience-Threshold", 2, None, None, None),

777 0x8cac: (0x101f, "msExchSenderHintTranslations", "ms-Exch-Sender-Hint-Translations", 1, "PidTagAddressBookSenderHintTranslations", "PR_EMS_AB_DL_SENDER_HINT_TRANSLATIONS_W", None),

778 0x8cad: (0x000d, "msExchModeratedByLink", "ms-Exch-Moderated-By-Link", 1, None, None, None),

779 0x8cae: (0x000d, "msExchCoManagedByLink", "ms-Exch-Co-Managed-By-Link", 1, None, None, None),

780 0x8caf: (0x000d, "msExchModeratedObjectsBL", "ms-Exch-Moderated-Objects-BL", 1, None, None, None),

781 0x8cb0: (0x000d, "msExchCoManagedObjectsBL", "ms-Exch-Co-Managed-Objects-BL", 1, None, None, None),

782 0x8cb1: (0x001f, "msExchArbitrationMailbox", "ms-Exch-Arbitration-Mailbox", 1, None, None, None),

783 0x8cb3: (0x0003, "msExchGroupJoinRestriction", "ms-Exch-Group-Join-Restriction", 1, None, None, None),

784 0x8cb4: (0x0003, "msExchGroupDepartRestriction", "ms-Exch-Group-Depart-Restriction", 1, None, None, None),

785 0x8cb5: (0x000b, "msExchEnableModeration", "ms-Exch-Enable-Moderation", 1, "PidTagAddressBookModerationEnabled", None, None),

786 0x8cb6: (0x0003, "msExchModerationFlags", "ms-Exch-Moderation-Flags", 1, None, None, None),

787 0x8cb7: (0x101f, "msExchSignupAddresses", "ms-Exch-Signup-Addresses", 1, None, None, None),

788 0x8cc1: (0x001f, "msExchWindowsLiveID", "ms-Exch-Windows-Live-ID", 1, None, None, None),

789 0x8cc2: (0x0102, "msExchUMSpokenName", "ms-Exch-UM-Spoken-Name", 1, "PidTagSpokenName", "PR_EMS_AB_UM_SPOKEN_NAME", None),

790 0x8cc3: (0x001f, "msExchPrivacyStatementURL", "ms-Exch-Privacy-Statement-URL", 2, None, None, None),

791 0x8cc4: (0x001f, "msExchControlPanelFeedbackURL", "ms-Exch-Control-Panel-Feedback-URL", 2, None, None, None),

792 0x8cc5: (0x001f, "msExchControlPanelHelpURL", "ms-Exch-Control-Panel-Help-URL", 2, None, None, None),

793 0x8cc6: (0x000b, "msExchExchangeHelpAppOnline", "ms-Exch-Exchange-Help-App-Online", 2, None, None, None),

794 0x8cc7: (0x001f, "msExchManagementConsoleFeedbackURL", "ms-Exch-Management-Console-Feedback-URL", 2, None, None, None),

795 0x8cc8: (0x001f, "msExchManagementConsoleHelpURL", "ms-Exch-Management-Console-Help-URL", 2, None, None, None),

796 0x8cc9: (0x001f, "msExchOWAFeedbackURL", "ms-Exch-OWA-Feedback-URL", 2, None, None, None),

797 0x8cca: (0x001f, "msExchOWAHelpURL", "ms-Exch-OWA-Help-URL", 2, None, None, None),

798 0x8ccb: (0x001f, "msExchWindowsLiveAccountURL", "ms-Exch-Windows-Live-Account-URL", 2, None, None, None),

799 0x8ccc: (0x0003, "msExchTransportRecipientSettingsFlags", "ms-Exch-Transport-Recipient-Settings-Flags", 1, None, None, None),

800 0x8ccd: (0x000b, "msExchControlPanelFeedbackEnabled", "ms-Exch-Control-Panel-Feedback-Enabled", 2, None, None, None),

801 0x8cce: (0x000b, "msExchManagementConsoleFeedbackEnabled", "ms-Exch-Management-Console-Feedback-Enabled", 2, None, None, None),

802 0x8ccf: (0x000b, "msExchOWAFeedbackEnabled", "ms-Exch-OWA-Feedback-Enabled", 2, None, None, None),

803 0x8cd0: (0x000b, "msExchPrivacyStatementURLEnabled", "ms-Exch-Privacy-Statement-URL-Enabled", 2, None, None, None),

804 0x8cd1: (0x000b, "msExchWindowsLiveAccountURLEnabled", "ms-Exch-Windows-Live-Account-URL-Enabled", 2, None, None, None),

805 0x8cd2: (0x000d, "msExchBypassModerationLink", "ms-Exch-Bypass-Moderation-Link", 1, None, None, None),

806 0x8cd3: (0x000d, "msExchBypassModerationBL", "ms-Exch-Bypass-Moderation-BL", 1, None, None, None),

807 0x8cd4: (0x000d, "msExchBypassModerationFromDLMembersLink", "ms-Exch-Bypass-Moderation-From-DL-Members-Link", 1, None, None, None),

808 0x8cd5: (0x000d, "msExchBypassModerationFromDLMembersBL", "ms-Exch-Bypass-Moderation-From-DL-Members-BL", 1, None, None, None),

809 0x8cd6: (0x001f, "msExchRetentionComment", "ms-Exch-Retention-Comment", 1, None, None, None),

810 0x8cd7: (0x001f, "msExchRetentionURL", "ms-Exch-Retention-URL", 1, None, None, None),

811 0x8cd8: (0x000d, "authOrig", "ms-Exch-Auth-Orig", 1, "PidTagAddressBookAuthorizedSenders", "PR_EMS_AB_AUTH_ORIG", None),

812 0x8cd9: (0x000d, "unauthOrig", "ms-Exch-Unauth-Orig", 1, "PidTagAddressBookUnauthorizedSenders", "PR_EMS_AB_UNAUTH_ORIG", None),

813 0x8cda: (0x000d, "dLMemSubmitPerms", "ms-Exch-DL-Mem-Submit-Perms", 1, "PidTagAddressBookDistributionListMemberSubmitRejected", "PR_EMS_AB_DL_MEM_SUBMIT_PERMS", None),

814 0x8cdb: (0x000d, "dLMemRejectPerms", "ms-Exch-DL-Mem-Reject-Perms", 1, "PidTagAddressBookDistributionListRejectMessagesFromDLMembers", "PR_EMS_AB_DL_MEM_REJECT_PERMS", None),

815 0x8cdc: (0x000d, "msOrg-LeadersBL", "ms-Org-Leaders-BL", 2, None, None, None),

816 0x8cdd: (0x000b, "msOrg-IsOrganizational", "ms-Org-Is-Organizational-Group", 1, "PidTagAddressBookHierarchicalIsHierarchicalGroup", "PR_EMS_AB_HAB_IS_HIERARCHICAL_GROUP", None),

817 0x8cde: (0x000d, "msOrg-Leaders", "ms-Org-Leaders", 1, None, None, None),

818 0x8cdf: (0x001f, "msOrg-GroupSubtypeName", "ms-Org-Group-Subtype-Name", 1, None, None, None),

819 0x8ce0: (0x101f, "msOrg-OtherDisplayNames", "ms-Org-Other-Display-Names", 1, None, None, None),

820 0x8ce2: (0x0003, "msExchGroupMemberCount", "ms-Exch-Group-Member-Count", 1, "PidTagAddressBookDistributionListMemberCount", "PR_EMS_AB_DL_TOTAL_MEMBER_COUNT", None),

821 0x8ce3: (0x0003, "msExchGroupExternalMemberCount", "ms-Exch-Group-External-Member-Count", 1, "PidTagAddressBookDistributionListExternalMemberCount", "PR_EMS_AB_DL_EXTERNAL_MEMBER_COUNT", None),

822 0x8ce5: (0x000d, "msExchDelegateListLink", "ms-Exch-Delegate-List-Link", 1, None, None, None),

823 0x8ce6: (0x000d, "msExchDelegateListBL", "ms-Exch-Delegate-List-BL", 2, None, None, None),

824 0x8ce7: (0x001f, "msExchArchiveAddress", "ms-Exch-Archive-Address", 1, None, None, None),

825 0x8ce8: (0x0003, "msExchArchiveStatus", "ms-Exch-Archive-Status", 1, None, None, None),

826 0x8ce9: (0x001f, "msExchDistributionGroupNamingPolicy", "ms-Exch-Distribution-Group-Naming-Policy", 2, None, None, None),

827 0x8cea: (0x101f, "msExchDistributionGroupNameBlockedWordsList", "ms-Exch-Distribution-Group-Name-Blocked-Words-List", 2, None, None, None),

828 0x8ceb: (0x001f, "msExchDistributionGroupDefaultOU", "ms-Exch-Distribution-Group-Default-OU", 2, None, None, None),

829 0x8cec: (0x0003, "msExchAddressBookFlags", "ms-Exch-Address-Book-Flags", 1, None, None, None),

830 0x8ced: (0x001f, "msExchExtensionAttribute16", "ms-Exch-Extension-Attribute-16", 1, None, None, None),

831 0x8cee: (0x001f, "msExchExtensionAttribute17", "ms-Exch-Extension-Attribute-17", 1, None, None, None),

832 0x8cef: (0x001f, "msExchExtensionAttribute18", "ms-Exch-Extension-Attribute-18", 1, None, None, None),

833 0x8cf0: (0x001f, "msExchExtensionAttribute19", "ms-Exch-Extension-Attribute-19", 1, None, None, None),

834 0x8cf1: (0x001f, "msExchExtensionAttribute20", "ms-Exch-Extension-Attribute-20", 1, None, None, None),

835 0x8cf2: (0x001f, "msExchExtensionAttribute21", "ms-Exch-Extension-Attribute-21", 1, None, None, None),

836 0x8cf3: (0x001f, "msExchExtensionAttribute22", "ms-Exch-Extension-Attribute-22", 1, None, None, None),

837 0x8cf4: (0x001f, "msExchExtensionAttribute23", "ms-Exch-Extension-Attribute-23", 1, None, None, None),

838 0x8cf5: (0x001f, "msExchExtensionAttribute24", "ms-Exch-Extension-Attribute-24", 1, None, None, None),

839 0x8cf6: (0x001f, "msExchExtensionAttribute25", "ms-Exch-Extension-Attribute-25", 1, None, None, None),

840 0x8cf7: (0x001f, "msExchExtensionAttribute26", "ms-Exch-Extension-Attribute-26", 1, None, None, None),

841 0x8cf8: (0x001f, "msExchExtensionAttribute27", "ms-Exch-Extension-Attribute-27", 1, None, None, None),

842 0x8cf9: (0x001f, "msExchExtensionAttribute28", "ms-Exch-Extension-Attribute-28", 1, None, None, None),

843 0x8cfa: (0x001f, "msExchExtensionAttribute29", "ms-Exch-Extension-Attribute-29", 1, None, None, None),

844 0x8cfb: (0x001f, "msExchExtensionAttribute30", "ms-Exch-Extension-Attribute-30", 1, None, None, None),

845 0x8cfc: (0x001f, "msExchExtensionAttribute31", "ms-Exch-Extension-Attribute-31", 1, None, None, None),

846 0x8cfd: (0x001f, "msExchExtensionAttribute32", "ms-Exch-Extension-Attribute-32", 1, None, None, None),

847 0x8cfe: (0x001f, "msExchExtensionAttribute33", "ms-Exch-Extension-Attribute-33", 1, None, None, None),

848 0x8cff: (0x001f, "msExchExtensionAttribute34", "ms-Exch-Extension-Attribute-34", 1, None, None, None),

849 0x8d00: (0x001f, "msExchExtensionAttribute35", "ms-Exch-Extension-Attribute-35", 1, None, None, None),

850 0x8d01: (0x001f, "msExchExtensionAttribute36", "ms-Exch-Extension-Attribute-36", 1, None, None, None),

851 0x8d02: (0x001f, "msExchExtensionAttribute37", "ms-Exch-Extension-Attribute-37", 1, None, None, None),

852 0x8d03: (0x001f, "msExchExtensionAttribute38", "ms-Exch-Extension-Attribute-38", 1, None, None, None),

853 0x8d04: (0x001f, "msExchExtensionAttribute39", "ms-Exch-Extension-Attribute-39", 1, None, None, None),

854 0x8d05: (0x001f, "msExchExtensionAttribute40", "ms-Exch-Extension-Attribute-40", 1, None, None, None),

855 0x8d06: (0x001f, "msExchExtensionAttribute41", "ms-Exch-Extension-Attribute-41", 1, None, None, None),

856 0x8d07: (0x001f, "msExchExtensionAttribute42", "ms-Exch-Extension-Attribute-42", 1, None, None, None),

857 0x8d08: (0x001f, "msExchExtensionAttribute43", "ms-Exch-Extension-Attribute-43", 1, None, None, None),

858 0x8d09: (0x001f, "msExchExtensionAttribute44", "ms-Exch-Extension-Attribute-44", 1, None, None, None),

859 0x8d0a: (0x001f, "msExchExtensionAttribute45", "ms-Exch-Extension-Attribute-45", 1, None, None, None),

860 0x8d0b: (0x000d, "msExchUGMemberLink", "ms-Exch-UG-Member-Link", 1, None, None, None),

861 0x8d0c: (0x000d, "msExchUGMemberBL", "ms-Exch-UG-Member-BL", 1, None, None, None),

862 0x8d0e: (0x000d, "msExchAdministrativeUnitLink", "ms-Exch-Administrative-Unit-Link", 1, None, None, None),

863 0x8d0f: (0x0003, "msExchGroupSecurityFlags", "ms-Exch-Group-Security-Flags", 1, None, None, None),

864 0xfff8: (0x101f, "msExchTemplateRDNs", "ms-Exch-Template-RDNs", 2, None, None, None),

865# ====================

866 0x850e: (0x000b, None, None, 4, "PidLidAgingDontAgeMe", "dispidAgingDontAgeMe", None),

867 0x8238: (0x001f, None, None, 4, "PidLidAllAttendeesString", "dispidAllAttendeesString", None),

868 0x8246: (0x000b, None, None, 4, "PidLidAllowExternalCheck", "dispidAllowExternCheck", None),

869 0x8207: (0x0003, None, None, 4, "PidLidAppointmentAuxiliaryFlags", "dispidApptAuxFlags", None),

870 0x8214: (0x0003, None, None, 4, "PidLidAppointmentColor", "dispidApptColor", None),

871 0x8257: (0x000b, None, None, 4, "PidLidAppointmentCounterProposal", "dispidApptCounterProposal", None),

872 0x8213: (0x0003, None, None, 4, "PidLidAppointmentDuration", "dispidApptDuration", None),

873 0x8211: (0x0040, None, None, 4, "PidLidAppointmentEndDate", "dispidApptEndDate", None),

874 0x8210: (0x0040, None, None, 4, "PidLidAppointmentEndTime", "dispidApptEndTime", None),

875 0x820e: (0x0040, None, None, 4, "PidLidAppointmentEndWhole", "dispidApptEndWhole", None),

876 0x8203: (0x0003, None, None, 4, "PidLidAppointmentLastSequence", "dispidApptLastSequence", None),

877 0x0024: (0x001f, None, None, 4, "PidLidAppointmentMessageClass", "dispidApptMessageClass", "OriginatorReturnAddress"),

878 0x825a: (0x000b, None, None, 4, "PidLidAppointmentNotAllowPropose", "dispidApptNotAllowPropose", None),

879 0x8259: (0x0003, None, None, 4, "PidLidAppointmentProposalNumber", "dispidApptProposalNum", None),

880 0x8256: (0x0003, None, None, 4, "PidLidAppointmentProposedDuration", "dispidApptProposedDuration", None),

881 0x8251: (0x0040, None, None, 4, "PidLidAppointmentProposedEndWhole", "dispidApptProposedEndWhole", None),

882 0x8250: (0x0040, None, None, 4, "PidLidAppointmentProposedStartWhole", "dispidApptProposedStartWhole", None),

883 0x8216: (0x0102, None, None, 4, "PidLidAppointmentRecur", "dispidApptRecur", None),

884 0x8230: (0x001f, None, None, 4, "PidLidAppointmentReplyName", "dispidApptReplyName", None),

885 0x8220: (0x0040, None, None, 4, "PidLidAppointmentReplyTime", "dispidApptReplyTime", None),

886 0x8201: (0x0003, None, None, 4, "PidLidAppointmentSequence", "dispidApptSequence", None),

887 0x8212: (0x0040, None, None, 4, "PidLidAppointmentStartDate", "dispidApptStartDate", None),

888 0x820f: (0x0040, None, None, 4, "PidLidAppointmentStartTime", "dispidApptStartTime", None),

889 0x820d: (0x0040, None, None, 4, "PidLidAppointmentStartWhole", "dispidApptStartWhole", None),

890 0x8217: (0x0003, None, None, 4, "PidLidAppointmentStateFlags", "dispidApptStateFlags", None),

891 0x8215: (0x000b, None, None, 4, "PidLidAppointmentSubType", "dispidApptSubType", None),

892 0x825f: (0x0102, None, None, 4, "PidLidAppointmentTimeZoneDefinitionEndDisplay", "dispidApptTZDefEndDisplay", None),

893 0x8260: (0x0102, None, None, 4, "PidLidAppointmentTimeZoneDefinitionRecur", "dispidApptTZDefRecur", None),

894 0x825e: (0x0102, None, None, 4, "PidLidAppointmentTimeZoneDefinitionStartDisplay", "dispidApptTZDefStartDisplay", None),

895 0x825d: (0x0102, None, None, 4, "PidLidAppointmentUnsendableRecipients", "dispidApptUnsendableRecips", None),

896 0x8226: (0x0040, None, None, 4, "PidLidAppointmentUpdateTime", "dispidApptUpdateTime", None),

897 0x0001: (0x0102, None, None, 4, "PidTagTemplateData", "PR_EMS_TEMPLATE_BLOB", "AcknowledgementMode"),

898 0x823a: (0x000b, None, None, 4, "PidLidAutoFillLocation", "dispidAutoFillLocation", None),

899 0x851a: (0x0003, None, None, 4, "PidLidAutoProcessState", "dispidSniffState", None),

900 0x8244: (0x000b, None, None, 4, "PidLidAutoStartCheck", "dispidAutoStartCheck", None),

901 0x8535: (0x001f, None, None, 4, "PidLidBilling", "dispidBilling", None),

902 0x804d: (0x0102, None, None, 4, "PidLidBirthdayEventEntryId", "dispidBirthdayEventEID", None),

903 0x8205: (0x0003, None, None, 4, "PidLidBusyStatus", "dispidBusyStatus", None),

904 0x001c: (0x0003, None, None, 4, "PidLidCalendarType", "LID_CALENDAR_TYPE", None),

905 0x9000: (0x101f, None, None, 4, "PidLidCategories", "dispidCategories", None),

906 0x823c: (0x001f, None, None, 4, "PidLidCcAttendeesString", "dispidCCAttendeesString", None),

907 0x8204: (0x0003, None, None, 4, "PidLidChangeHighlight", "dispidChangeHighlight", None),

908 0x85b6: (0x001f, None, None, 4, "PidLidClassification", "dispidClassification", None),

909 0x85b7: (0x001f, None, None, 4, "PidLidClassificationDescription", "dispidClassDesc", None),

910 0x85b8: (0x001f, None, None, 4, "PidLidClassificationGuid", "dispidClassGuid", None),

911 0x85ba: (0x000b, None, None, 4, "PidLidClassificationKeep", "dispidClassKeep", None),

912 0x85b5: (0x000b, None, None, 4, "PidLidClassified", "dispidClassified", None),

913 0x0023: (0x000b, None, None, 4, "PidTagOriginatorDeliveryReportRequested", "PR_ORIGINATOR_DELIVERY_REPORT_REQUESTED", "OriginatorDeliveryReportRequested"),

914 0x0015: (0x0040, None, None, 4, "PidTagExpiryTime", "PR_EXPIRY_TIME", "ExpiryTime"),

915 0x8236: (0x0040, None, None, 4, "PidLidClipEnd", "dispidClipEnd", None),

916 0x8235: (0x0040, None, None, 4, "PidLidClipStart", "dispidClipStart", None),

917 0x8247: (0x001f, None, None, 4, "PidLidCollaborateDoc", "dispidCollaborateDoc", None),

918 0x8517: (0x0040, None, None, 4, "PidLidCommonEnd", "dispidCommonEnd", None),

919 0x8516: (0x0040, None, None, 4, "PidLidCommonStart", "dispidCommonStart", None),

920 0x8539: (0x101f, None, None, 4, "PidLidCompanies", "dispidCompanies", None),

921 0x8240: (0x000b, None, None, 4, "PidLidConferencingCheck", "dispidConfCheck", None),

922 0x8241: (0x0003, None, None, 4, "PidLidConferencingType", "dispidConfType", None),

923 0x8585: (0x0102, None, None, 4, "PidLidContactLinkEntry", "dispidContactLinkEntry", None),

924 0x8586: (0x001f, None, None, 4, "PidLidContactLinkName", "dispidContactLinkName", None),

925 0x8584: (0x0102, None, None, 4, "PidLidContactLinkSearchKey", "dispidContactLinkSearchKey", None),

926 0x853a: (0x101f, None, None, 4, "PidLidContacts", "dispidContacts", None),

927 0x8050: (0x001f, None, None, 4, "PidLidContactUserField2", "dispidContactUserField2", None),

928 0x85ca: (0x0040, None, None, 4, "PidLidConversationActionLastAppliedTime", "dispidConvActionLastAppliedTime", None),

929 0x85c8: (0x0040, None, None, 4, "PidLidConversationActionMaxDeliveryTime", "dispidConvActionMaxDeliveryTime", None),

930 0x85c6: (0x0102, None, None, 4, "PidLidConversationActionMoveFolderEid", "dispidConvActionMoveFolderEid", None),

931 0x85c7: (0x0102, None, None, 4, "PidLidConversationActionMoveStoreEid", "dispidConvActionMoveStoreEid", None),

932 0x85cb: (0x0003, None, None, 4, "PidLidConversationActionVersion", "dispidConvActionVersion", None),

933 0x85c9: (0x0003, None, None, 4, "PidLidConversationProcessed", "dispidConvExLegacyProcessedRand", None),

934 0x8552: (0x0003, None, None, 4, "PidLidCurrentVersion", "dispidCurrentVersion", None),

935 0x8554: (0x001f, None, None, 4, "PidLidCurrentVersionName", "dispidCurrentVersionName", None),

936 0x0011: (0x0002, None, None, 4, "PidLidDayInterval", "LID_DAY_INTERVAL", "DiscardReason"),

937 0x1000: (0x001f, None, None, 4, "PidTagBody", "PR_BODY", "Body"),

938 0x0009: (0x000b, None, None, 4, "PidLidDelegateMail", "LID_DELEGATE_MAIL", "ContentLength"),

939 0x8242: (0x001f, None, None, 4, "PidLidDirectory", "dispidDirectory", None),

940 0x000f: (0x0040, None, None, 4, "PidTagDeferredDeliveryTime", "PR_DEFERRED_DELIVERY_TIME", "DeferredDeliveryTime"),

941 0x0010: (0x0040, None, None, 4, "PidTagDeliverTime", "PR_DELIVER_TIME", "DeliverTime"),

942 0x8228: (0x0040, None, None, 4, "PidLidExceptionReplaceTime", "dispidExceptionReplaceTime", None),

943 0x822b: (0x000b, None, None, 4, "PidLidFExceptionalAttendees", "dispidFExceptionalAttendees", None),

944 0x8206: (0x000b, None, None, 4, "PidLidFExceptionalBody", "dispidFExceptionalBody", None),

945 0x8229: (0x000b, None, None, 4, "PidLidFInvited", "dispidFInvited", None),

946 0x8530: (0x001f, None, None, 4, "PidLidFlagRequest", "dispidRequest", None),

947 0x85c0: (0x0003, None, None, 4, "PidLidFlagString", "dispidFlagStringEnum", None),

948 0x820a: (0x000b, None, None, 4, "PidLidForwardInstance", "dispidFwrdInstance", None),

949 0x8261: (0x0102, None, None, 4, "PidLidForwardNotificationRecipients", "dispidForwardNotificationRecipients", None),

950 0x822f: (0x000b, None, None, 4, "PidLidFOthersAppointment", "dispidFOthersAppt", None),

951 0x0003: (0x0102, None, None, 4, "PidLidGlobalObjectId", "LID_GLOBAL_OBJID", "AuthorizingUsers"),

952 0x801a: (0x001f, None, None, 4, "PidLidHomeAddress", "dispidHomeAddress", None),

953 0x802b: (0x001f, None, None, 4, "PidLidHtml", "dispidHTML", None),

954 0x1001: (0x001f, None, None, 4, "PidTagReportText", "PR_REPORT_TEXT", "ReportText"),

955 0x827a: (0x0102, None, None, 4, "PidLidInboundICalStream", "InboundICalStream", None),

956 0x85b1: (0x001f, None, None, 4, "PidLidInfoPathFormName", None, None),

957 0x8224: (0x0003, None, None, 4, "PidLidIntendedBusyStatus", "dispidIntendedBusyStatus", None),

958 0x8580: (0x001f, None, None, 4, "PidLidInternetAccountName", "dispidInetAcctName", None),

959 0x8581: (0x001f, None, None, 4, "PidLidInternetAccountStamp", "dispidInetAcctStamp", None),

960 0x000a: (0x000b, None, None, 4, "PidLidIsException", "LID_IS_EXCEPTION", "ContentReturnRequested"),

961 0x0005: (0x000b, None, None, 4, "PidTagAutoForwarded", "PR_AUTO_FORWARDED", "AutoForwarded"),

962 0x0004: (0x0102, None, None, 4, "PidTagScriptData", "PR_EMS_SCRIPT_BLOB", "AutoForwardComment"),

963 0x820c: (0x1102, None, None, 4, "PidLidLinkedTaskItems", "dispidLinkedTaskItems", None),

964 0x8208: (0x001f, None, None, 4, "PidLidLocation", "dispidLocation", None),

965 0x8711: (0x000b, None, None, 4, "PidLidLogDocumentPosted", "dispidLogDocPosted", None),

966 0x870e: (0x000b, None, None, 4, "PidLidLogDocumentPrinted", "dispidLogDocPrinted", None),

967 0x8710: (0x000b, None, None, 4, "PidLidLogDocumentRouted", "dispidLogDocRouted", None),

968 0x870f: (0x000b, None, None, 4, "PidLidLogDocumentSaved", "dispidLogDocSaved", None),

969 0x8707: (0x0003, None, None, 4, "PidLidLogDuration", "dispidLogDuration", None),

970 0x8708: (0x0040, None, None, 4, "PidLidLogEnd", "dispidLogEnd", None),

971 0x870c: (0x0003, None, None, 4, "PidLidLogFlags", "dispidLogFlags", None),

972 0x8706: (0x0040, None, None, 4, "PidLidLogStart", "dispidLogStart", None),

973 0x8700: (0x001f, None, None, 4, "PidLidLogType", "dispidLogType", None),

974 0x8712: (0x001f, None, None, 4, "PidLidLogTypeDesc", "dispidLogTypeDesc", None),

975 0x0026: (0x0003, None, None, 4, "PidTagPriority", "PR_PRIORITY", "Priority"),

976 0x8209: (0x001f, None, None, 4, "PidLidMeetingWorkspaceUrl", "dispidMWSURL", None),

977 0x0013: (0x0002, None, None, 4, "PidLidMonthInterval", "LID_MONTH_INTERVAL", "DlExpansionHistory"),

978 0x1006: (0x0003, None, None, 4, "PidLidMonthOfYear", None, "RtfSyncBodyCrc"),

979 0x0017: (0x0003, None, None, 4, "PidTagImportance", "PR_IMPORTANCE", "Importance"),

980 0x8248: (0x001f, None, None, 4, "PidLidNetShowUrl", "dispidNetShowURL", None),

981 0x100b: (0x000b, None, None, 4, "PidLidNoEndDateFlag", "http://schemas.microsoft.com/mapi/fnoenddate", "IsIntegJobProgress"),

982 0x8538: (0x001f, None, None, 4, "PidLidNonSendableBcc", "dispidNonSendableBCC", None),

983 0x8537: (0x001f, None, None, 4, "PidLidNonSendableCc", "dispidNonSendableCC", None),

984 0x8536: (0x001f, None, None, 4, "PidLidNonSendableTo", "dispidNonSendableTo", None),

985 0x8545: (0x1003, None, None, 4, "PidLidNonSendBccTrackStatus", "dispidNonSendBccTrackStatus", None),

986 0x8544: (0x1003, None, None, 4, "PidLidNonSendCcTrackStatus", "dispidNonSendCcTrackStatus", None),

987 0x8543: (0x1003, None, None, 4, "PidLidNonSendToTrackStatus", "dispidNonSendToTrackStatus", None),

988 0x8b00: (0x0003, None, None, 4, "PidLidNoteColor", "dispidNoteColor", None),

989 0x8b03: (0x0003, None, None, 4, "PidLidNoteHeight", "dispidNoteHeight", None),

990 0x8b02: (0x0003, None, None, 4, "PidLidNoteWidth", "dispidNoteWidth", None),

991 0x8b04: (0x0003, None, None, 4, "PidLidNoteX", "dispidNoteX", None),

992 0x8b05: (0x0003, None, None, 4, "PidLidNoteY", "dispidNoteY", None),

993 0x1005: (0x0003, None, None, 4, "PidLidOccurrences", None, "IsIntegJobCreationTime"),

994 0x0028: (0x001f, None, None, 4, "PidLidOldLocation", "dispidOldLocation", "ProofOfSubmissionRequested"),

995 0x0018: (0x0002, None, None, 4, "PidLidOldRecurrenceType", "LID_RECUR_TYPE", "IpmId"),

996 0x002a: (0x0040, None, None, 4, "PidTagReceiptTime", "PR_RECEIPT_TIME", "ReceiptTime"),

997 0x0029: (0x000b, None, None, 4, "PidTagReadReceiptRequested", "PR_READ_RECEIPT_REQUESTED", "ReadReceiptRequested"),

998 0x8249: (0x001f, None, None, 4, "PidLidOnlinePassword", "dispidOnlinePassword", None),

999 0x0007: (0x001f, None, None, 4, "PidLidOptionalAttendees", "LID_OPTIONAL_ATTENDEES", "ContentCorrelator"),

1000 0x8243: (0x001f, None, None, 4, "PidLidOrganizerAlias", "dispidOrgAlias", None),

1001 0x8237: (0x0102, None, None, 4, "PidLidOriginalStoreEntryId", "dispidOrigStoreEid", None),

1002 0x801c: (0x001f, None, None, 4, "PidLidOtherAddress", "dispidOtherAddress", None),

1003 0x001a: (0x001f, None, None, 4, "PidTagMessageClass", "PR_MESSAGE_CLASS", "MessageClass"),

1004 0x822e: (0x001f, None, None, 4, "PidLidOwnerName", "dispidOwnerName", None),

1005 0x85e0: (0x0003, None, None, 4, "PidLidPendingStateForSiteMailboxDocument", "dispidPendingStateforTMDocument", None),

1006 0x8022: (0x0003, None, None, 4, "PidLidPostalAddressId", "dispidPostalAddressId", None),

1007 0x8904: (0x001f, None, None, 4, "PidLidPostRssChannel", "dispidPostRssChannel", None),

1008 0x8900: (0x001f, None, None, 4, "PidLidPostRssChannelLink", "dispidPostRssChannelLink", None),

1009 0x8903: (0x001f, None, None, 4, "PidLidPostRssItemGuid", "dispidPostRssItemGuid", None),

1010 0x8902: (0x0003, None, None, 4, "PidLidPostRssItemHash", "dispidPostRssItemHash", None),

1011 0x8901: (0x001f, None, None, 4, "PidLidPostRssItemLink", "dispidPostRssItemLink", None),

1012 0x8905: (0x001f, None, None, 4, "PidLidPostRssItemXml", "dispidPostRssItemXml", None),

1013 0x8906: (0x001f, None, None, 4, "PidLidPostRssSubscription", "dispidPostRssSubscription", None),

1014 0x8506: (0x000b, None, None, 4, "PidLidPrivate", "dispidPrivate", None),

1015 0x100d: (0x0003, None, None, 4, "PidLidRecurrenceDuration", None, "IsIntegJobSource"),

1016 0x8232: (0x001f, None, None, 4, "PidLidRecurrencePattern", "dispidRecurPattern", None),

1017 0x8231: (0x0003, None, None, 4, "PidLidRecurrenceType", "dispidRecurType", None),

1018 0x8223: (0x000b, None, None, 4, "PidLidRecurring", "dispidRecurring", None),

1019 0x85bd: (0x0102, None, None, 4, "PidLidReferenceEntryId", "dispidReferenceEID", None),

1020 0x8501: (0x0003, None, None, 4, "PidLidReminderDelta", "dispidReminderDelta", None),

1021 0x851f: (0x001f, None, None, 4, "PidLidReminderFileParameter", "dispidReminderFileParam", None),

1022 0x851c: (0x000b, None, None, 4, "PidLidReminderOverride", "dispidReminderOverride", None),

1023 0x851e: (0x000b, None, None, 4, "PidLidReminderPlaySound", "dispidReminderPlaySound", None),

1024 0x8503: (0x000b, None, None, 4, "PidLidReminderSet", "dispidReminderSet", None),

1025 0x8560: (0x0040, None, None, 4, "PidLidReminderSignalTime", "dispidReminderNextTime", None),

1026 0x8502: (0x0040, None, None, 4, "PidLidReminderTime", "dispidReminderTime", None),

1027 0x8505: (0x0040, None, None, 4, "PidLidReminderTimeDate", "dispidReminderTimeDate", None),

1028 0x8504: (0x0040, None, None, 4, "PidLidReminderTimeTime", "dispidReminderTimeTime", None),

1029 0x851d: (0x0003, None, None, 4, "PidLidReminderType", "dispidReminderType", None),

1030 0x8511: (0x0003, None, None, 4, "PidLidRemoteStatus", "dispidRemoteStatus", None),

1031 0x0006: (0x001f, None, None, 4, "PidLidRequiredAttendees", "LID_REQUIRED_ATTENDEES", "ContentConfidentialityAlgorithmId"),

1032 0x0008: (0x001f, None, None, 4, "PidLidResourceAttendees", "LID_RESOURCE_ATTENDEES", "ContentIdentifier"),

1033 0x8218: (0x0003, None, None, 4, "PidLidResponseStatus", "dispidResponseStatus", None),

1034 0x85cc: (0x000b, None, None, 4, "PidLidServerProcessed", "dispidExchangeProcessed", None),

1035 0x85cd: (0x0003, None, None, 4, "PidLidServerProcessingActions", "dispidExchangeProcessingAction", None),

1036 0x8a19: (0x0003, None, None, 4, "PidLidSharingAnonymity", "dispidSharingAnonymity", None),

1037 0x8a2d: (0x0102, None, None, 4, "PidLidSharingBindingEntryId", "dispidSharingBindingEid", None),

1038 0x8a51: (0x001f, None, None, 4, "PidLidSharingBrowseUrl", "dispidSharingBrowseUrl", None),

1039 0x8a17: (0x0003, None, None, 4, "PidLidSharingCapabilities", "dispidSharingCaps", None),

1040 0x8a24: (0x001f, None, None, 4, "PidLidSharingConfigurationUrl", "dispidSharingConfigUrl", None),

1041 0x8a45: (0x0040, None, None, 4, "PidLidSharingDataRangeEnd", "dispidSharingDataRangeEnd", None),

1042 0x8a44: (0x0040, None, None, 4, "PidLidSharingDataRangeStart", "dispidSharingDataRangeStart", None),

1043 0x8a2b: (0x0003, None, None, 4, "PidLidSharingDetail", "dispidSharingDetail", None),

1044 0x8a21: (0x001f, None, None, 4, "PidLidSharingExtensionXml", "dispidSharingExtXml", None),

1045 0x8a13: (0x0102, None, None, 4, "PidLidSharingFilter", "dispidSharingFilter", None),

1046 0x8a0a: (0x0003, None, None, 4, "PidLidSharingFlags", "dispidSharingFlags", None),

1047 0x8a18: (0x0003, None, None, 4, "PidLidSharingFlavor", "dispidSharingFlavor", None),

1048 0x8a15: (0x0102, None, None, 4, "PidLidSharingFolderEntryId", "dispidSharingFolderEid", None),

1049 0x8a2e: (0x0102, None, None, 4, "PidLidSharingIndexEntryId", "dispidSharingIndexEid", None),

1050 0x8a09: (0x0102, None, None, 4, "PidLidSharingInitiatorEntryId", "dispidSharingInitiatorEid", None),

1051 0x8a07: (0x001f, None, None, 4, "PidLidSharingInitiatorName", "dispidSharingInitiatorName", None),

1052 0x8a08: (0x001f, None, None, 4, "PidLidSharingInitiatorSmtp", "dispidSharingInitiatorSmtp", None),

1053 0x8a1c: (0x0102, None, None, 4, "PidLidSharingInstanceGuid", "dispidSharingInstanceGuid", None),

1054 0x8a55: (0x0040, None, None, 4, "PidLidSharingLastAutoSyncTime", "dispidSharingLastAutoSync", None),

1055 0x8a1f: (0x0040, None, None, 4, "PidLidSharingLastSyncTime", "dispidSharingLastSync", None),

1056 0x8a4d: (0x001f, None, None, 4, "PidLidSharingLocalComment", "dispidSharingLocalComment", None),

1057 0x8a23: (0x0040, None, None, 4, "PidLidSharingLocalLastModificationTime", "dispidSharingLocalLastMod", None),

1058 0x8a0f: (0x001f, None, None, 4, "PidLidSharingLocalName", "dispidSharingLocalName", None),

1059 0x8a0e: (0x001f, None, None, 4, "PidLidSharingLocalPath", "dispidSharingLocalPath", None),

1060 0x8a49: (0x001f, None, None, 4, "PidLidSharingLocalStoreUid", "dispidSharingLocalStoreUid", None),

1061 0x8a14: (0x001f, None, None, 4, "PidLidSharingLocalType", "dispidSharingLocalType", None),

1062 0x8a10: (0x001f, None, None, 4, "PidLidSharingLocalUid", "dispidSharingLocalUid", None),

1063 0x8a29: (0x0102, None, None, 4, "PidLidSharingOriginalMessageEntryId", "dispidSharingOriginalMessageEid", None),

1064 0x8a5c: (0x0102, None, None, 4, "PidLidSharingParentBindingEntryId", "dispidSharingParentBindingEid", None),

1065 0x8a1e: (0x001f, None, None, 4, "PidLidSharingParticipants", "dispidSharingParticipants", None),

1066 0x8a1b: (0x0003, None, None, 4, "PidLidSharingPermissions", "dispidSharingPermissions", None),

1067 0x8a0b: (0x001f, None, None, 4, "PidLidSharingProviderExtension", "dispidSharingProviderExtension", None),

1068 0x8a01: (0x0102, None, None, 4, "PidLidSharingProviderGuid", "dispidSharingProviderGuid", None),

1069 0x8a02: (0x001f, None, None, 4, "PidLidSharingProviderName", "dispidSharingProviderName", None),

1070 0x8a03: (0x001f, None, None, 4, "PidLidSharingProviderUrl", "dispidSharingProviderUrl", None),

1071 0x8a47: (0x0003, None, None, 4, "PidLidSharingRangeEnd", "dispidSharingRangeEnd", None),

1072 0x8a46: (0x0003, None, None, 4, "PidLidSharingRangeStart", "dispidSharingRangeStart", None),

1073 0x8a1a: (0x0003, None, None, 4, "PidLidSharingReciprocation", "dispidSharingReciprocation", None),

1074 0x8a4b: (0x0003, None, None, 4, "PidLidSharingRemoteByteSize", "dispidSharingRemoteByteSize", None),

1075 0x8a2f: (0x001f, None, None, 4, "PidLidSharingRemoteComment", "dispidSharingRemoteComment", None),

1076 0x8a4c: (0x0003, None, None, 4, "PidLidSharingRemoteCrc", "dispidSharingRemoteCrc", None),

1077 0x8a22: (0x0040, None, None, 4, "PidLidSharingRemoteLastModificationTime", "dispidSharingRemoteLastMod", None),

1078 0x8a4f: (0x0003, None, None, 4, "PidLidSharingRemoteMessageCount", "dispidSharingRemoteMsgCount", None),

1079 0x8a05: (0x001f, None, None, 4, "PidLidSharingRemoteName", "dispidSharingRemoteName", None),

1080 0x8a0d: (0x001f, None, None, 4, "PidLidSharingRemotePass", "dispidSharingRemotePass", None),

1081 0x8a04: (0x001f, None, None, 4, "PidLidSharingRemotePath", "dispidSharingRemotePath", None),

1082 0x8a48: (0x001f, None, None, 4, "PidLidSharingRemoteStoreUid", "dispidSharingRemoteStoreUid", None),

1083 0x8a1d: (0x001f, None, None, 4, "PidLidSharingRemoteType", "dispidSharingRemoteType", None),

1084 0x8a06: (0x001f, None, None, 4, "PidLidSharingRemoteUid", "dispidSharingRemoteUid", None),

1085 0x8a0c: (0x001f, None, None, 4, "PidLidSharingRemoteUser", "dispidSharingRemoteUser", None),

1086 0x8a5b: (0x001f, None, None, 4, "PidLidSharingRemoteVersion", "dispidSharingRemoteVersion", None),

1087 0x8a28: (0x0040, None, None, 4, "PidLidSharingResponseTime", "dispidSharingResponseTime", None),

1088 0x8a27: (0x0003, None, None, 4, "PidLidSharingResponseType", "dispidSharingResponseType", None),

1089 0x8a4e: (0x0003, None, None, 4, "PidLidSharingRoamLog", "dispidSharingRoamLog", None),

1090 0x8a25: (0x0040, None, None, 4, "PidLidSharingStart", "dispidSharingStart", None),

1091 0x8a00: (0x0003, None, None, 4, "PidLidSharingStatus", "dispidSharingStatus", None),

1092 0x8a26: (0x0040, None, None, 4, "PidLidSharingStop", "dispidSharingStop", None),

1093 0x8a60: (0x0003, None, None, 4, "PidLidSharingSyncFlags", "dispidSharingSyncFlags", None),

1094 0x8a2a: (0x0003, None, None, 4, "PidLidSharingSyncInterval", "dispidSharingSyncInterval", None),

1095 0x8a2c: (0x0003, None, None, 4, "PidLidSharingTimeToLive", "dispidSharingTimeToLive", None),

1096 0x8a56: (0x0003, None, None, 4, "PidLidSharingTimeToLiveAuto", "dispidSharingTimeToLiveAuto", None),

1097 0x8a42: (0x0003, None, None, 4, "PidLidSharingWorkingHoursDays", "dispidSharingWorkingHoursDays", None),

1098 0x8a41: (0x0040, None, None, 4, "PidLidSharingWorkingHoursEnd", "dispidSharingWorkingHoursEnd", None),

1099 0x8a40: (0x0040, None, None, 4, "PidLidSharingWorkingHoursStart", "dispidSharingWorkingHoursStart", None),

1100 0x8a43: (0x0102, None, None, 4, "PidLidSharingWorkingHoursTimeZone", "dispidSharingWorkingHoursTZ", None),

1101 0x8510: (0x0003, None, None, 4, "PidLidSideEffects", "dispidSideEffects", None),

1102 0x827b: (0x000b, None, None, 4, "PidLidSingleBodyICal", "IsSingleBodyICal", None),

1103 0x8514: (0x000b, None, None, 4, "PidLidSmartNoAttach", "dispidSmartNoAttach", None),

1104 0x859c: (0x0102, None, None, 4, "PidLidSpamOriginalFolder", "dispidSpamOriginalFolder", None),

1105 0x000d: (0x0003, None, None, 4, "PidLidStartRecurrenceDate", "LID_START_RECUR_DATE", "ConversionWithLossProhibited"),

1106 0x000e: (0x0003, None, None, 4, "PidLidStartRecurrenceTime", "LID_START_RECUR_TIME", "ConvertedEits"),

1107 0x811c: (0x000b, None, None, 4, "PidLidTaskComplete", "dispidTaskComplete", None),

1108 0x8519: (0x0102, None, None, 4, "PidLidTaskGlobalId", "dispidTaskGlobalObjId", None),

1109 0x8518: (0x0003, None, None, 4, "PidLidTaskMode", "dispidTaskMode", None),

1110 0x000c: (0x0003, None, None, 4, "PidLidTimeZone", "LID_TIME_ZONE", "ConversionEits"),

1111 0x8234: (0x001f, None, None, 4, "PidLidTimeZoneDescription", "dispidTimeZoneDesc", None),

1112 0x8233: (0x0102, None, None, 4, "PidLidTimeZoneStruct", "dispidTimeZoneStruct", None),

1113 0x823b: (0x001f, None, None, 4, "PidLidToAttendeesString", "dispidToAttendeesString", None),

1114 0x85a0: (0x0040, None, None, 4, "PidLidToDoOrdinalDate", "dispidToDoOrdinalDate", None),

1115 0x85a1: (0x001f, None, None, 4, "PidLidToDoSubOrdinal", "dispidToDoSubOrdinal", None),

1116 0x85a4: (0x001f, None, None, 4, "PidLidToDoTitle", "dispidToDoTitle", None),

1117 0x8582: (0x000b, None, None, 4, "PidLidUseTnef", "dispidUseTNEF", None),

1118 0x85bf: (0x0040, None, None, 4, "PidLidValidFlagStringProof", "dispidValidFlagStringProof", None),

1119 0x8524: (0x001f, None, None, 4, "PidLidVerbResponse", "dispidVerbResponse", None),

1120 0x8520: (0x0102, None, None, 4, "PidLidVerbStream", "dispidVerbStream", None),

1121 0x0012: (0x0002, None, None, 4, "PidLidWeekInterval", "LID_WEEK_INTERVAL", "DisclosureOfRecipients"),

1122 0x0002: (0x000b, None, None, 4, "PidTagAlternateRecipientAllowed", "PR_ALTERNATE_RECIPIENT_ALLOWED", "AlternateRecipientAllowed"),

1123 0x801b: (0x001f, None, None, 4, "PidLidWorkAddress", "dispidWorkAddress", None),

1124 0x0014: (0x0002, None, None, 4, "PidLidYearInterval", "LID_YEAR_INTERVAL", "DlExpansionProhibited"),

1125 0x802c: (0x001f, None, None, 4, "PidLidYomiFirstName", "dispidYomiFirstName", None),

1126 0x0ff4: (0x0003, None, None, 4, "PidTagAccess", "PR_ACCESS", "Access"),

1127 0x3fe0: (0x0102, None, None, 4, "PidTagAccessControlListData", "PR_ACL_DATA", "AclTable"),

1128 0x0ff7: (0x0003, None, None, 4, "PidTagAccessLevel", "PR_ACCESS_LEVEL", "AccessLevel"),

1129 0x36d8: (0x1102, None, None, 4, "PidTagAdditionalRenEntryIds", "PR_ADDITIONAL_REN_ENTRYIDS", "AdditionalRenEntryIds"),

1130 0x36d9: (0x0102, None, None, 4, "PidTagAdditionalRenEntryIdsEx", "PR_ADDITIONAL_REN_ENTRYIDS_EX", "AdditionalRenEntryIdsEx"),

1131 0xfffd: (0x0003, None, None, 4, "PidTagAddressBookContainerId", "PR_EMS_AB_CONTAINERID", "AbContainerId"),

1132 0x8c93: (0x0003, None, None, 4, "PidTagAddressBookDisplayTypeExtended", "PR_EMS_AB_DISPLAY_TYPE_EX", None),

1133 0x663b: (0x0102, None, None, 4, "PidTagAddressBookEntryId", "PR_ADDRESS_BOOK_ENTRYID", "AddressBookEntryId"),

1134 0xfffb: (0x000b, None, None, 4, "PidTagAddressBookIsMaster", "PR_EMS_AB_IS_MASTER", "AbIsMaster"),

1135 0x6704: (0x000d, None, None, 4, "PidTagAddressBookManageDistributionList", "PR_EMS_AB_MANAGE_DL", "ClientVersion"),

1136 0x674f: (0x0014, None, None, 4, "PidTagAddressBookMessageId", "ptagAddrbookMID", None),

1137 0xfffc: (0x0102, None, None, 4, "PidTagAddressBookParentEntryId", "PR_EMS_AB_PARENT_ENTRYID", "AbParentEntryId"),

1138 0x3002: (0x001f, None, None, 4, "PidTagAddressType", "PR_ADDRTYPE", "AddrType"),

1139 0x360c: (0x001f, None, None, 4, "PidTagAnr", "PR_ANR", "Anr"),

1140 0x301f: (0x0040, None, None, 4, "PidTagArchiveDate", "PR_ARCHIVE_DATE", "ArchiveDate"),

1141 0x301e: (0x0003, None, None, 4, "PidTagArchivePeriod", "PR_ARCHIVE_PERIOD", "ArchivePeriod"),

1142 0x3018: (0x0102, None, None, 4, "PidTagArchiveTag", "PR_ARCHIVE_TAG", "ArchiveTag"),

1143 0x67aa: (0x000b, None, None, 4, "PidTagAssociated", "ptagAssociated", "Associated"),

1144 0x370f: (0x0102, None, None, 4, "PidTagAttachAdditionalInformation", "PR_ATTACH_ADDITIONAL_INFO", "AttachAdditionalInfo"),

1145 0x3711: (0x001f, None, None, 4, "PidTagAttachContentBase", None, "AttachmentContentBase"),

1146 0x3712: (0x001f, None, None, 4, "PidTagAttachContentId", "PR_ATTACH_CONTENT_ID", "AttachmentContentId"),

1147 0x3713: (0x001f, None, None, 4, "PidTagAttachContentLocation", "PR_ATTACH_CONTENT_LOCATION", "AttachContentLocation"),

1148 0x3701: (0x000d, None, None, 4, "PidTagAttachDataObject", "PR_ATTACH_DATA_OBJ", "AttachDataObj"),

1149 0x3702: (0x0102, None, None, 4, "PidTagAttachEncoding", "PR_ATTACH_ENCODING", "AttachEncoding"),

1150 0x3703: (0x001f, None, None, 4, "PidTagAttachExtension", "PR_ATTACH_EXTENSION", "AttachExtension"),

1151 0x3704: (0x001f, None, None, 4, "PidTagAttachFilename", "PR_ATTACH_FILENAME", "AttachFileName"),

1152 0x3714: (0x0003, None, None, 4, "PidTagAttachFlags", "PR_ATTACH_FLAGS", "AttachFlags"),

1153 0x3707: (0x001f, None, None, 4, "PidTagAttachLongFilename", "PR_ATTACH_LONG_FILENAME", "AttachLongFileName"),

1154 0x370d: (0x001f, None, None, 4, "PidTagAttachLongPathname", "PR_ATTACH_LONG_PATHNAME", "AttachLongPathName"),

1155 0x7fff: (0x000b, None, None, 4, "PidTagAttachmentContactPhoto", "PR_ATTACHMENT_CONTACTPHOTO", "IsContactPhoto"),

1156 0x7ffd: (0x0003, None, None, 4, "PidTagAttachmentFlags", "PR_ATTACHMENT_FLAGS", "AttachmentCalendarFlags"),

1157 0x7ffe: (0x000b, None, None, 4, "PidTagAttachmentHidden", "PR_ATTACHMENT_HIDDEN", "AttachmentCalendarHidden"),

1158 0x7ffa: (0x0003, None, None, 4, "PidTagAttachmentLinkId", "PR_ATTACHMENT_LINKID", "AttachmentCalendarLinkId"),

1159 0x3705: (0x0003, None, None, 4, "PidTagAttachMethod", "PR_ATTACH_METHOD", "AttachMethod"),

1160 0x370e: (0x001f, None, None, 4, "PidTagAttachMimeTag", "PR_ATTACH_MIME_TAG", "AttachMimeTag"),

1161 0x0e21: (0x0003, None, None, 4, "PidTagAttachNumber", "PR_ATTACH_NUM", "AttachNum"),

1162 0x3708: (0x001f, None, None, 4, "PidTagAttachPathname", "PR_ATTACH_PATHNAME", "AttachPathName"),

1163 0x371a: (0x001f, None, None, 4, "PidTagAttachPayloadClass", "PR_ATTACH_PAYLOAD_CLASS", "AttachmentPayloadClass"),

1164 0x3719: (0x001f, None, None, 4, "PidTagAttachPayloadProviderGuidString", "PR_ATTACH_PAYLOAD_PROV_GUID_STR", "AttachmentPayloadProviderGuidString"),

1165 0x3709: (0x0102, None, None, 4, "PidTagAttachRendering", "PR_ATTACH_RENDERING", "AttachRendering"),

1166 0x0e20: (0x0003, None, None, 4, "PidTagAttachSize", "PR_ATTACH_SIZE", "AttachSize"),

1167 0x370a: (0x0102, None, None, 4, "PidTagAttachTag", "PR_ATTACH_TAG", "AttachTag"),

1168 0x370c: (0x001f, None, None, 4, "PidTagAttachTransportName", "PR_ATTACH_TRANSPORT_NAME", "AttachTransportName"),

1169 0x10f4: (0x000b, None, None, 4, "PidTagAttributeHidden", "PR_ATTR_HIDDEN", "AttrHidden"),

1170 0x10f6: (0x000b, None, None, 4, "PidTagAttributeReadOnly", "PR_ATTR_READONLY", "AttrReadOnly"),

1171 0x3fdf: (0x0003, None, None, 4, "PidTagAutoResponseSuppress", "PR_AUTO_RESPONSE_SUPPRESS", "AutoResponseSuppress"),

1172 0x3a42: (0x0040, None, None, 4, "PidTagBirthday", "PR_BIRTHDAY", "Birthday"),

1173 0x1096: (0x0003, None, None, 4, "PidTagBlockStatus", "PR_BLOCK_STATUS", "BlockStatus"),

1174 0x1015: (0x001f, None, None, 4, "PidTagBodyContentId", "PR_BODY_CONTENT_ID", "BodyContentId"),

1175 0x1014: (0x001f, None, None, 4, "PidTagBodyContentLocation", "PR_BODY_CONTENT_LOCATION", "BodyContentLocation"),

1176 0x1013: (0x0102, None, None, 4, "PidTagHtml", "PR_HTML", "BodyHtml"),

1177 0x3a24: (0x001f, None, None, 4, "PidTagBusinessFaxNumber", "PR_BUSINESS_FAX_NUMBER", "BusinessFaxNumber"),

1178 0x3a51: (0x001f, None, None, 4, "PidTagBusinessHomePage", "PR_BUSINESS_HOME_PAGE", "BusinessHomePage"),

1179 0x3a02: (0x001f, None, None, 4, "PidTagCallbackTelephoneNumber", "PR_CALLBACK_TELEPHONE_NUMBER", "CallbackTelephoneNumber"),

1180 0x6806: (0x001f, None, None, 4, "PidTagCallId", "InternalSchemaCallID", "MailboxMiscFlags"),

1181 0x3a1e: (0x001f, None, None, 4, "PidTagCarTelephoneNumber", "PR_CAR_TELEPHONE_NUMBER", "CarTelephoneNumber"),

1182 0x10c5: (0x0040, None, None, 4, "PidTagCdoRecurrenceid", "PR_CDO_RECURRENCEID", None),

1183 0x65e2: (0x0102, None, None, 4, "PidTagChangeKey", "PR_CHANGE_KEY", "ChangeKey"),

1184 0x67a4: (0x0014, None, None, 4, "PidTagChangeNumber", "ptagCn", "Cn"),

1185 0x3a58: (0x101f, None, None, 4, "PidTagChildrensNames", "PR_CHILDRENS_NAMES", "ChildrensNames"),

1186 0x6645: (0x0102, None, None, 4, "PidTagClientActions", "PR_CLIENT_ACTIONS", "PromotedProperties"),

1187 0x0039: (0x0040, None, None, 4, "PidTagClientSubmitTime", "PR_CLIENT_SUBMIT_TIME", "ClientSubmitTime"),

1188 0x66c3: (0x0003, None, None, 4, "PidTagCodePageId", "PR_CODE_PAGE_ID", "CodePageId"),

1189 0x3a57: (0x001f, None, None, 4, "PidTagCompanyMainTelephoneNumber", "PR_COMPANY_MAIN_PHONE_NUMBER", "CompanyMainPhoneNumber"),

1190 0x3a49: (0x001f, None, None, 4, "PidTagComputerNetworkName", "PR_COMPUTER_NETWORK_NAME", "ComputerNetworkName"),

1191 0x3ff0: (0x0102, None, None, 4, "PidTagConflictEntryId", "PR_CONFLICT_ENTRYID", "BackfillTimeout"),

1192 0x3613: (0x001f, None, None, 4, "PidTagContainerClass", "PR_CONTAINER_CLASS", "ContainerClass"),

1193 0x360f: (0x000d, None, None, 4, "PidTagContainerContents", "PR_CONTAINER_CONTENTS", "ContainerContents"),

1194 0x3600: (0x0003, None, None, 4, "PidTagContainerFlags", "PR_CONTAINER_FLAGS", "ContainerFlags"),

1195 0x360e: (0x000d, None, None, 4, "PidTagContainerHierarchy", "PR_CONTAINER_HIERARCHY", "ContainerHierarchy"),

1196 0x3602: (0x0003, None, None, 4, "PidTagContentCount", "PR_CONTENT_COUNT", "ContentCount"),

1197 0x4076: (0x0003, None, None, 4, "PidTagContentFilterSpamConfidenceLevel", "PR_CONTENT_FILTER_SCL", "SpamConfidenceLevel"),

1198 0x3603: (0x0003, None, None, 4, "PidTagContentUnreadCount", "PR_CONTENT_UNREAD", "ContentUnread"),

1199 0x3013: (0x0102, None, None, 4, "PidTagConversationId", "PR_CONVERSATION_ID", "ConversationId"),

1200 0x0071: (0x0102, None, None, 4, "PidTagConversationIndex", "PR_CONVERSATION_INDEX", "ConversationIndex"),

1201 0x3016: (0x000b, None, None, 4, "PidTagConversationIndexTracking", "PR_CONVERSATION_INDEX_TRACKING", "ConversationIndexTracking"),

1202 0x0070: (0x001f, None, None, 4, "PidTagConversationTopic", "PR_CONVERSATION_TOPIC", "ConversationTopic"),

1203 0x3ff9: (0x0102, None, None, 4, "PidTagCreatorEntryId", "PR_CREATOR_ENTRYID", "CreatorEntryId"),

1204 0x3ff8: (0x001f, None, None, 4, "PidTagCreatorName", "PR_CREATOR_NAME", "CreatorName"),

1205 0x3a4a: (0x001f, None, None, 4, "PidTagCustomerId", "PR_CUSTOMER_ID", "CustomerId"),

1206 0x6647: (0x000b, None, None, 4, "PidTagDamBackPatched", "PR_DAM_BACK_PATCHED", "DeferredActionMessageBackPatched"),

1207 0x6646: (0x0102, None, None, 4, "PidTagDamOriginalEntryId", "PR_DAM_ORIGINAL_ENTRYID", "HiddenPromotedProperties"),

1208 0x36e5: (0x001f, None, None, 4, "PidTagDefaultPostMessageClass", "PR_DEF_POST_MSGCLASS", "DefaultPostMsgClass"),

1209 0x6741: (0x00fb, None, None, 4, "PidTagDeferredActionMessageOriginalEntryId", "PR_DAM_ORIG_MSG_SVREID", "OriginalMessageSvrEId"),

1210 0x3feb: (0x0003, None, None, 4, "PidTagDeferredSendNumber", "PR_DEFERRED_SEND_NUMBER", "DeferredSendNumber"),

1211 0x3fef: (0x0040, None, None, 4, "PidTagDeferredSendTime", "PR_DEFERRED_SEND_TIME", "DeferredSendTime"),

1212 0x3fec: (0x0003, None, None, 4, "PidTagDeferredSendUnits", "PR_DEFERRED_SEND_UNITS", "DeferredSendUnits"),

1213 0x3fe3: (0x000b, None, None, 4, "PidTagDelegatedByRule", "PR_DELEGATED_BY_RULE", "OofHistory"),

1214 0x686b: (0x1003, None, None, 4, "PidTagDelegateFlags", "PR_DELEGATE_FLAGS", "DelegateFlags"),

1215 0x0e01: (0x000b, None, None, 4, "PidTagDeleteAfterSubmit", "PR_DELETE_AFTER_SUBMIT", "DeleteAfterSubmit"),

1216 0x670b: (0x0003, None, None, 4, "PidTagDeletedCountTotal", "PR_DELETED_COUNT_TOTAL", "DeletedCountTotal"),

1217 0x668f: (0x0040, None, None, 4, "PidTagDeletedOn", "PR_DELETED_ON", "DeletedOn"),

1218 0x3005: (0x0003, None, None, 4, "PidTagDepth", "PR_DEPTH", "Depth"),

1219 0x0e02: (0x001f, None, None, 4, "PidTagDisplayBcc", "PR_DISPLAY_BCC", "DisplayBcc"),

1220 0x0e03: (0x001f, None, None, 4, "PidTagDisplayCc", "PR_DISPLAY_CC", "DisplayCc"),

1221 0x3001: (0x001f, None, None, 4, "PidTagDisplayName", "PR_DISPLAY_NAME", "DisplayName"),

1222 0x3a45: (0x001f, None, None, 4, "PidTagDisplayNamePrefix", "PR_DISPLAY_NAME_PREFIX", "DisplayNamePrefix"),

1223 0x0e04: (0x001f, None, None, 4, "PidTagDisplayTo", "PR_DISPLAY_TO", "DisplayTo"),

1224 0x3900: (0x0003, None, None, 4, "PidTagDisplayType", "PR_DISPLAY_TYPE", "DisplayType"),

1225 0x3003: (0x001f, None, None, 4, "PidTagEmailAddress", "PR_EMAIL_ADDRESS", "EmailAddress"),

1226 0x0061: (0x0040, None, None, 4, "PidTagEndDate", "PR_END_DATE", "EndDate"),

1227 0x0fff: (0x0102, None, None, 4, "PidTagEntryId", "PR_ENTRYID", "EntryId"),

1228 0x7ffc: (0x0040, None, None, 4, "PidTagExceptionEndTime", "PR_EXCEPTION_ENDTIME", "AppointmentExceptionEndTime"),

1229 0x7ff9: (0x0040, None, None, 4, "PidTagExceptionReplaceTime", "PR_EXCEPTION_REPLACETIME", "SExceptionReplaceTime"),

1230 0x7ffb: (0x0040, None, None, 4, "PidTagExceptionStartTime", "PR_EXCEPTION_STARTTIME", "AppointmentExceptionStartTime"),

1231 0x0e84: (0x0102, None, None, 4, "PidTagExchangeNTSecurityDescriptor", "http://schemas.microsoft.com/exchange/ntsecuritydescriptor", None),

1232 0x3fed: (0x0003, None, None, 4, "PidTagExpiryNumber", "PR_EXPIRY_NUMBER", "ExpiryNumber"),

1233 0x3fee: (0x0003, None, None, 4, "PidTagExpiryUnits", "PR_EXPIRY_UNITS", "ExpiryUnits"),

1234 0x36da: (0x0102, None, None, 4, "PidTagExtendedFolderFlags", "PR_EXTENDED_FOLDER_FLAGS", "ExtendedFolderFlags"),

1235 0x0e99: (0x0102, None, None, 4, "PidTagExtendedRuleMessageActions", "PR_EXTENDED_RULE_MSG_ACTIONS", "ExtendedRuleActions"),

1236 0x0e9a: (0x0102, None, None, 4, "PidTagExtendedRuleMessageCondition", "PR_EXTENDED_RULE_MSG_CONDITION", "ExtendedRuleCondition"),

1237 0x0e9b: (0x0003, None, None, 4, "PidTagExtendedRuleSizeLimit", "PR_EXTENDED_RULE_SIZE_LIMIT", "ExtendedRuleSizeLimit"),

1238 0x6804: (0x001e, None, None, 4, "PidTagOfflineAddressBookDistinguishedName", "PR_OAB_DN", "ShutoffQuota"),

1239 0x1091: (0x0040, None, None, 4, "PidTagFlagCompleteTime", "PR_FLAG_COMPLETE_TIME", "FlagCompleteTime"),

1240 0x1090: (0x0003, None, None, 4, "PidTagFlagStatus", "PR_FLAG_STATUS", "FlagStatus"),

1241 0x670e: (0x001f, None, None, 4, "PidTagFlatUrlName", "PR_FLAT_URL_NAME", None),

1242 0x3610: (0x000d, None, None, 4, "PidTagFolderAssociatedContents", "PR_FOLDER_ASSOCIATED_CONTENTS", "FolderAssociatedContents"),

1243 0x6748: (0x0014, None, None, 4, "PidTagFolderId", "ptagFID", "Fid"),

1244 0x66a8: (0x0003, None, None, 4, "PidTagFolderFlags", "PR_FOLDER_FLAGS", "FolderFlags"),

1245 0x3601: (0x0003, None, None, 4, "PidTagFolderType", "PR_FOLDER_TYPE", "FolderType"),

1246 0x1095: (0x0003, None, None, 4, "PidTagFollowupIcon", "PR_FOLLOWUP_ICON", "FollowupIcon"),

1247 0x6869: (0x0003, None, None, 4, "PidTagFreeBusyCountMonths", "PR_FREEBUSY_COUNT_MONTHS", "OutlookFreeBusyMonthCount"),

1248 0x36e4: (0x1102, None, None, 4, "PidTagFreeBusyEntryIds", "PR_FREEBUSY_ENTRYIDS", "FreeBusyEntryIds"),

1249 0x6849: (0x0003, None, None, 4, "PidTagWlinkType", None, "ScheduleInfoRecipientLegacyDn"),

1250 0x6848: (0x0003, None, None, 4, "PidTagSearchFolderEfpFlags", "PR_WB_SF_EFP_FLAGS", "AssociatedSearchFolderFlags"),

1251 0x6847: (0x0003, None, None, 4, "PidTagWlinkSaveStamp", None, "AssociatedSearchFolderTag"),

1252 0x6868: (0x0040, None, None, 4, "PidTagFreeBusyRangeTimestamp", "PR_FREEBUSY_RANGE_TIMESTAMP", None),

1253 0x3a4c: (0x001f, None, None, 4, "PidTagFtpSite", "PR_FTP_SITE", "FtpSite"),

1254 0x6846: (0x0003, None, None, 4, "PidTagSearchFolderStorageType", "PR_WB_SF_STORAGE_TYPE", "AssociatedSearchFolderStorageType"),

1255 0x3a4d: (0x0002, None, None, 4, "PidTagGender", "PR_GENDER", "Gender"),

1256 0x3a05: (0x001f, None, None, 4, "PidTagGeneration", "PR_GENERATION", "Generation"),

1257 0x3a07: (0x001f, None, None, 4, "PidTagGovernmentIdNumber", "PR_GOVERNMENT_ID_NUMBER", "GovernmentIdNumber"),

1258 0x0e1b: (0x000b, None, None, 4, "PidTagHasAttachments", "PR_HASATTACH", "Hasattach"),

1259 0x3fea: (0x000b, None, None, 4, "PidTagHasDeferredActionMessages", "PR_HAS_DAMS", "HasDeferredActionMessage"),

1260 0x664a: (0x000b, None, None, 4, "PidTagHasNamedProperties", "PR_HAS_NAMED_PROPERTIES", "HasNamedProperties"),

1261 0x663a: (0x000b, None, None, 4, "PidTagHasRules", "PR_HAS_RULES", "HasRules"),

1262 0x663e: (0x0003, None, None, 4, "PidTagHierarchyChangeNumber", "PR_HIERARCHY_CHANGE_NUM", "HierarchyChangeNumber"),

1263 0x4082: (0x0040, None, None, 4, "PidTagHierRev", "PR_HIER_REV", "HierRev"),

1264 0x3a43: (0x001f, None, None, 4, "PidTagHobbies", "PR_HOBBIES", "Hobbies"),

1265 0x3a59: (0x001f, None, None, 4, "PidTagHomeAddressCity", "PR_HOME_ADDRESS_CITY", "HomeAddressCity"),

1266 0x3a5a: (0x001f, None, None, 4, "PidTagHomeAddressCountry", "PR_HOME_ADDRESS_COUNTRY", "HomeAddressCountry"),

1267 0x3a5b: (0x001f, None, None, 4, "PidTagHomeAddressPostalCode", "PR_HOME_ADDRESS_POSTAL_CODE", "HomeAddressPostalCode"),

1268 0x3a5e: (0x001f, None, None, 4, "PidTagHomeAddressPostOfficeBox", "PR_HOME_ADDRESS_POST_OFFICE_BOX", "HomeAddressPostOfficeBox"),

1269 0x3a5c: (0x001f, None, None, 4, "PidTagHomeAddressStateOrProvince", "PR_HOME_ADDRESS_STATE_OR_PROVINCE", "HomeAddressStateOrProvince"),

1270 0x3a25: (0x001f, None, None, 4, "PidTagHomeFaxNumber", "PR_HOME_FAX_NUMBER", "HomeFaxNumber"),

1271 0x10c4: (0x0040, None, None, 4, "PidTagICalendarEndTime", "urn:schemas:calendar:dtend", None),

1272 0x10ca: (0x0040, None, None, 4, "PidTagICalendarReminderNextTime", "urn:schemas:calendar:remindernexttime", None),

1273 0x10c3: (0x0040, None, None, 4, "PidTagICalendarStartTime", "urn:schemas:calendar:dtstart", None),

1274 0x1080: (0x0003, None, None, 4, "PidTagIconIndex", "PR_ICON_INDEX", "IconIndex"),

1275 0x666c: (0x000b, None, None, 4, "PidTagInConflict", "PR_IN_CONFLICT", "AttachmentInConflict"),

1276 0x3f08: (0x0003, None, None, 4, "PidTagInitialDetailsPane", "PR_INITIAL_DETAILS_PANE", "InitialDetailsPane"),

1277 0x1042: (0x001f, None, None, 4, "PidTagInReplyToId", "PR_IN_REPLY_TO_ID", "InReplyTo"),

1278 0x0ff6: (0x0102, None, None, 4, "PidTagInstanceKey", "PR_INSTANCE_KEY", "InstanceKey"),

1279 0x674e: (0x0003, None, None, 4, "PidTagInstanceNum", "ptagInstanceNum", "InstanceNum"),

1280 0x674d: (0x0014, None, None, 4, "PidTagInstID", "ptagInstID", "InstanceId"),

1281 0x3fde: (0x0003, None, None, 4, "PidTagInternetCodepage", "PR_INTERNET_CPID", "InternetCPID"),

1282 0x5902: (0x0003, None, None, 4, "PidTagInternetMailOverrideFormat", "PR_INETMAIL_OVERRIDE_FORMAT", "INetMailOverrideFormat"),

1283 0x1035: (0x001f, None, None, 4, "PidTagInternetMessageId", "PR_INTERNET_MESSAGE_ID", "InternetMessageId"),

1284 0x1039: (0x001f, None, None, 4, "PidTagInternetReferences", "PR_INTERNET_REFERENCES", "InternetReferences"),

1285 0x36d0: (0x0102, None, None, 4, "PidTagIpmAppointmentEntryId", "PR_IPM_APPOINTMENT_ENTRYID", "CalendarFolderEntryId"),

1286 0x36d1: (0x0102, None, None, 4, "PidTagIpmContactEntryId", "PR_IPM_CONTACT_ENTRYID", "ContactsFolderEntryId"),

1287 0x36d7: (0x0102, None, None, 4, "PidTagIpmDraftsEntryId", "PR_IPM_DRAFTS_ENTRYID", "DraftsFolderEntryId"),

1288 0x36d2: (0x0102, None, None, 4, "PidTagIpmJournalEntryId", "PR_IPM_JOURNAL_ENTRYID", "JournalFolderEntryId"),

1289 0x36d3: (0x0102, None, None, 4, "PidTagIpmNoteEntryId", "PR_IPM_NOTE_ENTRYID", "NotesFolderEntryId"),

1290 0x36d4: (0x0102, None, None, 4, "PidTagIpmTaskEntryId", "PR_IPM_TASK_ENTRYID", "TasksFolderEntryId"),

1291 0x3a2d: (0x001f, None, None, 4, "PidTagIsdnNumber", "PR_ISDN_NUMBER", "IsdnNumber"),

1292 0x6103: (0x0003, None, None, 4, "PidTagJunkAddRecipientsToSafeSendersList", "PR_JUNK_ADD_RECIPS_TO_SSL", None),

1293 0x6100: (0x0003, None, None, 4, "PidTagJunkIncludeContacts", "PR_JUNK_INCLUDE_CONTACTS", "JunkIncludeContacts"),

1294 0x6102: (0x0003, None, None, 4, "PidTagJunkPermanentlyDelete", "PR_JUNK_PERMANENTLY_DELETE", None),

1295 0x6107: (0x000b, None, None, 4, "PidTagJunkPhishingEnableLinks", "PR_JUNK_PHISHING_ENABLE_LINKS", None),

1296 0x6101: (0x0003, None, None, 4, "PidTagJunkThreshold", "PR_JUNK_THRESHOLD", "JunkThreshold"),

1297 0x3a0b: (0x001f, None, None, 4, "PidTagKeyword", "PR_KEYWORD", "Keyword"),

1298 0x3a0c: (0x001f, None, None, 4, "PidTagLanguage", "PR_LANGUAGE", "Language"),

1299 0x3ffb: (0x0102, None, None, 4, "PidTagLastModifierEntryId", "PR_LAST_MODIFIER_ENTRYID", "LastModifierEntryId"),

1300 0x3ffa: (0x001f, None, None, 4, "PidTagLastModifierName", "PR_LAST_MODIFIER_NAME", "LastModifierName"),

1301 0x1081: (0x0003, None, None, 4, "PidTagLastVerbExecuted", "PR_LAST_VERB_EXECUTED", "LastVerbExecuted"),

1302 0x1082: (0x0040, None, None, 4, "PidTagLastVerbExecutionTime", "PR_LAST_VERB_EXECUTION_TIME", "LastVerbExecutionTime"),

1303 0x1043: (0x001f, None, None, 4, "PidTagListHelp", "PR_LIST_HELP", "ListHelp"),

1304 0x1044: (0x001f, None, None, 4, "PidTagListSubscribe", "PR_LIST_SUBSCRIBE", "ListSubscribe"),

1305 0x1045: (0x001f, None, None, 4, "PidTagListUnsubscribe", "PR_LIST_UNSUBSCRIBE", "ListUnsubscribe"),

1306 0x6709: (0x0040, None, None, 4, "PidTagLocalCommitTime", "PR_LOCAL_COMMIT_TIME", "LocalCommitTime"),

1307 0x670a: (0x0040, None, None, 4, "PidTagLocalCommitTimeMax", "PR_LOCAL_COMMIT_TIME_MAX", "LocalCommitTimeMax"),

1308 0x66a1: (0x0003, None, None, 4, "PidTagLocaleId", "PR_LOCALE_ID", "LocaleId"),

1309 0x3a0d: (0x001f, None, None, 4, "PidTagLocation", "PR_LOCATION", "Location"),

1310 0x661b: (0x0102, None, None, 4, "PidTagMailboxOwnerEntryId", "PR_MAILBOX_OWNER_ENTRYID", "InternetRFC821From"),

1311 0x661c: (0x001f, None, None, 4, "PidTagMailboxOwnerName", "PR_MAILBOX_OWNER_NAME", "MailboxOwnerName"),

1312 0x3a4e: (0x001f, None, None, 4, "PidTagManagerName", "PR_MANAGER_NAME", "ManagerName"),

1313 0x0ff8: (0x0102, None, None, 4, "PidTagMappingSignature", "PR_MAPPING_SIGNATURE", "MappingSignature"),

1314 0x666d: (0x0003, None, None, 4, "PidTagMaximumSubmitMessageSize", "PR_MAX_SUBMIT_MESSAGE_SIZE", "SearchAttachments"),

1315 0x6671: (0x0014, None, None, 4, "PidTagMemberId", "PR_MEMBER_ID", "MemberId"),

1316 0x6672: (0x001f, None, None, 4, "PidTagMemberName", "PR_MEMBER_NAME", "MemberName"),

1317 0x6673: (0x0003, None, None, 4, "PidTagMemberRights", "PR_MEMBER_RIGHTS", "MemberRights"),

1318 0x0e13: (0x000d, None, None, 4, "PidTagMessageAttachments", "PR_MESSAGE_ATTACHMENTS", "MessageAttachments"),

1319 0x0058: (0x000b, None, None, 4, "PidTagMessageCcMe", "PR_MESSAGE_CC_ME", "MessageCcMe"),

1320 0x3ffd: (0x0003, None, None, 4, "PidTagMessageCodepage", "PR_MESSAGE_CODEPAGE", "MessageCodePage"),

1321 0x0e06: (0x0040, None, None, 4, "PidTagMessageDeliveryTime", "PR_MESSAGE_DELIVERY_TIME", "MessageDeliveryTime"),

1322 0x5909: (0x0003, None, None, 4, "PidTagMessageEditorFormat", "PR_MSG_EDITOR_FORMAT", "MessageEditorFormat"),

1323 0x0e07: (0x0003, None, None, 4, "PidTagMessageFlags", "PR_MESSAGE_FLAGS", "MessageFlags"),

1324 0x3ff1: (0x0003, None, None, 4, "PidTagMessageLocaleId", "PR_MESSAGE_LOCALE_ID", "MessageLocaleId"),

1325 0x0059: (0x000b, None, None, 4, "PidTagMessageRecipientMe", "PR_MESSAGE_RECIP_ME", "MessageRecipMe"),

1326 0x0e12: (0x000d, None, None, 4, "PidTagMessageRecipients", "PR_MESSAGE_RECIPIENTS", "MessageRecipients"),

1327 0x0e08: (0x0014, None, None, 4, "PidTagMessageSizeExtended", "PR_MESSAGE_SIZE_EXTENDED", "MessageSize"),

1328 0x0e17: (0x0003, None, None, 4, "PidTagMessageStatus", "PR_MSG_STATUS", "MsgStatus"),

1329 0x0047: (0x0102, None, None, 4, "PidTagMessageSubmissionId", "PR_MESSAGE_SUBMISSION_ID", "MessageSubmissionId"),

1330 0x0057: (0x000b, None, None, 4, "PidTagMessageToMe", "PR_MESSAGE_TO_ME", "MessageToMe"),

1331 0x674a: (0x0014, None, None, 4, "PidTagMid", "ptagMID", "Mid"),

1332 0x3a44: (0x001f, None, None, 4, "PidTagMiddleName", "PR_MIDDLE_NAME", "MiddleName"),

1333 0x64f0: (0x0102, None, None, 4, "PidTagMimeSkeleton", "ptagMimeSkeleton", "MimeSkeleton"),

1334 0x1016: (0x0003, None, None, 4, "PidTagNativeBody", "PR_NATIVE_BODY_INFO", "NativeBodyInfo"),

1335 0x0e29: (0x001f, None, None, 4, "PidTagNextSendAcct", "PR_NEXT_SEND_ACCT", "NextSendAccount"),

1336 0x3a4f: (0x001f, None, None, 4, "PidTagNickname", "PR_NICKNAME", "Nickname"),

1337 0x0c05: (0x0003, None, None, 4, "PidTagNonDeliveryReportDiagCode", "PR_NDR_DIAG_CODE", "NdrDiagCode"),

1338 0x0c04: (0x0003, None, None, 4, "PidTagNonDeliveryReportReasonCode", "PR_NDR_REASON_CODE", "NdrReasonCode"),

1339 0x0c20: (0x0003, None, None, 4, "PidTagNonDeliveryReportStatusCode", "PR_NDR_STATUS_CODE", "NDRStatusCode"),

1340 0x0c06: (0x000b, None, None, 4, "PidTagNonReceiptNotificationRequested", "PR_NON_RECEIPT_NOTIFICATION_REQUESTED", "NonReceiptNotificationRequested"),

1341 0x0e1d: (0x001f, None, None, 4, "PidTagNormalizedSubject", "PR_NORMALIZED_SUBJECT", "NormalizedSubject"),

1342 0x0ffe: (0x0003, None, None, 4, "PidTagObjectType", "PR_OBJECT_TYPE", "ObjectType"),

1343 0x6802: (0x001f, None, None, 4, "PidTagSenderTelephoneNumber", "InternalSchemaSenderTelephoneNumber", "SenderTelephoneNumber"),

1344 0x6803: (0x001f, None, None, 4, "PidTagVoiceMessageSenderName", "InternalSchemaVoiceMessageSenderName", "SendOutlookRecallReport"),

1345 0x6800: (0x001f, None, None, 4, "PidTagOfflineAddressBookName", "PR_OAB_NAME", None),

1346 0x6801: (0x0003, None, None, 4, "PidTagVoiceMessageDuration", "InternalSchemaVoiceMessageDuration", "VoiceMessageDuration"),

1347 0x6805: (0x001f, None, None, 4, "PidTagVoiceMessageAttachmentOrder", "InternalSchemaVoiceMessageAttachmentOrder", "VoiceMessageAttachmentOrder"),

1348 0x36e2: (0x0003, None, None, 4, "PidTagOrdinalMost", "PR_ORDINAL_MOST", None),

1349 0x3a10: (0x001f, None, None, 4, "PidTagOrganizationalIdNumber", "PR_ORGANIZATIONAL_ID_NUMBER", "OrganizationalIdNumber"),

1350 0x004c: (0x0102, None, None, 4, "PidTagOriginalAuthorEntryId", "PR_ORIGINAL_AUTHOR_ENTRYID", "OriginalAuthorEntryId"),

1351 0x004d: (0x001f, None, None, 4, "PidTagOriginalAuthorName", "PR_ORIGINAL_AUTHOR_NAME_W", "OriginalAuthorName"),

1352 0x0055: (0x0040, None, None, 4, "PidTagOriginalDeliveryTime", "PR_ORIGINAL_DELIVERY_TIME", "OriginalDeliveryTime"),

1353 0x0072: (0x001f, None, None, 4, "PidTagOriginalDisplayBcc", "PR_ORIGINAL_DISPLAY_BCC", "OriginalDisplayBcc"),

1354 0x0073: (0x001f, None, None, 4, "PidTagOriginalDisplayCc", "PR_ORIGINAL_DISPLAY_CC", "OriginalDisplayCc"),

1355 0x0074: (0x001f, None, None, 4, "PidTagOriginalDisplayTo", "PR_ORIGINAL_DISPLAY_TO", "OriginalDisplayTo"),

1356 0x3a12: (0x0102, None, None, 4, "PidTagOriginalEntryId", "PR_ORIGINAL_ENTRYID", "OriginalEntryId"),

1357 0x004b: (0x001f, None, None, 4, "PidTagOriginalMessageClass", "PR_ORIG_MESSAGE_CLASS", "OrigMessageClass"),

1358 0x1046: (0x001f, None, None, 4, "PidTagOriginalMessageId", "ptagOriginalInternetMessageID", "OriginalInternetMessageId"),

1359 0x0066: (0x001f, None, None, 4, "PidTagOriginalSenderAddressType", "PR_ORIGINAL_SENDER_ADDRTYPE", "OriginalSenderAddrType"),

1360 0x0067: (0x001f, None, None, 4, "PidTagOriginalSenderEmailAddress", "PR_ORIGINAL_SENDER_EMAIL_ADDRESS", "OriginalSenderEmailAddress"),

1361 0x005b: (0x0102, None, None, 4, "PidTagOriginalSenderEntryId", "PR_ORIGINAL_SENDER_ENTRYID", "OriginalSenderEntryId"),

1362 0x005a: (0x001f, None, None, 4, "PidTagOriginalSenderName", "PR_ORIGINAL_SENDER_NAME", "OriginalSenderName"),

1363 0x005c: (0x0102, None, None, 4, "PidTagOriginalSenderSearchKey", "PR_ORIGINAL_SENDER_SEARCH_KEY", "OriginalSenderSearchKey"),

1364 0x002e: (0x0003, None, None, 4, "PidTagOriginalSensitivity", "PR_ORIGINAL_SENSITIVITY", "OriginalSensitivity"),

1365 0x0068: (0x001f, None, None, 4, "PidTagOriginalSentRepresentingAddressType", "PR_ORIGINAL_SENT_REPRESENTING_ADDRTYPE", "OriginalSentRepresentingAddrType"),

1366 0x0069: (0x001f, None, None, 4, "PidTagOriginalSentRepresentingEmailAddress", "PR_ORIGINAL_SENT_REPRESENTING_EMAIL_ADDRESS", "OriginalSentRepresentingEmailAddress"),

1367 0x005e: (0x0102, None, None, 4, "PidTagOriginalSentRepresentingEntryId", "PR_ORIGINAL_SENT_REPRESENTING_ENTRYID", "OriginalSentRepresentingEntryId"),

1368 0x005d: (0x001f, None, None, 4, "PidTagOriginalSentRepresentingName", "PR_ORIGINAL_SENT_REPRESENTING_NAME", "OriginalSentRepresentingName"),

1369 0x005f: (0x0102, None, None, 4, "PidTagOriginalSentRepresentingSearchKey", "PR_ORIGINAL_SENT_REPRESENTING_SEARCH_KEY", "OriginalSentRepresentingSearchKey"),

1370 0x0049: (0x001f, None, None, 4, "PidTagOriginalSubject", "PR_ORIGINAL_SUBJECT", "OriginalSubject"),

1371 0x004e: (0x0040, None, None, 4, "PidTagOriginalSubmitTime", "PR_ORIGINAL_SUBMIT_TIME", "OriginalSubmitTime"),

1372 0x0c08: (0x000b, None, None, 4, "PidTagOriginatorNonDeliveryReportRequested", "PR_ORIGINATOR_NON_DELIVERY_REPORT_REQUESTED", "OriginatorNonDeliveryReportRequested"),

1373 0x7c24: (0x000b, None, None, 4, "PidTagOscSyncEnabled", "PR_OSC_SYNC_ENABLEDONSERVER", "OscSyncEnabledOnServer"),

1374 0x3a5f: (0x001f, None, None, 4, "PidTagOtherAddressCity", "PR_OTHER_ADDRESS_CITY", "OtherAddressCity"),

1375 0x3a60: (0x001f, None, None, 4, "PidTagOtherAddressCountry", "PR_OTHER_ADDRESS_COUNTRY", "OtherAddressCountry"),

1376 0x3a61: (0x001f, None, None, 4, "PidTagOtherAddressPostalCode", "PR_OTHER_ADDRESS_POSTAL_CODE", "OtherAddressPostalCode"),

1377 0x3a64: (0x001f, None, None, 4, "PidTagOtherAddressPostOfficeBox", "PR_OTHER_ADDRESS_POST_OFFICE_BOX", "OtherAddressPostOfficeBox"),

1378 0x3a62: (0x001f, None, None, 4, "PidTagOtherAddressStateOrProvince", "PR_OTHER_ADDRESS_STATE_OR_PROVINCE", "OtherAddressStateOrProvince"),

1379 0x3a63: (0x001f, None, None, 4, "PidTagOtherAddressStreet", "PR_OTHER_ADDRESS_STREET", "OtherAddressStreet"),

1380 0x3a1f: (0x001f, None, None, 4, "PidTagOtherTelephoneNumber", "PR_OTHER_TELEPHONE_NUMBER", "OtherTelephoneNumber"),

1381 0x661d: (0x000b, None, None, 4, "PidTagOutOfOfficeState", "PR_OOF_STATE", "OofState"),

1382 0x0062: (0x0003, None, None, 4, "PidTagOwnerAppointmentId", "PR_OWNER_APPT_ID", "OwnerApptId"),

1383 0x0e09: (0x0102, None, None, 4, "PidTagParentEntryId", "PR_PARENT_ENTRYID", "ParentEntryId"),

1384 0x6749: (0x0014, None, None, 4, "PidTagParentFolderId", "ptagParentFID", "ParentFid"),

1385 0x0025: (0x0102, None, None, 4, "PidTagParentKey", "PR_PARENT_KEY", "ParentKey"),

1386 0x65e1: (0x0102, None, None, 4, "PidTagParentSourceKey", "PR_PARENT_SOURCE_KEY", "ParentSourceKey"),

1387 0x3a50: (0x001f, None, None, 4, "PidTagPersonalHomePage", "PR_PERSONAL_HOME_PAGE", "PersonalHomePage"),

1388 0x3019: (0x0102, None, None, 4, "PidTagPolicyTag", "PR_POLICY_TAG", "PolicyTag"),

1389 0x3a15: (0x001f, None, None, 4, "PidTagPostalAddress", "PR_POSTAL_ADDRESS", "PostalAddress"),

1390 0x65e3: (0x0102, None, None, 4, "PidTagPredecessorChangeList", "PR_PREDECESSOR_CHANGE_LIST", "PredecessorChangeList"),

1391 0x0e28: (0x001f, None, None, 4, "PidTagPrimarySendAccount", "PR_PRIMARY_SEND_ACCT", "PrimarySendAccount"),

1392 0x3a1a: (0x001f, None, None, 4, "PidTagPrimaryTelephoneNumber", "PR_PRIMARY_TELEPHONE_NUMBER", "PrimaryTelephoneNumber"),

1393 0x7d01: (0x000b, None, None, 4, "PidTagProcessed", "PR_PROCESSED", "IsProcessed"),

1394 0x3a46: (0x001f, None, None, 4, "PidTagProfession", "PR_PROFESSION", "Profession"),

1395 0x666a: (0x0003, None, None, 4, "PidTagProhibitReceiveQuota", "PR_PROHIBIT_RECEIVE_QUOTA", "ProhibitReceiveQuota"),

1396 0x666e: (0x0003, None, None, 4, "PidTagProhibitSendQuota", "PR_PROHIBIT_SEND_QUOTA", "ProhibitSendQuota"),

1397 0x4083: (0x001f, None, None, 4, "PidTagPurportedSenderDomain", "PR_PURPORTED_SENDER_DOMAIN", "PurportedSenderDomain"),

1398 0x3a1d: (0x001f, None, None, 4, "PidTagRadioTelephoneNumber", "PR_RADIO_TELEPHONE_NUMBER", "RadioTelephoneNumber"),

1399 0x0e69: (0x000b, None, None, 4, "PidTagRead", "PR_READ", "Read"),

1400 0x4029: (0x001f, None, None, 4, "PidTagReadReceiptAddressType", "ptagReadReceiptAddrType", "ReadReceiptAddrType"),

1401 0x402a: (0x001f, None, None, 4, "PidTagReadReceiptEmailAddress", "ptagReadReceiptEmailAddr", "ReadReceiptEmailAddress"),

1402 0x0046: (0x0102, None, None, 4, "PidTagReadReceiptEntryId", "PR_READ_RECEIPT_ENTRYID", "ReadReceiptEntryId"),

1403 0x402b: (0x001f, None, None, 4, "PidTagReadReceiptName", "ptagReadReceiptDisplayName", "ReadReceiptDisplayName"),

1404 0x0053: (0x0102, None, None, 4, "PidTagReadReceiptSearchKey", "PR_READ_RECEIPT_SEARCH_KEY", "ReadReceiptSearchKey"),

1405 0x5d05: (0x001f, None, None, 4, "PidTagReadReceiptSmtpAddress", "ptagRecipientReadReceiptSmtpAddress", "ReadReceiptSMTPAddress"),

1406 0x0075: (0x001f, None, None, 4, "PidTagReceivedByAddressType", "PR_RECEIVED_BY_ADDRTYPE", "ReceivedByAddrType"),

1407 0x0076: (0x001f, None, None, 4, "PidTagReceivedByEmailAddress", "PR_RECEIVED_BY_EMAIL_ADDRESS", "ReceivedByEmailAddress"),

1408 0x003f: (0x0102, None, None, 4, "PidTagReceivedByEntryId", "PR_RECEIVED_BY_ENTRYID", "ReceivedByEntryId"),

1409 0x0040: (0x001f, None, None, 4, "PidTagReceivedByName", "PR_RECEIVED_BY_NAME", "ReceivedByName"),

1410 0x0051: (0x0102, None, None, 4, "PidTagReceivedBySearchKey", "PR_RECEIVED_BY_SEARCH_KEY", "ReceivedBySearchKey"),

1411 0x5d07: (0x001f, None, None, 4, "PidTagReceivedBySmtpAddress", "ptagRecipientRcvdBySmtpAddress", "ReceivedBySmtpAddress"),

1412 0x0077: (0x001f, None, None, 4, "PidTagReceivedRepresentingAddressType", "PR_RCVD_REPRESENTING_ADDRTYPE", "RcvdRepresentingAddrType"),

1413 0x0078: (0x001f, None, None, 4, "PidTagReceivedRepresentingEmailAddress", "PR_RCVD_REPRESENTING_EMAIL_ADDRESS", "RcvdRepresentingEmailAddress"),

1414 0x0043: (0x0102, None, None, 4, "PidTagReceivedRepresentingEntryId", "PR_RCVD_REPRESENTING_ENTRYID", "RcvdRepresentingEntryId"),

1415 0x0044: (0x001f, None, None, 4, "PidTagReceivedRepresentingName", "PR_RCVD_REPRESENTING_NAME", "RcvdRepresentingName"),

1416 0x0052: (0x0102, None, None, 4, "PidTagReceivedRepresentingSearchKey", "PR_RCVD_REPRESENTING_SEARCH_KEY", "RcvdRepresentingSearchKey"),

1417 0x5d08: (0x001f, None, None, 4, "PidTagReceivedRepresentingSmtpAddress", "ptagRecipientRcvdRepresentingSmtpAddress", "RcvdRepresentingSmtpAddress"),

1418 0x5ff6: (0x001f, None, None, 4, "PidTagRecipientDisplayName", "PR_RECIPIENT_DISPLAY_NAME", "RecipientDisplayName"),

1419 0x5ff7: (0x0102, None, None, 4, "PidTagRecipientEntryId", "PR_RECIPIENT_ENTRYID", "RecipientEntryId"),

1420 0x5ffd: (0x0003, None, None, 4, "PidTagRecipientFlags", "PR_RECIPIENT_FLAGS", "RecipientFlags"),

1421 0x5fdf: (0x0003, None, None, 4, "PidTagRecipientOrder", "PR_RECIPIENT_ORDER", "RecipientOrder"),

1422 0x5fe1: (0x000b, None, None, 4, "PidTagRecipientProposed", "PR_RECIPIENT_PROPOSED", "RecipientProposed"),

1423 0x5fe4: (0x0040, None, None, 4, "PidTagRecipientProposedEndTime", "PR_RECIPIENT_PROPOSEDENDTIME", "RecipientProposedEndTime"),

1424 0x5fe3: (0x0040, None, None, 4, "PidTagRecipientProposedStartTime", "PR_RECIPIENT_PROPOSEDSTARTTIME", "RecipientProposedStartTime"),

1425 0x002b: (0x000b, None, None, 4, "PidTagRecipientReassignmentProhibited", "PR_RECIPIENT_REASSIGNMENT_PROHIBITED", "RecipientReassignmentProhibited"),

1426 0x5fff: (0x0003, None, None, 4, "PidTagRecipientTrackStatus", "PR_RECIPIENT_TRACKSTATUS", "RecipientTrackStatus"),

1427 0x5ffb: (0x0040, None, None, 4, "PidTagRecipientTrackStatusTime", "PR_RECIPIENT_TRACKSTATUS_TIME", "RecipientTrackStatusTime"),

1428 0x0c15: (0x0003, None, None, 4, "PidTagRecipientType", "PR_RECIPIENT_TYPE", "RecipientType"),

1429 0x0ff9: (0x0102, None, None, 4, "PidTagRecordKey", "PR_RECORD_KEY", "RecordKey"),

1430 0x3a47: (0x001f, None, None, 4, "PidTagReferredByName", "PR_REFERRED_BY_NAME", "PreferredByName"),

1431 0x36d5: (0x0102, None, None, 4, "PidTagRemindersOnlineEntryId", "PR_REM_ONLINE_ENTRYID", "RemindersSearchFolderEntryId"),

1432 0x0c21: (0x001f, None, None, 4, "PidTagRemoteMessageTransferAgent", "PR_DSN_REMOTE_MTA", "RemoteMta"),

1433 0x370b: (0x0003, None, None, 4, "PidTagRenderingPosition", "PR_RENDERING_POSITION", "RenderingPosition"),

1434 0x004f: (0x0102, None, None, 4, "PidTagReplyRecipientEntries", "PR_REPLY_RECIPIENT_ENTRIES", "ReplyRecipientEntries"),

1435 0x0050: (0x001f, None, None, 4, "PidTagReplyRecipientNames", "PR_REPLY_RECIPIENT_NAMES", "ReplyRecipientNames"),

1436 0x0c17: (0x000b, None, None, 4, "PidTagReplyRequested", "PR_REPLY_REQUESTED", "ReplyRequested"),

1437 0x65c2: (0x0102, None, None, 4, "PidTagReplyTemplateId", "PR_REPLY_TEMPLATE_ID", "ReplyTemplateID"),

1438 0x0030: (0x0040, None, None, 4, "PidTagReplyTime", "PR_REPLY_TIME", "ReplyTime"),

1439 0x0080: (0x001f, None, None, 4, "PidTagReportDisposition", "PR_REPORT_DISPOSITION_W", "ReportDisposition"),

1440 0x0081: (0x001f, None, None, 4, "PidTagReportDispositionMode", "PR_REPORT_DISPOSITION_MODE_W", "ReportDispositionMode"),

1441 0x0045: (0x0102, None, None, 4, "PidTagReportEntryId", "PR_REPORT_ENTRYID", "ReportEntryId"),

1442 0x6820: (0x001f, None, None, 4, "PidTagReportingMessageTransferAgent", "ptagDsnReportingMta", "ReportingMta"),

1443 0x003a: (0x001f, None, None, 4, "PidTagReportName", "PR_REPORT_NAME", "ReportName"),

1444 0x0054: (0x0102, None, None, 4, "PidTagReportSearchKey", "PR_REPORT_SEARCH_KEY", "ReportSearchKey"),

1445 0x0031: (0x0102, None, None, 4, "PidTagReportTag", "PR_REPORT_TAG", "ReportTag"),

1446 0x0032: (0x0040, None, None, 4, "PidTagReportTime", "PR_REPORT_TIME", "ReportTime"),

1447 0x3fe7: (0x0003, None, None, 4, "PidTagResolveMethod", "PR_RESOLVE_METHOD", "ResolveMethod"),

1448 0x0063: (0x000b, None, None, 4, "PidTagResponseRequested", "PR_RESPONSE_REQUESTED", "ResponseRequested"),

1449 0x0e0f: (0x000b, None, None, 4, "PidTagResponsibility", "PR_RESPONSIBILITY", "Responsibility"),

1450 0x301c: (0x0040, None, None, 4, "PidTagRetentionDate", "PR_RETENTION_DATE", "RetentionDate"),

1451 0x301d: (0x0003, None, None, 4, "PidTagRetentionFlags", "PR_RETENTION_FLAGS", "RetentionFlags"),

1452 0x301a: (0x0003, None, None, 4, "PidTagRetentionPeriod", "PR_RETENTION_PERIOD", "RetentionPeriod"),

1453 0x6639: (0x0003, None, None, 4, "PidTagRights", "PR_RIGHTS", "AccessRights"),

1454 0x7c06: (0x0003, None, None, 4, "PidTagRoamingDatatypes", "PR_ROAMING_DATATYPES", "UserConfigurationType"),

1455 0x7c07: (0x0102, None, None, 4, "PidTagRoamingDictionary", "PR_ROAMING_DICTIONARY", "UserConfigurationDictionary"),

1456 0x7c08: (0x0102, None, None, 4, "PidTagRoamingXmlStream", "PR_ROAMING_XMLSTREAM", "UserConfigurationXml"),

1457 0x3000: (0x0003, None, None, 4, "PidTagRowid", "PR_ROWID", "RowId"),

1458 0x0ff5: (0x0003, None, None, 4, "PidTagRowType", "PR_ROW_TYPE", "RowType"),

1459 0x1009: (0x0102, None, None, 4, "PidTagRtfCompressed", "PR_RTF_COMPRESSED", "RtfCompressed"),

1460 0x0e1f: (0x000b, None, None, 4, "PidTagRtfInSync", "PR_RTF_IN_SYNC", "RtfInSync"),

1461 0x6650: (0x0003, None, None, 4, "PidTagRuleActionNumber", "PR_RULE_ACTION_NUMBER", "RuleActionNumber"),

1462 0x6680: (0x00fe, None, None, 4, "PidTagRuleActions", "PR_RULE_ACTIONS", "RuleActions"),

1463 0x6649: (0x0003, None, None, 4, "PidTagRuleActionType", "PR_RULE_ACTION_TYPE", "RuleActionType"),

1464 0x6679: (0x00fd, None, None, 4, "PidTagRuleCondition", "PR_RULE_CONDITION", "RuleCondition"),

1465 0x6648: (0x0003, None, None, 4, "PidTagRuleError", "PR_RULE_ERROR", "RuleError"),

1466 0x6651: (0x0102, None, None, 4, "PidTagRuleFolderEntryId", "PR_RULE_FOLDER_ENTRYID", "RuleFolderEntryID"),

1467 0x6674: (0x0014, None, None, 4, "PidTagRuleId", "PR_RULE_ID", "RuleID"),

1468 0x6675: (0x0102, None, None, 4, "PidTagRuleIds", "PR_RULE_IDS", "RuleIDs"),

1469 0x6683: (0x0003, None, None, 4, "PidTagRuleLevel", "PR_RULE_LEVEL", "RuleLevel"),

1470 0x65ed: (0x0003, None, None, 4, "PidTagRuleMessageLevel", "PR_RULE_MSG_LEVEL", "RuleMsgLevel"),

1471 0x65ec: (0x001f, None, None, 4, "PidTagRuleMessageName", "ptagRuleMsgName", "RuleMsgName"),

1472 0x65eb: (0x001f, None, None, 4, "PidTagRuleMessageProvider", "ptagRuleMsgProvider", "RuleMsgProvider"),

1473 0x65ee: (0x0102, None, None, 4, "PidTagRuleMessageProviderData", "PR_RULE_MSG_PROVIDER_DATA", "RuleMsgProviderData"),

1474 0x65f3: (0x0003, None, None, 4, "PidTagRuleMessageSequence", "PR_RULE_MSG_SEQUENCE", "RuleMsgSequence"),

1475 0x65e9: (0x0003, None, None, 4, "PidTagRuleMessageState", "PR_RULE_MSG_STATE", "RuleMsgState"),

1476 0x65ea: (0x0003, None, None, 4, "PidTagRuleMessageUserFlags", "PR_RULE_MSG_USER_FLAGS", "RuleMsgUserFlags"),

1477 0x6682: (0x001f, None, None, 4, "PidTagRuleName", "PR_RULE_NAME", "RuleName"),

1478 0x6681: (0x001f, None, None, 4, "PidTagRuleProvider", "PR_RULE_PROVIDER", "RuleProvider"),

1479 0x6684: (0x0102, None, None, 4, "PidTagRuleProviderData", "PR_RULE_PROVIDER_DATA", "RuleProviderData"),

1480 0x6676: (0x0003, None, None, 4, "PidTagRuleSequence", "PR_RULE_SEQUENCE", "RuleSequence"),

1481 0x6677: (0x0003, None, None, 4, "PidTagRuleState", "PR_RULE_STATE", "RuleState"),

1482 0x6678: (0x0003, None, None, 4, "PidTagRuleUserFlags", "PR_RULE_USER_FLAGS", "RuleUserFlags"),

1483 0x686a: (0x0102, None, None, 4, "PidTagScheduleInfoAppointmentTombstone", "PR_SCHDINFO_APPT_TOMBSTONE", "AppointmentTombstonesId"),

1484 0x686d: (0x000b, None, None, 4, "PidTagScheduleInfoAutoAcceptAppointments", "PR_SCHDINFO_AUTO_ACCEPT_APPTS", None),

1485 0x6845: (0x0102, None, None, 4, "PidTagSearchFolderDefinition", "PR_WB_SF_DEFINITION", "DelegateEntryIds"),

1486 0x6844: (0x0102, None, None, 4, "PidTagSearchFolderRecreateInfo", "PR_WB_SF_RECREATE_INFO", "ActivityLogicalItemId"),

1487 0x684a: (0x0003, None, None, 4, "PidTagWlinkFlags", "PR_WLINK_FLAGS", "DelegateNames"),

1488 0x6842: (0x0102, None, None, 4, "PidTagWlinkGroupHeaderID", None, "DelegateBossWantsCopy"),

1489 0x684b: (0x0102, None, None, 4, "PidTagWlinkOrdinal", "PR_WLINK_ORDINAL", "DelegateBossWantsInfo"),

1490 0x686f: (0x000b, None, None, 4, "PidTagScheduleInfoDisallowOverlappingAppts", "PR_SCHDINFO_DISALLOW_OVERLAPPING_APPTS", None),

1491 0x686e: (0x000b, None, None, 4, "PidTagScheduleInfoDisallowRecurringAppts", "PR_SCHDINFO_DISALLOW_RECURRING_APPTS", None),

1492 0x6843: (0x000b, None, None, 4, "PidTagScheduleInfoDontMailDelegates", "PR_SCHDINFO_DONT_MAIL_DELEGATES", "ActivityContainerType"),

1493 0x686c: (0x0102, None, None, 4, "PidTagScheduleInfoFreeBusy", "PR_SCHDINFO_FREEBUSY", None),

1494 0x6856: (0x1102, None, None, 4, "PidTagScheduleInfoFreeBusyAway", "PR_SCHDINFO_FREEBUSY_OOF", "AgingFileName9AndPrev"),

1495 0x6854: (0x0102, None, None, 4, "PidTagWlinkAddressBookEID", "PR_WLINK_ABEID", "NavigationNodeAddressBookEntryId"),

1496 0x6850: (0x0102, None, None, 4, "PidTagWlinkGroupClsid", "PR_WLINK_GROUP_CLSID", "ScheduleInfoFreeBusyMerged"),

1497 0x6852: (0x0003, None, None, 4, "PidTagWlinkSection", "PR_WLINK_SECTION", "NavigationNodeGroupSection"),

1498 0x6855: (0x1003, None, None, 4, "PidTagScheduleInfoMonthsAway", "PR_SCHDINFO_MONTHS_OOF", "ScheduleInfoMonthsOof"),

1499 0x6853: (0x0003, None, None, 4, "PidTagWlinkCalendarColor", "PR_WLINK_CALENDAR_COLOR", "NavigationNodeCalendarColor"),

1500 0x684f: (0x0102, None, None, 4, "PidTagWlinkFolderType", "PR_WLINK_FOLDER_TYPE", "ScheduleInfoMonthsMerged"),

1501 0x6851: (0x001f, None, None, 4, "PidTagWlinkGroupName", "PR_WLINK_GROUP_NAME", "NavigationNodeGroupName"),

1502 0x6841: (0x0003, None, None, 4, "PidTagSearchFolderTemplateId", "PR_WB_SF_TEMPLATE_ID", "AssociatedSearchFolderTemplateId"),

1503 0x6622: (0x0102, None, None, 4, "PidTagSchedulePlusFreeBusyEntryId", "PR_SPLUS_FREE_BUSY_ENTRYID", "FreeBusyEntryId"),

1504 0x683a: (0x0003, None, None, 4, "PidTagSearchFolderExpiration", "PR_WB_SF_EXPIRATION", "ActivitySequenceNumber"),

1505 0x6834: (0x0003, None, None, 4, "PidTagSearchFolderLastUsed", "PR_WB_SF_LAST_USED", "AssociatedSearchFolderLastUsedTime"),

1506 0x300b: (0x0102, None, None, 4, "PidTagSearchKey", "PR_SEARCH_KEY", "SearchKey"),

1507 0x0e6a: (0x001f, None, None, 4, "PidTagSecurityDescriptorAsXml", "PR_NT_SECURITY_DESCRIPTOR_AS_XML", "NTSDAsXML"),

1508 0x3609: (0x000b, None, None, 4, "PidTagSelectable", "PR_SELECTABLE", "Selectable"),

1509 0x0c1e: (0x001f, None, None, 4, "PidTagSenderAddressType", "PR_SENDER_ADDRTYPE", "SenderAddrType"),

1510 0x0c1f: (0x001f, None, None, 4, "PidTagSenderEmailAddress", "PR_SENDER_EMAIL_ADDRESS", "SenderEmailAddress"),

1511 0x0c19: (0x0102, None, None, 4, "PidTagSenderEntryId", "PR_SENDER_ENTRYID", "SenderEntryId"),

1512 0x4079: (0x0003, None, None, 4, "PidTagSenderIdStatus", "PR_SENDER_ID_STATUS", "SenderIdStatus"),

1513 0x0c1a: (0x001f, None, None, 4, "PidTagSenderName", "PR_SENDER_NAME", "SenderName"),

1514 0x0c1d: (0x0102, None, None, 4, "PidTagSenderSearchKey", "PR_SENDER_SEARCH_KEY", "SenderSearchKey"),

1515 0x5d01: (0x001f, None, None, 4, "PidTagSenderSmtpAddress", "SenderSmtpAddress", "SenderSmtpAddress"),

1516 0x0036: (0x0003, None, None, 4, "PidTagSensitivity", "PR_SENSITIVITY", "Sensitivity"),

1517 0x6740: (0x00fb, None, None, 4, "PidTagSentMailSvrEID", "ptagSentMailSvrEID", "SentMailSvrEId"),

1518 0x0064: (0x001f, None, None, 4, "PidTagSentRepresentingAddressType", "PR_SENT_REPRESENTING_ADDRTYPE", "SentRepresentingAddrType"),

1519 0x0065: (0x001f, None, None, 4, "PidTagSentRepresentingEmailAddress", "PR_SENT_REPRESENTING_EMAIL_ADDRESS", "SentRepresentingEmailAddress"),

1520 0x0041: (0x0102, None, None, 4, "PidTagSentRepresentingEntryId", "PR_SENT_REPRESENTING_ENTRYID", "SentRepresentingEntryId"),

1521 0x401a: (0x0003, None, None, 4, "PidTagSentRepresentingFlags", "ptagSentRepresentingFlags", "SentRepresentingFlags"),

1522 0x0042: (0x001f, None, None, 4, "PidTagSentRepresentingName", "PR_SENT_REPRESENTING_NAME", "SentRepresentingName"),

1523 0x003b: (0x0102, None, None, 4, "PidTagSentRepresentingSearchKey", "PR_SENT_REPRESENTING_SEARCH_KEY", "SentRepresentingSearchKey"),

1524 0x5d02: (0x001f, None, None, 4, "PidTagSentRepresentingSmtpAddress", "ptagRecipientSentRepresentingSMTPAddress", "SentRepresentingSmtpAddress"),

1525 0x6638: (0x0102, None, None, 4, "PidTagSerializedReplidGuidMap", "ptagSerializedReplidGuidMap", "FolderChildCount32"),

1526 0x6705: (0x0003, None, None, 4, "PidTagSortLocaleId", "PR_SORT_LOCALE_ID", "SortLocaleId"),

1527 0x65e0: (0x0102, None, None, 4, "PidTagSourceKey", "PR_SOURCE_KEY", "SourceKey"),

1528 0x3a48: (0x001f, None, None, 4, "PidTagSpouseName", "PR_SPOUSE_NAME", "SpouseName"),

1529 0x0060: (0x0040, None, None, 4, "PidTagStartDate", "PR_START_DATE", "StartDate"),

1530 0x301b: (0x0102, None, None, 4, "PidTagStartDateEtc", "PR_START_DATE_ETC", "StartDateEtc"),

1531 0x0ffb: (0x0102, None, None, 4, "PidTagStoreEntryId", "PR_STORE_ENTRYID", "StoreEntryid"),

1532 0x340e: (0x0003, None, None, 4, "PidTagStoreState", "PR_STORE_STATE", "StoreState"),

1533 0x340d: (0x0003, None, None, 4, "PidTagStoreSupportMask", "PR_STORE_SUPPORT_MASK", "StoreSupportMask"),

1534 0x360a: (0x000b, None, None, 4, "PidTagSubfolders", "PR_SUBFOLDERS", "SubFolders"),

1535 0x0037: (0x001f, None, None, 4, "PidTagSubject", "PR_SUBJECT", "Subject"),

1536 0x003d: (0x001f, None, None, 4, "PidTagSubjectPrefix", "PR_SUBJECT_PREFIX", "SubjectPrefix"),

1537 0x0c1b: (0x001f, None, None, 4, "PidTagSupplementaryInfo", "PR_SUPPLEMENTARY_INFO", "SupplementaryInfo"),

1538 0x0e2d: (0x0102, None, None, 4, "PidTagSwappedToDoData", "PR_SWAPPED_TODO_DATA", "SwappedToDoData"),

1539 0x0e2c: (0x0102, None, None, 4, "PidTagSwappedToDoStore", "PR_SWAPPED_TODO_STORE", "SwappedToDoStore"),

1540 0x3010: (0x0102, None, None, 4, "PidTagTargetEntryId", "PR_TARGET_ENTRYID", "TargetEntryId"),

1541 0x3a4b: (0x001f, None, None, 4, "PidTagTelecommunicationsDeviceForDeafTelephoneNumber", "PR_TTYTDD_PHONE_NUMBER", "TtytddPhoneNumber"),

1542 0x3902: (0x0102, None, None, 4, "PidTagTemplateid", "PR_TEMPLATEID", "TemplateId"),

1543 0x371b: (0x001f, None, None, 4, "PidTagTextAttachmentCharset", "ptagTextAttachmentCharset", "TextAttachmentCharset"),

1544 0x007f: (0x0102, None, None, 4, "PidTagTnefCorrelationKey", "PR_TNEF_CORRELATION_KEY", "TnefCorrelationKey"),

1545 0x0e2b: (0x0003, None, None, 4, "PidTagToDoItemFlags", "PR_TODO_ITEM_FLAGS", "ToDoItemFlags"),

1546 0x3a20: (0x001f, None, None, 4, "PidTagTransmittableDisplayName", "PR_TRANSMITABLE_DISPLAY_NAME", "TransmitableDisplayName"),

1547 0x007d: (0x001f, None, None, 4, "PidTagTransportMessageHeaders", "PR_TRANSPORT_MESSAGE_HEADERS", "TransportMessageHeaders"),

1548 0x0e79: (0x0003, None, None, 4, "PidTagTrustSender", "PR_TRUST_SENDER", "TrustSender"),

1549 0x6619: (0x0102, None, None, 4, "PidTagUserEntryId", "PR_USER_ENTRYID", "InternetAddressConversion"),

1550 0x7001: (0x0102, None, None, 4, "PidTagViewDescriptorBinary", "PR_VD_BINARY", "UserInformationLastMaintenanceTime"),

1551 0x7006: (0x001f, None, None, 4, "PidTagViewDescriptorName", "PR_VD_NAME", None),

1552 0x7002: (0x001f, None, None, 4, "PidTagViewDescriptorStrings", "PR_VD_STRINGS", None),

1553 0x7007: (0x0003, None, None, 4, "PidTagViewDescriptorVersion", "PR_VD_VERSION", None),

1554 0x3a41: (0x0040, None, None, 4, "PidTagWeddingAnniversary", "PR_WEDDING_ANNIVERSARY", "WeddingAnniversary"),

1555 0x6891: (0x0102, None, None, 4, "PidTagWlinkAddressBookStoreEID", "PR_WLINK_AB_EXSTOREEID", "ConversationContentUnreadMailboxWide"),

1556 0x6890: (0x0102, None, None, 4, "PidTagWlinkClientID", "PR_WLINK_CLIENTID", "ConversationContentUnread"),

1557 0x684c: (0x0102, None, None, 4, "PidTagWlinkEntryId", "PR_WLINK_ENTRYID", "NavigationNodeEntryId"),

1558 0x684d: (0x0102, None, None, 4, "PidTagWlinkRecordKey", "PR_WLINK_RECKEY", "NavigationNodeRecordKey"),

1559 0x6892: (0x0003, None, None, 4, "PidTagWlinkROGroupType", "PR_WLINK_RO_GROUP_TYPE", "ConversationMessageSize"),

1560 0x684e: (0x0102, None, None, 4, "PidTagWlinkStoreEntryId", "PR_WLINK_STORE_ENTRYID", "NavigationNodeStoreEntryId"),

1561# ====================

1562 0x0000: (0x0001, None, None, 4, None, None, "Null"),

1563 0x6700: (0x001f, None, None, 4, None, None, "PstPath"),

1564 0x6603: (0x001f, None, None, 4, None, None, "ProfileUser"),

1565 0x660b: (0x001f, None, None, 4, None, None, "ProfileMailbox"),

1566 0x6602: (0x001f, None, None, 4, None, None, "ProfileHomeServer"),

1567 0x6612: (0x001f, None, None, 4, None, None, "ProfileHomeServerDn"),

1568 0x660c: (0x001f, None, None, 4, None, None, "ProfileServer"),

1569 0x6614: (0x001e, None, None, 4, None, None, "ProfileServerDn"),

1570 0x6601: (0x0003, None, None, 4, None, None, "ProfileConfigFlags"),

1571 0x6605: (0x0003, None, None, 4, None, None, "ProfileTransportFlags"),

1572 0x6600: (0x0003, None, None, 4, None, None, "ProfileVersion"),

1573 0x6604: (0x0003, None, None, 4, None, None, "ProfileConnectFlags"),

1574 0x6606: (0x0003, None, None, 4, None, None, "ProfileUiState"),

1575 0x000b: (0x0102, None, None, 4, None, None, "ConversationKey"),

1576 0x0016: (0x000b, None, None, 4, None, None, "ImplicitConversionProhibited"),

1577 0x0019: (0x0040, None, None, 4, None, None, "LatestDeliveryTime"),

1578 0x001b: (0x0102, None, None, 4, None, None, "MessageDeliveryId"),

1579 0x001e: (0x0102, None, None, 4, None, None, "MessageSecurityLabel"),

1580 0x001f: (0x0102, None, None, 4, None, None, "ObsoletedIpms"),

1581 0x0020: (0x0102, None, None, 4, None, None, "OriginallyIntendedRecipientName"),

1582 0x0021: (0x0102, None, None, 4, None, None, "OriginalEits"),

1583 0x0022: (0x0102, None, None, 4, None, None, "OriginatorCertificate"),

1584 0x0027: (0x0102, None, None, 4, None, None, "OriginCheck"),

1585 0x002c: (0x0102, None, None, 4, None, None, "RedirectionHistory"),

1586 0x002d: (0x0102, None, None, 4, None, None, "RelatedIpms"),

1587 0x002f: (0x001f, None, None, 4, None, None, "Languages"),

1588 0x0033: (0x000b, None, None, 4, None, None, "ReturnedIpm"),

1589 0x0034: (0x0003, None, None, 4, None, None, "Security"),

1590 0x0035: (0x000b, None, None, 4, None, None, "IncompleteCopy"),

1591 0x0038: (0x0102, None, None, 4, None, None, "SubjectIpm"),

1592 0x003c: (0x0102, None, None, 4, None, None, "X400ContentType"),

1593 0x003e: (0x0003, None, None, 4, None, None, "NonReceiptReason"),

1594 0x0048: (0x0040, None, None, 4, None, None, "ProviderSubmitTime"),

1595 0x004a: (0x000b, None, None, 4, None, None, "DiscVal"),

1596 0x0056: (0x0102, None, None, 4, None, None, "OriginalAuthorSearchKey"),

1597 0x0079: (0x001f, None, None, 4, None, None, "OriginalAuthorAddrType"),

1598 0x007a: (0x001f, None, None, 4, None, None, "OriginalAuthorEmailAddress"),

1599 0x007b: (0x001f, None, None, 4, None, None, "OriginallyIntendedRecipAddrType"),

1600 0x007c: (0x001f, None, None, 4, None, None, "OriginallyIntendedRecipEmailAddress"),

1601 0x007e: (0x0102, None, None, 4, None, None, "Delegation"),

1602 0x4031: (0x001f, None, None, 4, None, None, "SentRepresentingSimpleDisplayName"),

1603 0x4032: (0x001f, None, None, 4, None, None, "OriginalSenderSimpleDisplayName"),

1604 0x4033: (0x001f, None, None, 4, None, None, "OriginalSentRepresentingSimpleDisplayName"),

1605 0x4034: (0x001f, None, None, 4, None, None, "ReceivedBySimpleDisplayName"),

1606 0x4035: (0x001f, None, None, 4, None, None, "RcvdRepresentingSimpleDisplayName"),

1607 0x4036: (0x001f, None, None, 4, None, None, "ReadReceiptSimpleDisplayName"),

1608 0x4060: (0x001f, None, None, 4, None, None, "OriginalAuthorSimpleDisplayName"),

1609 0x1002: (0x0102, None, None, 4, None, None, "OriginatorAndDlExpansionHistory"),

1610 0x1003: (0x0102, None, None, 4, None, None, "ReportingDlName"),

1611 0x1004: (0x0102, None, None, 4, None, None, "ReportingMtaCertificate"),

1612 0x1007: (0x0003, None, None, 4, None, None, "RtfSyncBodyCount"),

1613 0x1008: (0x001f, None, None, 4, None, None, "RtfSyncBodyTag"),

1614 0x1010: (0x0003, None, None, 4, None, None, "RtfSyncPrefixCount"),

1615 0x1011: (0x0003, None, None, 4, None, None, "RtfSyncTrailingCount"),

1616 0x1012: (0x0102, None, None, 4, None, None, "OriginallyIntendedRecipEntryId"),

1617 0x1097: (0x0003, None, None, 4, None, None, "ItemTemporaryFlag"),

1618 0x10c6: (0x001f, None, None, 4, None, None, "DavSubmitData"),

1619 0x0c00: (0x0102, None, None, 4, None, None, "ContentIntegrityCheck"),

1620 0x0c01: (0x0003, None, None, 4, None, None, "ExplicitConversion"),

1621 0x0c02: (0x000b, None, None, 4, None, None, "IpmReturnRequested"),

1622 0x0c03: (0x0102, None, None, 4, None, None, "MessageToken"),

1623 0x0c07: (0x0003, None, None, 4, None, None, "DeliveryPoint"),

1624 0x0c09: (0x0102, None, None, 4, None, None, "OriginatorRequestedAlternateRecipient"),

1625 0x0c0a: (0x000b, None, None, 4, None, None, "PhysicalDeliveryBureauFaxDelivery"),

1626 0x0c0b: (0x0003, None, None, 4, None, None, "PhysicalDeliveryMode"),

1627 0x0c0c: (0x0003, None, None, 4, None, None, "PhysicalDeliveryReportRequest"),

1628 0x0c0d: (0x0102, None, None, 4, None, None, "PhysicalForwardingAddress"),

1629 0x0c0e: (0x000b, None, None, 4, None, None, "PhysicalForwardingAddressRequested"),

1630 0x0c0f: (0x000b, None, None, 4, None, None, "PhysicalForwardingProhibited"),

1631 0x0c10: (0x0102, None, None, 4, None, None, "PhysicalRenditionAttributes"),

1632 0x0c11: (0x0102, None, None, 4, None, None, "ProofOfDelivery"),

1633 0x0c12: (0x000b, None, None, 4, None, None, "ProofOfDeliveryRequested"),

1634 0x0c13: (0x0102, None, None, 4, None, None, "RecipientCertificate"),

1635 0x0c14: (0x001f, None, None, 4, None, None, "RecipientNumberForAdvice"),

1636 0x0c16: (0x0003, None, None, 4, None, None, "RegisteredMailType"),

1637 0x0c18: (0x0003, None, None, 4, None, None, "RequestedDeliveryMethod"),

1638 0x0c1c: (0x0003, None, None, 4, None, None, "TypeOfMtsUser"),

1639 0x5903: (0x001f, None, None, 4, None, None, "INetMailOverrideCharset"),

1640 0x4030: (0x001f, None, None, 4, None, None, "SenderSimpleDisplayName"),

1641 0x0e00: (0x0014, None, None, 4, None, None, "CurrentVersion"),

1642 0x0e05: (0x001f, None, None, 4, None, None, "ParentDisplay"),

1643 0x0e0a: (0x0102, None, None, 4, None, None, "SentMailEntryId"),

1644 0x0e0c: (0x000b, None, None, 4, None, None, "Correlate"),

1645 0x0e0d: (0x0102, None, None, 4, None, None, "CorrelateMtsid"),

1646 0x0e0e: (0x000b, None, None, 4, None, None, "DiscreteValues"),

1647 0x0e10: (0x0003, None, None, 4, None, None, "SpoolerStatus"),

1648 0x0e11: (0x0003, None, None, 4, None, None, "TransportStatus"),

1649 0x0e14: (0x0003, None, None, 4, None, None, "SubmitFlags"),

1650 0x0e15: (0x0003, None, None, 4, None, None, "RecipientStatus"),

1651 0x0e16: (0x0003, None, None, 4, None, None, "TransportKey"),

1652 0x0e18: (0x0003, None, None, 4, None, None, "MessageDownloadTime"),

1653 0x0e19: (0x0014, None, None, 4, None, None, "CreationVersion"),

1654 0x0e1a: (0x0014, None, None, 4, None, None, "ModifyVersion"),

1655 0x0e1c: (0x0003, None, None, 4, None, None, "BodyCrc"),

1656 0x0e22: (0x000b, None, None, 4, None, None, "Preprocess"),

1657 0x0e23: (0x0003, None, None, 4, None, None, "InternetArticleNumber"),

1658 0x0e25: (0x0102, None, None, 4, None, None, "OriginatingMtaCertificate"),

1659 0x0e26: (0x0102, None, None, 4, None, None, "ProofOfSubmission"),

1660 0x0e3a: (0x000d, None, None, 4, None, None, "MessageDeepAttachments"),

1661 0x0e85: (0x001f, None, None, 4, None, None, "AntiVirusVendor"),

1662 0x0e86: (0x0003, None, None, 4, None, None, "AntiVirusVersion"),

1663 0x0e87: (0x0003, None, None, 4, None, None, "AntiVirusScanStatus"),

1664 0x0e88: (0x001f, None, None, 4, None, None, "AntiVirusScanInfo"),

1665 0x0e96: (0x101f, None, None, 4, None, None, "TransportAntiVirusStamp"),

1666 0x0e7c: (0x0003, None, None, 4, None, None, "MessageDatabasePage"),

1667 0x0e7d: (0x0003, None, None, 4, None, None, "MessageHeaderDatabasePage"),

1668 0x0ffd: (0x0102, None, None, 4, None, None, "Icon"),

1669 0x0ffc: (0x0102, None, None, 4, None, None, "MiniIcon"),

1670 0x0ffa: (0x0102, None, None, 4, None, None, "StoreRecordKey"),

1671 0x0f0e: (0x001f, None, None, 4, None, None, "MessageAnnotation"),

1672 0x3006: (0x001f, None, None, 4, None, None, "ProviderDisplay"),

1673 0x3009: (0x0003, None, None, 4, None, None, "ResourceFlags"),

1674 0x300a: (0x001f, None, None, 4, None, None, "ProviderDllName"),

1675 0x300c: (0x0102, None, None, 4, None, None, "ProviderUid"),

1676 0x300d: (0x0003, None, None, 4, None, None, "ProviderOrdinal"),

1677 0x3012: (0x001f, None, None, 4, None, None, "ConversationIdObsolete"),

1678 0x3014: (0x0102, None, None, 4, None, None, "BodyTag"),

1679 0x3015: (0x0014, None, None, 4, None, None, "ConversationIndexTrackingObsolete"),

1680 0x6827: (0x0003, None, None, 4, None, None, "ConversationIdHash"),

1681 0x6200: (0x0003, None, None, 4, None, None, "InternetMessageIdHash"),

1682 0x6201: (0x0003, None, None, 4, None, None, "ConversationTopicHash"),

1683 0x3660: (0x0102, None, None, 4, None, None, "ConversationTopicHashEntries"),

1684 0x3301: (0x001f, None, None, 4, None, None, "FormVersion"),

1685 0x3302: (0x0048, None, None, 4, None, None, "FormClsid"),

1686 0x3303: (0x001f, None, None, 4, None, None, "FormContactName"),

1687 0x3304: (0x001f, None, None, 4, None, None, "FormCategory"),

1688 0x3305: (0x001f, None, None, 4, None, None, "FormCategorySub"),

1689 0x3306: (0x1003, None, None, 4, None, None, "FormHostMap"),

1690 0x3307: (0x000b, None, None, 4, None, None, "FormHidden"),

1691 0x3308: (0x001f, None, None, 4, None, None, "FormDesignerName"),

1692 0x3309: (0x0048, None, None, 4, None, None, "FormDesignerGuid"),

1693 0x330a: (0x0003, None, None, 4, None, None, "FormMessageBehavior"),

1694 0x3400: (0x000b, None, None, 4, None, None, "DefaultStore"),

1695 0x3410: (0x0102, None, None, 4, None, None, "IpmSubtreeSearchKey"),

1696 0x3411: (0x0102, None, None, 4, None, None, "IpmOutboxSearchKey"),

1697 0x3412: (0x0102, None, None, 4, None, None, "IpmWastebasketSearchKey"),

1698 0x3413: (0x0102, None, None, 4, None, None, "IpmSentMailSearchKey"),

1699 0x3414: (0x0102, None, None, 4, None, None, "MdbProvider"),

1700 0x3415: (0x000d, None, None, 4, None, None, "ReceiveFolderSettings"),

1701 0x35df: (0x0003, None, None, 4, None, None, "ValidFolderMask"),

1702 0x35e0: (0x0102, None, None, 4, None, None, "IpmSubtreeEntryId"),

1703 0x35e2: (0x0102, None, None, 4, None, None, "IpmOutboxEntryId"),

1704 0x35e4: (0x0102, None, None, 4, None, None, "IpmSentMailEntryId"),

1705 0x35e5: (0x0102, None, None, 4, None, None, "ViewsEntryId"),

1706 0x35e6: (0x0102, None, None, 4, None, None, "CommonViewsEntryId"),

1707 0x35e7: (0x0102, None, None, 4, None, None, "FinderEntryId"),

1708 0x35ec: (0x0102, None, None, 4, None, None, "ConversationsFolderEntryId"),

1709 0x35ee: (0x0102, None, None, 4, None, None, "AllItemsEntryId"),

1710 0x35ef: (0x0102, None, None, 4, None, None, "SharingFolderEntryId"),

1711 0x0e5c: (0x000b, None, None, 4, None, None, "CISearchEnabled"),

1712 0x3416: (0x0102, None, None, 4, None, None, "LocalDirectoryEntryId"),

1713 0x3646: (0x0102, None, None, 4, None, None, "OwnerLogonUserConfigurationCache"),

1714 0x3420: (0x0102, None, None, 4, None, None, "ControlDataForCalendarRepairAssistant"),

1715 0x3421: (0x0102, None, None, 4, None, None, "ControlDataForSharingPolicyAssistant"),

1716 0x3422: (0x0102, None, None, 4, None, None, "ControlDataForElcAssistant"),

1717 0x3423: (0x0102, None, None, 4, None, None, "ControlDataForTopNWordsAssistant"),

1718 0x3424: (0x0102, None, None, 4, None, None, "ControlDataForJunkEmailAssistant"),

1719 0x3425: (0x0102, None, None, 4, None, None, "ControlDataForCalendarSyncAssistant"),

1720 0x3426: (0x0003, None, None, 4, None, None, "ExternalSharingCalendarSubscriptionCount"),

1721 0x3427: (0x0102, None, None, 4, None, None, "ControlDataForUMReportingAssistant"),

1722 0x3428: (0x000b, None, None, 4, None, None, "HasUMReportData"),

1723 0x3429: (0x0003, None, None, 4, None, None, "InternetCalendarSubscriptionCount"),

1724 0x342a: (0x0003, None, None, 4, None, None, "ExternalSharingContactSubscriptionCount"),

1725 0x342b: (0x0003, None, None, 4, None, None, "JunkEmailSafeListDirty"),

1726 0x342c: (0x000b, None, None, 4, None, None, "IsTopNEnabled"),

1727 0x342d: (0x0102, None, None, 4, None, None, "LastSharingPolicyAppliedId"),

1728 0x342e: (0x0102, None, None, 4, None, None, "LastSharingPolicyAppliedHash"),

1729 0x342f: (0x0040, None, None, 4, None, None, "LastSharingPolicyAppliedTime"),

1730 0x3430: (0x0040, None, None, 4, None, None, "OofScheduleStart"),

1731 0x3431: (0x0040, None, None, 4, None, None, "OofScheduleEnd"),

1732 0x35fe: (0x0102, None, None, 4, None, None, "UnsearchableItemsStream"),

1733 0x3604: (0x000d, None, None, 4, None, None, "CreateTemplates"),

1734 0x3605: (0x000d, None, None, 4, None, None, "DetailsTable"),

1735 0x3607: (0x000d, None, None, 4, None, None, "Search"),

1736 0x360b: (0x0003, None, None, 4, None, None, "Status"),

1737 0x360d: (0x1003, None, None, 4, None, None, "ContentsSortOrder"),

1738 0x3611: (0x0102, None, None, 4, None, None, "DefCreateDl"),

1739 0x3612: (0x0102, None, None, 4, None, None, "DefCreateMailuser"),

1740 0x3614: (0x0014, None, None, 4, None, None, "ContainerModifyVersion"),

1741 0x3615: (0x0102, None, None, 4, None, None, "AbProviderId"),

1742 0x3616: (0x0102, None, None, 4, None, None, "DefaultViewEntryId"),

1743 0x3617: (0x0003, None, None, 4, None, None, "AssocContentCount"),

1744 0x3644: (0x0003, None, None, 4, None, None, "SearchFolderMsgCount"),

1745 0x361f: (0x000b, None, None, 4, None, None, "AllowAgeout"),

1746 0x6787: (0x101f, None, None, 4, None, None, "SearchBacklinkNames"),

1747 0x3700: (0x0102, None, None, 4, None, None, "AttachmentX400Parameters"),

1748 0x3716: (0x001f, None, None, 4, None, None, "AttachDisposition"),

1749 0x0eb0: (0x0003, None, None, 4, None, None, "SearchResultKind"),

1750 0x0eab: (0x001f, None, None, 4, None, None, "SearchFullText"),

1751 0x0eac: (0x001f, None, None, 4, None, None, "SearchFullTextSubject"),

1752 0x0ead: (0x001f, None, None, 4, None, None, "SearchFullTextBody"),

1753 0x0eae: (0x001f, None, None, 4, None, None, "SearchFullTextConversationIndex"),

1754 0x0eaf: (0x001f, None, None, 4, None, None, "SearchAllIndexedProps"),

1755 0x0eb1: (0x001f, None, None, 4, None, None, "SearchRecipients"),

1756 0x0eb2: (0x001f, None, None, 4, None, None, "SearchRecipientsTo"),

1757 0x0eb3: (0x001f, None, None, 4, None, None, "SearchRecipientsCc"),

1758 0x0eb4: (0x001f, None, None, 4, None, None, "SearchRecipientsBcc"),

1759 0x0eb5: (0x001f, None, None, 4, None, None, "SearchAccountTo"),

1760 0x0eb6: (0x001f, None, None, 4, None, None, "SearchAccountCc"),

1761 0x0eb7: (0x001f, None, None, 4, None, None, "SearchAccountBcc"),

1762 0x0eb8: (0x001f, None, None, 4, None, None, "SearchEmailAddressTo"),

1763 0x0eb9: (0x001f, None, None, 4, None, None, "SearchEmailAddressCc"),

1764 0x0eba: (0x001f, None, None, 4, None, None, "SearchEmailAddressBcc"),

1765 0x0ebb: (0x001f, None, None, 4, None, None, "SearchSmtpAddressTo"),

1766 0x0ebc: (0x001f, None, None, 4, None, None, "SearchSmtpAddressCc"),

1767 0x0ebd: (0x001f, None, None, 4, None, None, "SearchSmtpAddressBcc"),

1768 0x0ebe: (0x001f, None, None, 4, None, None, "SearchSender"),

1769 0x0ebf: (0x001f, None, None, 4, None, None, "SendYearHigh"),

1770 0x0ec0: (0x001f, None, None, 4, None, None, "SendYearLow"),

1771 0x0ec1: (0x001f, None, None, 4, None, None, "SendMonth"),

1772 0x0ec2: (0x001f, None, None, 4, None, None, "SendDayHigh"),

1773 0x0ec3: (0x001f, None, None, 4, None, None, "SendDayLow"),

1774 0x0ec4: (0x001f, None, None, 4, None, None, "SendQuarterHigh"),

1775 0x0ec5: (0x001f, None, None, 4, None, None, "SendQuarterLow"),

1776 0x0ec6: (0x001f, None, None, 4, None, None, "RcvdYearHigh"),

1777 0x0ec7: (0x001f, None, None, 4, None, None, "RcvdYearLow"),

1778 0x0ec8: (0x001f, None, None, 4, None, None, "RcvdMonth"),

1779 0x0ec9: (0x001f, None, None, 4, None, None, "RcvdDayHigh"),

1780 0x0eca: (0x001f, None, None, 4, None, None, "RcvdDayLow"),

1781 0x0ecb: (0x001f, None, None, 4, None, None, "RcvdQuarterHigh"),

1782 0x0ecc: (0x001f, None, None, 4, None, None, "RcvdQuarterLow"),

1783 0x0ecd: (0x000b, None, None, 4, None, None, "IsIrmMessage"),

1784 0x3a01: (0x0102, None, None, 4, None, None, "AlternateRecipient"),

1785 0x3a03: (0x000b, None, None, 4, None, None, "ConversionProhibited"),

1786 0x3a04: (0x000b, None, None, 4, None, None, "DiscloseRecipients"),

1787 0x3a0e: (0x000b, None, None, 4, None, None, "MailPermission"),

1788 0x3a13: (0x001f, None, None, 4, None, None, "OriginalDisplayName"),

1789 0x3a14: (0x0102, None, None, 4, None, None, "OriginalSearchKey"),

1790 0x3a52: (0x0048, None, None, 4, None, None, "ContactVersion"),

1791 0x3a53: (0x1102, None, None, 4, None, None, "ContactEntryIds"),

1792 0x3a54: (0x101f, None, None, 4, None, None, "ContactAddrTypes"),

1793 0x3a55: (0x0003, None, None, 4, None, None, "ContactDefaultAddressIndex"),

1794 0x3a56: (0x101f, None, None, 4, None, None, "ContactEmailAddresses"),

1795 0x3d00: (0x0102, None, None, 4, None, None, "StoreProviders"),

1796 0x3d01: (0x0102, None, None, 4, None, None, "AbProviders"),

1797 0x3d02: (0x0102, None, None, 4, None, None, "TransportProviders"),

1798 0x3d04: (0x000b, None, None, 4, None, None, "DefaultProfile"),

1799 0x3d05: (0x1102, None, None, 4, None, None, "AbSearchPath"),

1800 0x3d06: (0x0102, None, None, 4, None, None, "AbDefaultDir"),

1801 0x3d07: (0x0102, None, None, 4, None, None, "AbDefaultPab"),

1802 0x3d08: (0x0102, None, None, 4, None, None, "FilteringHooks"),

1803 0x3d09: (0x001f, None, None, 4, None, None, "ServiceName"),

1804 0x3d0a: (0x001f, None, None, 4, None, None, "ServiceDllName"),

1805 0x3d0c: (0x0102, None, None, 4, None, None, "ServiceUid"),

1806 0x3d0d: (0x0102, None, None, 4, None, None, "ServiceExtraUids"),

1807 0x3d0e: (0x0102, None, None, 4, None, None, "Services"),

1808 0x3d0f: (0x101f, None, None, 4, None, None, "ServiceSupportFiles"),

1809 0x3d10: (0x101f, None, None, 4, None, None, "ServiceDeleteFiles"),

1810 0x3d11: (0x0102, None, None, 4, None, None, "AbSearchPathUpdate"),

1811 0x3d12: (0x001f, None, None, 4, None, None, "ProfileName"),

1812 0x3fe9: (0x0003, None, None, 4, None, None, "EformsLocaleId"),

1813 0x6620: (0x0102, None, None, 4, None, None, "NonIpmSubtreeEntryId"),

1814 0x6621: (0x0102, None, None, 4, None, None, "EFormsRegistryEntryId"),

1815 0x6623: (0x0102, None, None, 4, None, None, "OfflineAddressBookEntryId"),

1816 0x6624: (0x0102, None, None, 4, None, None, "LocaleEFormsRegistryEntryId"),

1817 0x6625: (0x0102, None, None, 4, None, None, "LocalSiteFreeBusyEntryId"),

1818 0x6626: (0x0102, None, None, 4, None, None, "LocalSiteOfflineAddressBookEntryId"),

1819 0x6810: (0x0003, None, None, 4, None, None, "OofStateEx"),

1820 0x6813: (0x0040, None, None, 4, None, None, "OofStateUserChangeTime"),

1821 0x6814: (0x0102, None, None, 4, None, None, "UserOofSettingsItemId"),

1822 0x35e3: (0x0102, None, None, 4, None, None, "IpmWasteBasketEntryId"),

1823 0x3011: (0x0102, None, None, 4, None, None, "ForceUserClientBackoff"),

1824 0x6618: (0x0003, None, None, 4, None, None, "InTransitStatus"),

1825 0x662a: (0x000b, None, None, 4, None, None, "TransferEnabled"),

1826 0x65f6: (0x101f, None, None, 4, None, None, "ImapSubscribeList"),

1827 0x676c: (0x0102, None, None, 4, None, None, "MapiEntryIdGuid"),

1828 0x662f: (0x000d, None, None, 4, None, None, "FastTransfer"),

1829 0x681a: (0x000b, None, None, 4, None, None, "MailboxQuarantined"),

1830 0x6761: (0x0102, None, None, 4, None, None, "NextLocalId"),

1831 0x6670: (0x0102, None, None, 4, None, None, "LongTermEntryIdFromTable"),

1832 0x0e27: (0x0102, None, None, 4, None, None, "NTSD"),

1833 0x3d21: (0x0102, None, None, 4, None, None, "AdminNTSD"),

1834 0x0f00: (0x0102, None, None, 4, None, None, "FreeBusyNTSD"),

1835 0x0e3f: (0x0102, None, None, 4, None, None, "AclTableAndNTSD"),

1836 0x6707: (0x001f, None, None, 4, None, None, "UrlName"),

1837 0x6698: (0x0102, None, None, 4, None, None, "ReplicaList"),

1838 0x663f: (0x000b, None, None, 4, None, None, "HasModerator"),

1839 0x3fe6: (0x000b, None, None, 4, None, None, "PublishInAddressBook"),

1840 0x6699: (0x0003, None, None, 4, None, None, "OverallAgeLimit"),

1841 0x66c4: (0x0003, None, None, 4, None, None, "RetentionAgeLimit"),

1842 0x6779: (0x0003, None, None, 4, None, None, "PfQuotaStyle"),

1843 0x677b: (0x0003, None, None, 4, None, None, "PfStorageQuota"),

1844 0x6721: (0x0003, None, None, 4, None, None, "PfOverHardQuotaLimit"),

1845 0x6722: (0x0003, None, None, 4, None, None, "PfMsgSizeLimit"),

1846 0x6690: (0x0003, None, None, 4, None, None, "ReplicationStyle"),

1847 0x6691: (0x0102, None, None, 4, None, None, "ReplicationSchedule"),

1848 0x66c5: (0x000b, None, None, 4, None, None, "DisablePeruserRead"),

1849 0x6701: (0x0003, None, None, 4, None, None, "PfMsgAgeLimit"),

1850 0x671d: (0x0102, None, None, 4, None, None, "PfProxy"),

1851 0x3d2f: (0x0003, None, None, 4, None, None, "SystemFolderFlags"),

1852 0x3fd9: (0x001f, None, None, 4, None, None, "Preview"),

1853 0x6828: (0x0102, None, None, 4, None, None, "LocalDirectory"),

1854 0x0e63: (0x0003, None, None, 4, None, None, "SendFlags"),

1855 0x3fe1: (0x000d, None, None, 4, None, None, "RulesTable"),

1856 0x4080: (0x0003, None, None, 4, None, None, "OofReplyType"),

1857 0x4081: (0x001f, None, None, 4, None, None, "ElcAutoCopyLabel"),

1858 0x6716: (0x0102, None, None, 4, None, None, "ElcAutoCopyTag"),

1859 0x6717: (0x0102, None, None, 4, None, None, "ElcMoveDate"),

1860 0x6829: (0x001f, None, None, 4, None, None, "MemberEmail"),

1861 0x682a: (0x001f, None, None, 4, None, None, "MemberExternalId"),

1862 0x682b: (0x0102, None, None, 4, None, None, "MemberSID"),

1863 0x662c: (0x000d, None, None, 4, None, None, "HierarchySynchronizer"),

1864 0x662d: (0x000d, None, None, 4, None, None, "ContentsSynchronizer"),

1865 0x662e: (0x000d, None, None, 4, None, None, "Collector"),

1866 0x6609: (0x000b, None, None, 4, None, None, "SendRichInfoOnly"),

1867 0x6637: (0x000b, None, None, 4, None, None, "SendNativeBody"),

1868 0x6608: (0x0003, None, None, 4, None, None, "InternetTransmitInfo"),

1869 0x6610: (0x0003, None, None, 4, None, None, "InternetMessageFormat"),

1870 0x6611: (0x0003, None, None, 4, None, None, "InternetMessageTextFormat"),

1871 0x6615: (0x0003, None, None, 4, None, None, "InternetRequestLines"),

1872 0x6616: (0x0003, None, None, 4, None, None, "InternetHeaderLength"),

1873 0x6617: (0x0003, None, None, 4, None, None, "InternetAddressingOptions"),

1874 0x661a: (0x001f, None, None, 4, None, None, "InternetTemporaryFilename"),

1875 0x6570: (0x0003, None, None, 4, None, None, "InternetExternalNewsItem"),

1876 0x661e: (0x0003, None, None, 4, None, None, "InternetRequestHeaders"),

1877 0x6631: (0x001f, None, None, 4, None, None, "InternetClientHostIPName"),

1878 0x66c0: (0x0040, None, None, 4, None, None, "ConnectTime"),

1879 0x66c1: (0x0003, None, None, 4, None, None, "ConnectFlags"),

1880 0x66c2: (0x0003, None, None, 4, None, None, "LogonCount"),

1881 0x669f: (0x001f, None, None, 4, None, None, "HostAddress"),

1882 0x66a0: (0x001f, None, None, 4, None, None, "NTUserName"),

1883 0x66a2: (0x0040, None, None, 4, None, None, "LastLogonTime"),

1884 0x66a3: (0x0040, None, None, 4, None, None, "LastLogoffTime"),

1885 0x66a4: (0x0003, None, None, 4, None, None, "StorageLimitInformation"),

1886 0x66a5: (0x000b, None, None, 4, None, None, "InternetMdns"),

1887 0x669b: (0x0014, None, None, 4, None, None, "DeletedMessageSizeExtended"),

1888 0x669c: (0x0014, None, None, 4, None, None, "DeletedNormalMessageSizeExtended"),

1889 0x669d: (0x0014, None, None, 4, None, None, "DeleteAssocMessageSizeExtended"),

1890 0x6640: (0x0003, None, None, 4, None, None, "DeletedMsgCount"),

1891 0x6708: (0x0040, None, None, 4, None, None, "DateDiscoveredAbsentInDS"),

1892 0x6778: (0x001f, None, None, 4, None, None, "AdminNickName"),

1893 0x6723: (0x0003, None, None, 4, None, None, "QuotaReceiveThreshold"),

1894 0x66df: (0x0040, None, None, 4, None, None, "LastOpTime"),

1895 0x66ff: (0x0003, None, None, 4, None, None, "PacketRate"),

1896 0x66cc: (0x0040, None, None, 4, None, None, "LogonTime"),

1897 0x66cd: (0x0003, None, None, 4, None, None, "LogonFlags"),

1898 0x6764: (0x0014, None, None, 4, None, None, "MsgHeaderFid"),

1899 0x66c9: (0x001f, None, None, 4, None, None, "MailboxDisplayName"),

1900 0x66c8: (0x001f, None, None, 4, None, None, "MailboxDN"),

1901 0x66cb: (0x001f, None, None, 4, None, None, "UserDisplayName"),

1902 0x66ca: (0x001f, None, None, 4, None, None, "UserDN"),

1903 0x6710: (0x0014, None, None, 4, None, None, "SessionId"),

1904 0x66cf: (0x0003, None, None, 4, None, None, "OpenMessageCount"),

1905 0x66d0: (0x0003, None, None, 4, None, None, "OpenFolderCount"),

1906 0x66d1: (0x0003, None, None, 4, None, None, "OpenAttachCount"),

1907 0x66d2: (0x0003, None, None, 4, None, None, "OpenContentCount"),

1908 0x66d3: (0x0003, None, None, 4, None, None, "OpenHierarchyCount"),

1909 0x66d4: (0x0003, None, None, 4, None, None, "OpenNotifyCount"),

1910 0x66d5: (0x0003, None, None, 4, None, None, "OpenAttachTableCount"),

1911 0x66d6: (0x0003, None, None, 4, None, None, "OpenACLTableCount"),

1912 0x66d7: (0x0003, None, None, 4, None, None, "OpenRulesTableCount"),

1913 0x66d8: (0x0003, None, None, 4, None, None, "OpenStreamsCount"),

1914 0x66d9: (0x0003, None, None, 4, None, None, "OpenFXSrcStreamCount"),

1915 0x66da: (0x0003, None, None, 4, None, None, "OpenFXDestStreamCount"),

1916 0x66db: (0x0003, None, None, 4, None, None, "OpenContentRegularCount"),

1917 0x66dc: (0x0003, None, None, 4, None, None, "OpenContentCategCount"),

1918 0x66dd: (0x0003, None, None, 4, None, None, "OpenContentRestrictedCount"),

1919 0x66de: (0x0003, None, None, 4, None, None, "OpenContentCategAndRestrictedCount"),

1920 0x66b8: (0x0003, None, None, 4, None, None, "MessagingOpRate"),

1921 0x66b9: (0x0003, None, None, 4, None, None, "FolderOpRate"),

1922 0x66ba: (0x0003, None, None, 4, None, None, "TableOpRate"),

1923 0x66bb: (0x0003, None, None, 4, None, None, "TransferOpRate"),

1924 0x66bc: (0x0003, None, None, 4, None, None, "StreamOpRate"),

1925 0x66bd: (0x0003, None, None, 4, None, None, "ProgressOpRate"),

1926 0x66be: (0x0003, None, None, 4, None, None, "OtherOpRate"),

1927 0x66bf: (0x0003, None, None, 4, None, None, "TotalOpRate"),

1928 0x671f: (0x000b, None, None, 4, None, None, "PfProxyRequired"),

1929 0x6724: (0x0102, None, None, 4, None, None, "ClientIP"),

1930 0x6725: (0x0102, None, None, 4, None, None, "ClientIPMask"),

1931 0x6726: (0x0102, None, None, 4, None, None, "ClientMacAddress"),

1932 0x6727: (0x001f, None, None, 4, None, None, "ClientMachineName"),

1933 0x6728: (0x0003, None, None, 4, None, None, "ClientAdapterSpeed"),

1934 0x6729: (0x0003, None, None, 4, None, None, "ClientRpcsAttempted"),

1935 0x672a: (0x0003, None, None, 4, None, None, "ClientRpcsSucceeded"),

1936 0x672b: (0x0102, None, None, 4, None, None, "ClientRpcErrors"),

1937 0x672c: (0x0003, None, None, 4, None, None, "ClientLatency"),

1938 0x666f: (0x000b, None, None, 4, None, None, "SubmittedByAdmin"),

1939 0x680d: (0x0003, None, None, 4, None, None, "ObjectClassFlags"),

1940 0x682d: (0x0003, None, None, 4, None, None, "MaxMessageSize"),

1941 0x672d: (0x0003, None, None, 4, None, None, "TimeInServer"),

1942 0x672e: (0x0003, None, None, 4, None, None, "TimeInCPU"),

1943 0x672f: (0x0003, None, None, 4, None, None, "ROPCount"),

1944 0x6730: (0x0003, None, None, 4, None, None, "PageRead"),

1945 0x6731: (0x0003, None, None, 4, None, None, "PagePreread"),

1946 0x6732: (0x0003, None, None, 4, None, None, "LogRecordCount"),

1947 0x6733: (0x0003, None, None, 4, None, None, "LogRecordBytes"),

1948 0x6734: (0x0003, None, None, 4, None, None, "LdapReads"),

1949 0x6735: (0x0003, None, None, 4, None, None, "LdapSearches"),

1950 0x6736: (0x001f, None, None, 4, None, None, "DigestCategory"),

1951 0x6737: (0x0003, None, None, 4, None, None, "SampleId"),

1952 0x6738: (0x0040, None, None, 4, None, None, "SampleTime"),

1953 0x661f: (0x0102, None, None, 4, None, None, "DeferredActionFolderEntryID"),

1954 0x3fff: (0x0003, None, None, 4, None, None, "RulesSize"),

1955 0x668d: (0x0002, None, None, 4, None, None, "RuleVersion"),

1956 0x65f2: (0x0002, None, None, 4, None, None, "RuleMsgVersion"),

1957 0x3642: (0x0102, None, None, 4, None, None, "DAMReferenceMessageEntryID"),

1958 0x65f5: (0x0040, None, None, 4, None, None, "ImapInternalDate"),

1959 0x6751: (0x0003, None, None, 4, None, None, "NextArticleId"),

1960 0x6752: (0x0003, None, None, 4, None, None, "ImapLastArticleId"),

1961 0x0e2f: (0x0003, None, None, 4, None, None, "ImapId"),

1962 0x0e32: (0x0002, None, None, 4, None, None, "OriginalSourceServerVersion"),

1963 0x5806: (0x000b, None, None, 4, None, None, "DeliverAsRead"),

1964 0x67fe: (0x0014, None, None, 4, None, None, "ReadCn"),

1965 0x6808: (0x0003, None, None, 4, None, None, "EventMask"),

1966 0x676a: (0x0102, None, None, 4, None, None, "EventMailboxGuid"),

1967 0x6815: (0x0003, None, None, 4, None, None, "DocumentId"),

1968 0x6702: (0x000b, None, None, 4, None, None, "BeingDeleted"),

1969 0x678d: (0x0102, None, None, 4, None, None, "FolderCDN"),

1970 0x67f6: (0x0003, None, None, 4, None, None, "ModifiedCount"),

1971 0x67f7: (0x0003, None, None, 4, None, None, "DeleteState"),

1972 0x66fe: (0x001f, None, None, 4, None, None, "AdminDisplayName"),

1973 0x66a9: (0x0040, None, None, 4, None, None, "LastAccessTime"),

1974 0x6830: (0x0040, None, None, 4, None, None, "LastUserAccessTime"),

1975 0x6831: (0x0040, None, None, 4, None, None, "LastUserModificationTime"),

1976 0x66b4: (0x0014, None, None, 4, None, None, "AssocMessageSizeExtended"),

1977 0x66b5: (0x001f, None, None, 4, None, None, "FolderPathName"),

1978 0x66b6: (0x0003, None, None, 4, None, None, "OwnerCount"),

1979 0x66b7: (0x0003, None, None, 4, None, None, "ContactCount"),

1980 0x7c01: (0x001f, None, None, 4, None, None, "MessageAudioNotes"),

1981 0x3ff5: (0x0003, None, None, 4, None, None, "StorageQuotaLimit"),

1982 0x3ff6: (0x0003, None, None, 4, None, None, "ExcessStorageUsed"),

1983 0x3ff7: (0x001f, None, None, 4, None, None, "SvrGeneratingQuotaMsg"),

1984 0x3fc2: (0x000b, None, None, 4, None, None, "PrimaryMbxOverQuota"),

1985 0x65c6: (0x0003, None, None, 4, None, None, "SecureSubmitFlags"),

1986 0x673e: (0x0102, None, None, 4, None, None, "PropertyGroupInformation"),

1987 0x6784: (0x0102, None, None, 4, None, None, "SearchRestriction"),

1988 0x67b0: (0x00fd, None, None, 4, None, None, "ViewRestriction"),

1989 0x6788: (0x0003, None, None, 4, None, None, "LCIDRestriction"),

1990 0x676e: (0x0003, None, None, 4, None, None, "LCID"),

1991 0x67f3: (0x0040, None, None, 4, None, None, "ViewAccessTime"),

1992 0x689e: (0x0003, None, None, 4, None, None, "CategCount"),

1993 0x6819: (0x000b, None, None, 4, None, None, "SoftDeletedFilter"),

1994 0x681b: (0x000b, None, None, 4, None, None, "ConversationsFilter"),

1995 0x689c: (0x0003, None, None, 4, None, None, "DVUIdLowest"),

1996 0x689d: (0x0003, None, None, 4, None, None, "DVUIdHighest"),

1997 0x6880: (0x101f, None, None, 4, None, None, "ConversationMvFrom"),

1998 0x6881: (0x101f, None, None, 4, None, None, "ConversationMvFromMailboxWide"),

1999 0x6882: (0x101f, None, None, 4, None, None, "ConversationMvTo"),

2000 0x6883: (0x101f, None, None, 4, None, None, "ConversationMvToMailboxWide"),

2001 0x6884: (0x0040, None, None, 4, None, None, "ConversationMsgDeliveryTime"),

2002 0x6885: (0x0040, None, None, 4, None, None, "ConversationMsgDeliveryTimeMailboxWide"),

2003 0x6886: (0x101f, None, None, 4, None, None, "ConversationCategories"),

2004 0x6887: (0x101f, None, None, 4, None, None, "ConversationCategoriesMailboxWide"),

2005 0x6888: (0x0003, None, None, 4, None, None, "ConversationFlagStatus"),

2006 0x6889: (0x0003, None, None, 4, None, None, "ConversationFlagStatusMailboxWide"),

2007 0x688a: (0x0040, None, None, 4, None, None, "ConversationFlagCompleteTime"),

2008 0x688b: (0x0040, None, None, 4, None, None, "ConversationFlagCompleteTimeMailboxWide"),

2009 0x688c: (0x000b, None, None, 4, None, None, "ConversationHasAttach"),

2010 0x688d: (0x000b, None, None, 4, None, None, "ConversationHasAttachMailboxWide"),

2011 0x688e: (0x0003, None, None, 4, None, None, "ConversationContentCount"),

2012 0x688f: (0x0003, None, None, 4, None, None, "ConversationContentCountMailboxWide"),

2013 0x6893: (0x0003, None, None, 4, None, None, "ConversationMessageSizeMailboxWide"),

2014 0x6894: (0x101f, None, None, 4, None, None, "ConversationMessageClasses"),

2015 0x6895: (0x101f, None, None, 4, None, None, "ConversationMessageClassesMailboxWide"),

2016 0x6896: (0x0003, None, None, 4, None, None, "ConversationReplyForwardState"),

2017 0x6897: (0x0003, None, None, 4, None, None, "ConversationReplyForwardStateMailboxWide"),

2018 0x6898: (0x0003, None, None, 4, None, None, "ConversationImportance"),

2019 0x6899: (0x0003, None, None, 4, None, None, "ConversationImportanceMailboxWide"),

2020 0x689a: (0x101f, None, None, 4, None, None, "ConversationMvFromUnread"),

2021 0x689b: (0x101f, None, None, 4, None, None, "ConversationMvFromUnreadMailboxWide"),

2022 0x68a0: (0x1102, None, None, 4, None, None, "ConversationMvItemIds"),

2023 0x68a1: (0x1102, None, None, 4, None, None, "ConversationMvItemIdsMailboxWide"),

2024 0x68a2: (0x000b, None, None, 4, None, None, "ConversationHasIrm"),

2025 0x68a3: (0x000b, None, None, 4, None, None, "ConversationHasIrmMailboxWide"),

2026 0x682c: (0x0040, None, None, 4, None, None, "TransportSyncSubscriptionListTimestamp"),

2027 0x3690: (0x0102, None, None, 4, None, None, "TransportRulesSnapshot"),

2028 0x3691: (0x0048, None, None, 4, None, None, "TransportRulesSnapshotId"),

2029 0x7c05: (0x0040, None, None, 4, None, None, "DeletedMessageSizeExtendedLastModificationTime"),

2030 0x0082: (0x001f, None, None, 4, None, None, "ReportOriginalSender"),

2031 0x0083: (0x001f, None, None, 4, None, None, "ReportDispositionToNames"),

2032 0x0084: (0x001f, None, None, 4, None, None, "ReportDispositionToEmailAddress"),

2033 0x0085: (0x001f, None, None, 4, None, None, "ReportDispositionOptions"),

2034 0x0086: (0x0002, None, None, 4, None, None, "RichContent"),

2035 0x0100: (0x101f, None, None, 4, None, None, "AdministratorEMail"),

2036 0x0c24: (0x0102, None, None, 4, None, None, "ParticipantSID"),

2037 0x0c25: (0x0102, None, None, 4, None, None, "ParticipantGuid"),

2038 0x0c26: (0x001f, None, None, 4, None, None, "ToGroupExpansionRecipients"),

2039 0x0c27: (0x001f, None, None, 4, None, None, "CcGroupExpansionRecipients"),

2040 0x0c28: (0x001f, None, None, 4, None, None, "BccGroupExpansionRecipients"),

2041 0x0e0b: (0x0102, None, None, 4, None, None, "ImmutableEntryId"),

2042 0x0e2e: (0x0003, None, None, 4, None, None, "MessageIsHidden"),

2043 0x0e33: (0x001f, None, None, 4, None, None, "OlcPopId"),

2044 0x0e38: (0x0003, None, None, 4, None, None, "ReplFlags"),

2045 0x0e40: (0x0102, None, None, 4, None, None, "SenderGuid"),

2046 0x0e41: (0x0102, None, None, 4, None, None, "SentRepresentingGuid"),

2047 0x0e42: (0x0102, None, None, 4, None, None, "OriginalSenderGuid"),

2048 0x0e43: (0x0102, None, None, 4, None, None, "OriginalSentRepresentingGuid"),

2049 0x0e44: (0x0102, None, None, 4, None, None, "ReadReceiptGuid"),

2050 0x0e45: (0x0102, None, None, 4, None, None, "ReportGuid"),

2051 0x0e46: (0x0102, None, None, 4, None, None, "OriginatorGuid"),

2052 0x0e47: (0x0102, None, None, 4, None, None, "ReportDestinationGuid"),

2053 0x0e48: (0x0102, None, None, 4, None, None, "OriginalAuthorGuid"),

2054 0x0e49: (0x0102, None, None, 4, None, None, "ReceivedByGuid"),

2055 0x0e4a: (0x0102, None, None, 4, None, None, "ReceivedRepresentingGuid"),

2056 0x0e4b: (0x0102, None, None, 4, None, None, "CreatorGuid"),

2057 0x0e4c: (0x0102, None, None, 4, None, None, "LastModifierGuid"),

2058 0x0e4d: (0x0102, None, None, 4, None, None, "SenderSID"),

2059 0x0e4e: (0x0102, None, None, 4, None, None, "SentRepresentingSID"),

2060 0x0e4f: (0x0102, None, None, 4, None, None, "OriginalSenderSid"),

2061 0x0e50: (0x0102, None, None, 4, None, None, "OriginalSentRepresentingSid"),

2062 0x0e51: (0x0102, None, None, 4, None, None, "ReadReceiptSid"),

2063 0x0e52: (0x0102, None, None, 4, None, None, "ReportSid"),

2064 0x0e53: (0x0102, None, None, 4, None, None, "OriginatorSid"),

2065 0x0e54: (0x0102, None, None, 4, None, None, "ReportDestinationSid"),

2066 0x0e55: (0x0102, None, None, 4, None, None, "OriginalAuthorSid"),

2067 0x0e56: (0x0102, None, None, 4, None, None, "ReceivedBySid"),

2068 0x0e57: (0x0102, None, None, 4, None, None, "ReceivedRepresentingSid"),

2069 0x0e58: (0x0102, None, None, 4, None, None, "CreatorSID"),

2070 0x0e59: (0x0102, None, None, 4, None, None, "LastModifierSid"),

2071 0x0e5a: (0x0102, None, None, 4, None, None, "RecipientCAI"),

2072 0x0e5b: (0x0102, None, None, 4, None, None, "ConversationCreatorSID"),

2073 0x0e5d: (0x000b, None, None, 4, None, None, "IsUserKeyDecryptPossible"),

2074 0x0e5e: (0x0003, None, None, 4, None, None, "MaxIndices"),

2075 0x0e5f: (0x0014, None, None, 4, None, None, "SourceFid"),

2076 0x0e60: (0x0102, None, None, 4, None, None, "PFContactsGuid"),

2077 0x0e61: (0x0003, None, None, 4, None, None, "UrlCompNamePostfix"),

2078 0x0e62: (0x000b, None, None, 4, None, None, "URLCompNameSet"),

2079 0x0e64: (0x0003, None, None, 4, None, None, "DeletedSubfolderCount"),

2080 0x0e68: (0x0003, None, None, 4, None, None, "MaxCachedViews"),

2081 0x0e6b: (0x001f, None, None, 4, None, None, "AdminNTSecurityDescriptorAsXML"),

2082 0x0e6c: (0x001f, None, None, 4, None, None, "CreatorSidAsXML"),

2083 0x0e6d: (0x001f, None, None, 4, None, None, "LastModifierSidAsXML"),

2084 0x0e6e: (0x001f, None, None, 4, None, None, "SenderSIDAsXML"),

2085 0x0e6f: (0x001f, None, None, 4, None, None, "SentRepresentingSidAsXML"),

2086 0x0e70: (0x001f, None, None, 4, None, None, "OriginalSenderSIDAsXML"),

2087 0x0e71: (0x001f, None, None, 4, None, None, "OriginalSentRepresentingSIDAsXML"),

2088 0x0e72: (0x001f, None, None, 4, None, None, "ReadReceiptSIDAsXML"),

2089 0x0e73: (0x001f, None, None, 4, None, None, "ReportSIDAsXML"),

2090 0x0e74: (0x001f, None, None, 4, None, None, "OriginatorSidAsXML"),

2091 0x0e75: (0x001f, None, None, 4, None, None, "ReportDestinationSIDAsXML"),

2092 0x0e76: (0x001f, None, None, 4, None, None, "OriginalAuthorSIDAsXML"),

2093 0x0e77: (0x001f, None, None, 4, None, None, "ReceivedBySIDAsXML"),

2094 0x0e78: (0x001f, None, None, 4, None, None, "ReceivedRepersentingSIDAsXML"),

2095 0x0e7a: (0x0102, None, None, 4, None, None, "MergeMidsetDeleted"),

2096 0x0e7b: (0x0102, None, None, 4, None, None, "ReserveRangeOfIDs"),

2097 0x0e97: (0x001f, None, None, 4, None, None, "AddrTo"),

2098 0x0e98: (0x001f, None, None, 4, None, None, "AddrCc"),

2099 0x0e9f: (0x101f, None, None, 4, None, None, "EntourageSentHistory"),

2100 0x0ea2: (0x0003, None, None, 4, None, None, "ProofInProgress"),

2101 0x0ea5: (0x001f, None, None, 4, None, None, "SearchAttachmentsOLK"),

2102 0x0ea6: (0x001f, None, None, 4, None, None, "SearchRecipEmailTo"),

2103 0x0ea7: (0x001f, None, None, 4, None, None, "SearchRecipEmailCc"),

2104 0x0ea8: (0x001f, None, None, 4, None, None, "SearchRecipEmailBcc"),

2105 0x0eaa: (0x0003, None, None, 4, None, None, "SFGAOFlags"),

2106 0x0ece: (0x000b, None, None, 4, None, None, "SearchIsPartiallyIndexed"),

2107 0x0ecf: (0x001f, None, None, 4, None, None, "SearchUniqueBody"),

2108 0x0ed0: (0x0003, None, None, 4, None, None, "SearchErrorCode"),

2109 0x0ed1: (0x0040, None, None, 4, None, None, "SearchReceivedTime"),

2110 0x0ed2: (0x0003, None, None, 4, None, None, "SearchNumberOfTopRankedResults"),

2111 0x0ed3: (0x0003, None, None, 4, None, None, "SearchControlFlags"),

2112 0x0ed4: (0x001f, None, None, 4, None, None, "SearchRankingModel"),

2113 0x0ed5: (0x0003, None, None, 4, None, None, "SearchMinimumNumberOfDateOrderedResults"),

2114 0x0ed6: (0x001f, None, None, 4, None, None, "SearchSharePointOnlineSearchableProps"),

2115 0x0ed7: (0x0002, None, None, 4, None, None, "SearchRelevanceRankedResults"),

2116 0x0edd: (0x0102, None, None, 4, None, None, "MailboxSyncState"),

2117 0x0f01: (0x0040, None, None, 4, None, None, "RenewTime"),

2118 0x0f02: (0x0040, None, None, 4, None, None, "DeliveryOrRenewTime"),

2119 0x0f03: (0x0102, None, None, 4, None, None, "ConversationThreadId"),

2120 0x0f04: (0x0003, None, None, 4, None, None, "LikeCount"),

2121 0x0f05: (0x0002, None, None, 4, None, None, "RichContentDeprecated"),

2122 0x0f06: (0x0003, None, None, 4, None, None, "PeopleCentricConversationId"),

2123 0x0f07: (0x0040, None, None, 4, None, None, "ReturnTime"),

2124 0x0f08: (0x0040, None, None, 4, None, None, "LastAttachmentsProcessedTime"),

2125 0x0f0a: (0x0040, None, None, 4, None, None, "LastActivityTime"),

2126 0x100a: (0x0102, None, None, 4, None, None, "AlternateBestBody"),

2127 0x100c: (0x0102, None, None, 4, None, None, "IsIntegJobCorruptions"),

2128 0x100e: (0x0002, None, None, 4, None, None, "IsIntegJobPriority"),

2129 0x100f: (0x0005, None, None, 4, None, None, "IsIntegJobTimeInServer"),

2130 0x1017: (0x0102, None, None, 4, None, None, "AnnotationToken"),

2131 0x1030: (0x001f, None, None, 4, None, None, "InternetApproved"),

2132 0x1033: (0x001f, None, None, 4, None, None, "InternetFollowupTo"),

2133 0x1036: (0x001f, None, None, 4, None, None, "InetNewsgroups"),

2134 0x103d: (0x0102, None, None, 4, None, None, "PostReplyFolderEntries"),

2135 0x1040: (0x001f, None, None, 4, None, None, "NNTPXRef"),

2136 0x1084: (0x0003, None, None, 4, None, None, "Relevance"),

2137 0x1092: (0x0003, None, None, 4, None, None, "FormatPT"),

2138 0x10c0: (0x0102, None, None, 4, None, None, "SMTPTempTblData"),

2139 0x10c1: (0x0003, None, None, 4, None, None, "SMTPTempTblData2"),

2140 0x10c2: (0x0102, None, None, 4, None, None, "SMTPTempTblData3"),

2141 0x10f0: (0x0102, None, None, 4, None, None, "IMAPCachedMsgSize"),

2142 0x10f2: (0x000b, None, None, 4, None, None, "DisableFullFidelity"),

2143 0x10f3: (0x001f, None, None, 4, None, None, "UrlCompName"),

2144 0x10f5: (0x000b, None, None, 4, None, None, "AttrSystem"),

2145 0x1204: (0x1002, None, None, 4, None, None, "PredictedActions"),

2146 0x1205: (0x1002, None, None, 4, None, None, "GroupingActions"),

2147 0x1206: (0x0003, None, None, 4, None, None, "PredictedActionsSummary"),

2148 0x1207: (0x000b, None, None, 4, None, None, "IsClutter"),

2149 0x120b: (0x0102, None, None, 4, None, None, "OriginalDeliveryFolderInfo"),

2150 0x120c: (0x0102, None, None, 4, None, None, "ClutterFolderEntryIdWellKnown"),

2151 0x120d: (0x0102, None, None, 4, None, None, "BirthdayCalendarFolderEntryIdWellKnown"),

2152 0x120e: (0x0102, None, None, 4, None, None, "InferencePredictedClutterReasons"),

2153 0x120f: (0x0102, None, None, 4, None, None, "InferencePredictedNotClutterReasons"),

2154 0x1210: (0x0102, None, None, 4, None, None, "BookingStaffFolderEntryId"),

2155 0x1211: (0x0102, None, None, 4, None, None, "BookingServicesFolderEntryId"),

2156 0x1212: (0x0003, None, None, 4, None, None, "InferenceClassificationInternal"),

2157 0x1213: (0x0003, None, None, 4, None, None, "InferenceClassification"),

2158 0x1214: (0x0102, None, None, 4, None, None, "SchedulesFolderEntryId"),

2159 0x1215: (0x0102, None, None, 4, None, None, "AllTaggedItemsFolderEntryId"),

2160 0x1236: (0x0048, None, None, 4, None, None, "WellKnownFolderGuid"),

2161 0x1237: (0x0003, None, None, 4, None, None, "RemoteFolderSyncStatus"),

2162 0x1238: (0x0102, None, None, 4, None, None, "BookingCustomQuestionsFolderEntryId"),

2163 0x300e: (0x000b, None, None, 4, None, None, "UserInformationAntispamBypassEnabled"),

2164 0x300f: (0x001f, None, None, 4, None, None, "UserInformationArchiveDomain"),

2165 0x3017: (0x0040, None, None, 4, None, None, "UserInformationBirthdate"),

2166 0x3020: (0x001f, None, None, 4, None, None, "UserInformationCountryOrRegion"),

2167 0x3021: (0x001f, None, None, 4, None, None, "UserInformationDefaultMailTip"),

2168 0x3022: (0x000b, None, None, 4, None, None, "UserInformationDeliverToMailboxAndForward"),

2169 0x3023: (0x101f, None, None, 4, None, None, "UserInformationDescription"),

2170 0x3024: (0x0048, None, None, 4, None, None, "UserInformationDisabledArchiveGuid"),

2171 0x3025: (0x000b, None, None, 4, None, None, "UserInformationDowngradeHighPriorityMessagesEnabled"),

2172 0x3026: (0x000b, None, None, 4, None, None, "UserInformationECPEnabled"),

2173 0x3027: (0x000b, None, None, 4, None, None, "UserInformationEmailAddressPolicyEnabled"),

2174 0x3028: (0x000b, None, None, 4, None, None, "UserInformationEwsAllowEntourage"),

2175 0x3029: (0x000b, None, None, 4, None, None, "UserInformationEwsAllowMacOutlook"),

2176 0x302a: (0x000b, None, None, 4, None, None, "UserInformationEwsAllowOutlook"),

2177 0x302b: (0x0003, None, None, 4, None, None, "UserInformationEwsApplicationAccessPolicy"),

2178 0x302c: (0x0003, None, None, 4, None, None, "UserInformationEwsEnabled"),

2179 0x302d: (0x101f, None, None, 4, None, None, "UserInformationEwsExceptions"),

2180 0x302e: (0x101f, None, None, 4, None, None, "UserInformationEwsWellKnownApplicationAccessPolicies"),

2181 0x302f: (0x0048, None, None, 4, None, None, "UserInformationExchangeGuid"),

2182 0x3030: (0x0003, None, None, 4, None, None, "UserInformationExternalOofOptions"),

2183 0x3031: (0x001f, None, None, 4, None, None, "UserInformationFirstName"),

2184 0x3032: (0x001f, None, None, 4, None, None, "UserInformationForwardingSmtpAddress"),

2185 0x3033: (0x001f, None, None, 4, None, None, "UserInformationGender"),

2186 0x3034: (0x001f, None, None, 4, None, None, "UserInformationGenericForwardingAddress"),

2187 0x3035: (0x001f, None, None, 4, None, None, "UserInformationGeoCoordinates"),

2188 0x3036: (0x0003, None, None, 4, None, None, "UserInformationHABSeniorityIndex"),

2189 0x3037: (0x000b, None, None, 4, None, None, "UserInformationHasActiveSyncDevicePartnership"),

2190 0x3038: (0x000b, None, None, 4, None, None, "UserInformationHiddenFromAddressListsEnabled"),

2191 0x3039: (0x000b, None, None, 4, None, None, "UserInformationHiddenFromAddressListsValue"),

2192 0x303a: (0x001f, None, None, 4, None, None, "UserInformationHomePhone"),

2193 0x303b: (0x000b, None, None, 4, None, None, "UserInformationImapEnabled"),

2194 0x303c: (0x000b, None, None, 4, None, None, "UserInformationImapEnableExactRFC822Size"),

2195 0x303d: (0x000b, None, None, 4, None, None, "UserInformationImapForceICalForCalendarRetrievalOption"),

2196 0x303e: (0x0003, None, None, 4, None, None, "UserInformationImapMessagesRetrievalMimeFormat"),

2197 0x303f: (0x0003, None, None, 4, None, None, "UserInformationImapProtocolLoggingEnabled"),

2198 0x3040: (0x000b, None, None, 4, None, None, "UserInformationImapSuppressReadReceipt"),

2199 0x3041: (0x000b, None, None, 4, None, None, "UserInformationImapUseProtocolDefaults"),

2200 0x3042: (0x000b, None, None, 4, None, None, "UserInformationIncludeInGarbageCollection"),

2201 0x3043: (0x001f, None, None, 4, None, None, "UserInformationInitials"),

2202 0x3044: (0x101f, None, None, 4, None, None, "UserInformationInPlaceHolds"),

2203 0x3045: (0x000b, None, None, 4, None, None, "UserInformationInternalOnly"),

2204 0x3046: (0x001f, None, None, 4, None, None, "UserInformationInternalUsageLocation"),

2205 0x3047: (0x0003, None, None, 4, None, None, "UserInformationInternetEncoding"),

2206 0x3048: (0x000b, None, None, 4, None, None, "UserInformationIsCalculatedTargetAddress"),

2207 0x3049: (0x000b, None, None, 4, None, None, "UserInformationIsExcludedFromServingHierarchy"),

2208 0x304a: (0x000b, None, None, 4, None, None, "UserInformationIsHierarchyReady"),

2209 0x304b: (0x000b, None, None, 4, None, None, "UserInformationIsInactiveMailbox"),

2210 0x304c: (0x000b, None, None, 4, None, None, "UserInformationIsSoftDeletedByDisable"),

2211 0x304d: (0x000b, None, None, 4, None, None, "UserInformationIsSoftDeletedByRemove"),

2212 0x304e: (0x001f, None, None, 4, None, None, "UserInformationIssueWarningQuota"),

2213 0x304f: (0x001f, None, None, 4, None, None, "UserInformationJournalArchiveAddress"),

2214 0x3051: (0x0040, None, None, 4, None, None, "UserInformationLastExchangeChangedTime"),

2215 0x3052: (0x001f, None, None, 4, None, None, "UserInformationLastName"),

2216 0x3053: (0x0040, None, None, 4, None, None, "UserInformationLastAliasSyncSubmittedTime"),

2217 0x3054: (0x000b, None, None, 4, None, None, "UserInformationLEOEnabled"),

2218 0x3055: (0x1003, None, None, 4, None, None, "UserInformationLocaleID"),

2219 0x3056: (0x0003, None, None, 4, None, None, "UserInformationLongitude"),

2220 0x3057: (0x0003, None, None, 4, None, None, "UserInformationMacAttachmentFormat"),

2221 0x3058: (0x0048, None, None, 4, None, None, "UserInformationMailboxContainerGuid"),

2222 0x3059: (0x001f, None, None, 4, None, None, "UserInformationMailboxMoveBatchName"),

2223 0x305a: (0x001f, None, None, 4, None, None, "UserInformationMailboxMoveRemoteHostName"),

2224 0x305b: (0x0003, None, None, 4, None, None, "UserInformationMailboxMoveStatus"),

2225 0x305c: (0x001f, None, None, 4, None, None, "UserInformationMailboxRelease"),

2226 0x305d: (0x101f, None, None, 4, None, None, "UserInformationMailTipTranslations"),

2227 0x305e: (0x000b, None, None, 4, None, None, "UserInformationMAPIBlockOutlookNonCachedMode"),

2228 0x305f: (0x000b, None, None, 4, None, None, "UserInformationMAPIBlockOutlookRpcHttp"),

2229 0x3060: (0x001f, None, None, 4, None, None, "UserInformationMAPIBlockOutlookVersions"),

2230 0x3061: (0x0003, None, None, 4, None, None, "UserInformationMailboxStatus"),

2231 0x3062: (0x000b, None, None, 4, None, None, "UserInformationMapiRecipient"),

2232 0x3063: (0x0003, None, None, 4, None, None, "UserInformationMaxBlockedSenders"),

2233 0x3064: (0x001f, None, None, 4, None, None, "UserInformationMaxReceiveSize"),

2234 0x3065: (0x0003, None, None, 4, None, None, "UserInformationMaxSafeSenders"),

2235 0x3066: (0x001f, None, None, 4, None, None, "UserInformationMaxSendSize"),

2236 0x3067: (0x001f, None, None, 4, None, None, "UserInformationMemberName"),

2237 0x3068: (0x0003, None, None, 4, None, None, "UserInformationMessageBodyFormat"),

2238 0x3069: (0x0003, None, None, 4, None, None, "UserInformationMessageFormat"),

2239 0x306a: (0x000b, None, None, 4, None, None, "UserInformationMessageTrackingReadStatusDisabled"),

2240 0x306b: (0x0003, None, None, 4, None, None, "UserInformationMobileFeaturesEnabled"),

2241 0x306c: (0x001f, None, None, 4, None, None, "UserInformationMobilePhone"),

2242 0x306d: (0x0003, None, None, 4, None, None, "UserInformationModerationFlags"),

2243 0x306e: (0x001f, None, None, 4, None, None, "UserInformationNotes"),

2244 0x306f: (0x001f, None, None, 4, None, None, "UserInformationOccupation"),

2245 0x3070: (0x000b, None, None, 4, None, None, "UserInformationOpenDomainRoutingDisabled"),

2246 0x3071: (0x101f, None, None, 4, None, None, "UserInformationOtherHomePhone"),

2247 0x3072: (0x101f, None, None, 4, None, None, "UserInformationOtherMobile"),

2248 0x3073: (0x101f, None, None, 4, None, None, "UserInformationOtherTelephone"),

2249 0x3074: (0x000b, None, None, 4, None, None, "UserInformationOWAEnabled"),

2250 0x3075: (0x000b, None, None, 4, None, None, "UserInformationOWAforDevicesEnabled"),

2251 0x3076: (0x001f, None, None, 4, None, None, "UserInformationPager"),

2252 0x3077: (0x1003, None, None, 4, None, None, "UserInformationPersistedCapabilities"),

2253 0x3078: (0x001f, None, None, 4, None, None, "UserInformationPhone"),

2254 0x3079: (0x001f, None, None, 4, None, None, "UserInformationPhoneProviderId"),

2255 0x307a: (0x000b, None, None, 4, None, None, "UserInformationPopEnabled"),

2256 0x307b: (0x000b, None, None, 4, None, None, "UserInformationPopEnableExactRFC822Size"),

2257 0x307c: (0x000b, None, None, 4, None, None, "UserInformationPopForceICalForCalendarRetrievalOption"),

2258 0x307d: (0x0003, None, None, 4, None, None, "UserInformationPopMessagesRetrievalMimeFormat"),

2259 0x307e: (0x0003, None, None, 4, None, None, "UserInformationPopProtocolLoggingEnabled"),

2260 0x307f: (0x000b, None, None, 4, None, None, "UserInformationPopSuppressReadReceipt"),

2261 0x3080: (0x000b, None, None, 4, None, None, "UserInformationPopUseProtocolDefaults"),

2262 0x3081: (0x001f, None, None, 4, None, None, "UserInformationPostalCode"),

2263 0x3082: (0x101f, None, None, 4, None, None, "UserInformationPostOfficeBox"),

2264 0x3083: (0x0048, None, None, 4, None, None, "UserInformationPreviousExchangeGuid"),

2265 0x3084: (0x0003, None, None, 4, None, None, "UserInformationPreviousRecipientTypeDetails"),

2266 0x3085: (0x001f, None, None, 4, None, None, "UserInformationProhibitSendQuota"),

2267 0x3086: (0x001f, None, None, 4, None, None, "UserInformationProhibitSendReceiveQuota"),

2268 0x3087: (0x000b, None, None, 4, None, None, "UserInformationQueryBaseDNRestrictionEnabled"),

2269 0x3088: (0x0003, None, None, 4, None, None, "UserInformationRecipientDisplayType"),

2270 0x3089: (0x001f, None, None, 4, None, None, "UserInformationRecipientLimits"),

2271 0x308a: (0x0003, None, None, 4, None, None, "UserInformationRecipientSoftDeletedStatus"),

2272 0x308b: (0x001f, None, None, 4, None, None, "UserInformationRecoverableItemsQuota"),

2273 0x308c: (0x001f, None, None, 4, None, None, "UserInformationRecoverableItemsWarningQuota"),

2274 0x308d: (0x001f, None, None, 4, None, None, "UserInformationRegion"),

2275 0x308e: (0x000b, None, None, 4, None, None, "UserInformationRemotePowerShellEnabled"),

2276 0x308f: (0x0003, None, None, 4, None, None, "UserInformationRemoteRecipientType"),

2277 0x3090: (0x000b, None, None, 4, None, None, "UserInformationRequireAllSendersAreAuthenticated"),

2278 0x3091: (0x000b, None, None, 4, None, None, "UserInformationResetPasswordOnNextLogon"),

2279 0x3092: (0x0014, None, None, 4, None, None, "UserInformationRetainDeletedItemsFor"),

2280 0x3093: (0x000b, None, None, 4, None, None, "UserInformationRetainDeletedItemsUntilBackup"),

2281 0x3094: (0x001f, None, None, 4, None, None, "UserInformationRulesQuota"),

2282 0x3095: (0x000b, None, None, 4, None, None, "UserInformationShouldUseDefaultRetentionPolicy"),

2283 0x3096: (0x001f, None, None, 4, None, None, "UserInformationSimpleDisplayName"),

2284 0x3097: (0x000b, None, None, 4, None, None, "UserInformationSingleItemRecoveryEnabled"),

2285 0x3098: (0x001f, None, None, 4, None, None, "UserInformationStateOrProvince"),

2286 0x3099: (0x001f, None, None, 4, None, None, "UserInformationStreetAddress"),

2287 0x309a: (0x000b, None, None, 4, None, None, "UserInformationSubscriberAccessEnabled"),

2288 0x309b: (0x001f, None, None, 4, None, None, "UserInformationTextEncodedORAddress"),

2289 0x309c: (0x101f, None, None, 4, None, None, "UserInformationTextMessagingState"),

2290 0x309d: (0x001f, None, None, 4, None, None, "UserInformationTimezone"),

2291 0x309e: (0x000b, None, None, 4, None, None, "UserInformationUCSImListMigrationCompleted"),

2292 0x309f: (0x001f, None, None, 4, None, None, "UserInformationUpgradeDetails"),

2293 0x30a0: (0x001f, None, None, 4, None, None, "UserInformationUpgradeMessage"),

2294 0x30a1: (0x0003, None, None, 4, None, None, "UserInformationUpgradeRequest"),

2295 0x30a2: (0x0003, None, None, 4, None, None, "UserInformationUpgradeStage"),

2296 0x30a3: (0x0040, None, None, 4, None, None, "UserInformationUpgradeStageTimeStamp"),

2297 0x30a4: (0x0003, None, None, 4, None, None, "UserInformationUpgradeStatus"),

2298 0x30a5: (0x001f, None, None, 4, None, None, "UserInformationUsageLocation"),

2299 0x30a6: (0x0003, None, None, 4, None, None, "UserInformationUseMapiRichTextFormat"),

2300 0x30a7: (0x000b, None, None, 4, None, None, "UserInformationUsePreferMessageFormat"),

2301 0x30a8: (0x000b, None, None, 4, None, None, "UserInformationUseUCCAuditConfig"),

2302 0x30a9: (0x001f, None, None, 4, None, None, "UserInformationWebPage"),

2303 0x30aa: (0x0040, None, None, 4, None, None, "UserInformationWhenMailboxCreated"),

2304 0x30ab: (0x0040, None, None, 4, None, None, "UserInformationWhenSoftDeleted"),

2305 0x30ac: (0x001f, None, None, 4, None, None, "UserInformationBirthdayPrecision"),

2306 0x30ad: (0x001f, None, None, 4, None, None, "UserInformationNameVersion"),

2307 0x30ae: (0x0040, None, None, 4, None, None, "UserInformationOptInTime"),

2308 0x30af: (0x000b, None, None, 4, None, None, "UserInformationIsMigratedConsumerMailbox"),

2309 0x30b0: (0x000b, None, None, 4, None, None, "UserInformationMigrationDryRun"),

2310 0x30b1: (0x000b, None, None, 4, None, None, "UserInformationIsPremiumConsumerMailbox"),

2311 0x30b2: (0x001f, None, None, 4, None, None, "UserInformationAlternateSupportEmailAddresses"),

2312 0x30b3: (0x101f, None, None, 4, None, None, "UserInformationEmailAddresses"),

2313 0x30b4: (0x000b, None, None, 4, None, None, "UserInformationHasSnackyAppData"),

2314 0x30b5: (0x001f, None, None, 4, None, None, "UserInformationMailboxMoveTargetMDB"),

2315 0x30b6: (0x001f, None, None, 4, None, None, "UserInformationMailboxMoveSourceMDB"),

2316 0x30b7: (0x0003, None, None, 4, None, None, "UserInformationMailboxMoveFlags"),

2317 0x30b8: (0x0040, None, None, 4, None, None, "UserInformationHydraLastSyncTimestamp"),

2318 0x30b9: (0x0048, None, None, 4, None, None, "UserInformationHydraSyncStartIdentity"),

2319 0x30ba: (0x0040, None, None, 4, None, None, "UserInformationHydraSyncStartTimestamp"),

2320 0x30bb: (0x0002, None, None, 4, None, None, "UserInformationStatus"),

2321 0x30bc: (0x0040, None, None, 4, None, None, "UserInformationDeletedOn"),

2322 0x30bd: (0x000b, None, None, 4, None, None, "UserInformationMigrationInterruptionTest"),

2323 0x30be: (0x0002, None, None, 4, None, None, "UserInformationLocatorSource"),

2324 0x30bf: (0x000b, None, None, 4, None, None, "UserInformationMAPIEnabled"),

2325 0x30c0: (0x0003, None, None, 4, None, None, "UserInformationOlcDatFlags"),

2326 0x30c1: (0x0003, None, None, 4, None, None, "UserInformationOlcDat2Flags"),

2327 0x30c2: (0x001f, None, None, 4, None, None, "UserInformationDefaultFromAddress"),

2328 0x30c3: (0x101f, None, None, 4, None, None, "UserInformationNotManagedEmailAddresses"),

2329 0x30c4: (0x0003, None, None, 4, None, None, "UserInformationLatitude"),

2330 0x30c5: (0x101f, None, None, 4, None, None, "UserInformationConnectedAccounts"),

2331 0x30c6: (0x0003, None, None, 4, None, None, "UserInformationAccountTrustLevel"),

2332 0x30c7: (0x001f, None, None, 4, None, None, "UserInformationBlockReason"),

2333 0x30c8: (0x000b, None, None, 4, None, None, "UserInformationHijackDetection"),

2334 0x30c9: (0x000b, None, None, 4, None, None, "UserInformationHipChallengeApplicable"),

2335 0x30ca: (0x000b, None, None, 4, None, None, "UserInformationIsBlocked"),

2336 0x30cb: (0x000b, None, None, 4, None, None, "UserInformationIsSwitchUser"),

2337 0x30cc: (0x000b, None, None, 4, None, None, "UserInformationIsToolsAccount"),

2338 0x30cd: (0x0040, None, None, 4, None, None, "UserInformationLastBlockTime"),

2339 0x30ce: (0x0003, None, None, 4, None, None, "UserInformationMaxDailyMessages"),

2340 0x30cf: (0x000b, None, None, 4, None, None, "UserInformationReportToExternalSender"),

2341 0x30d0: (0x0040, None, None, 4, None, None, "UserInformationWhenOlcMailboxCreated"),

2342 0x30d1: (0x001f, None, None, 4, None, None, "UserInformationMailboxProvisioningConstraint"),

2343 0x30d2: (0x101f, None, None, 4, None, None, "UserInformationMailboxProvisioningPreferences"),

2344 0x30d3: (0x0014, None, None, 4, None, None, "UserInformationCID"),

2345 0x30d4: (0x101f, None, None, 4, None, None, "UserInformationSharingAnonymousIdentities"),

2346 0x30d5: (0x0102, None, None, 4, None, None, "UserInformationExchangeSecurityDescriptor"),

2347 0x30d6: (0x000b, None, None, 4, None, None, "UserInformationMapiHttpEnabled"),

2348 0x30d7: (0x000b, None, None, 4, None, None, "UserInformationMAPIBlockOutlookExternalConnectivity"),

2349 0x30d8: (0x000b, None, None, 4, None, None, "UserInformationUniversalOutlookEnabled"),

2350 0x30d9: (0x000b, None, None, 4, None, None, "UserInformationPopMessageDeleteEnabled"),

2351 0x30da: (0x0003, None, None, 4, None, None, "UserInformationPrimaryMailboxSource"),

2352 0x30db: (0x0002, None, None, 4, None, None, "UserInformationLocatorCacheHint"),

2353 0x30dc: (0x0014, None, None, 4, None, None, "UserInformationNetID"),

2354 0x30dd: (0x000b, None, None, 4, None, None, "UserInformationIsProsumerConsumerMailbox"),

2355 0x30de: (0x101f, None, None, 4, None, None, "UserInformationProsumerEmailAddresses"),

2356 0x30df: (0x101f, None, None, 4, None, None, "UserInformationProsumerMSAVerifiedEmailAddresses"),

2357 0x30e0: (0x0048, None, None, 4, None, None, "UserInformationShardOwnerExchangeObjectId"),

2358 0x30e1: (0x0102, None, None, 4, None, None, "UserInformationShardOwnerTenantPartitionHint"),

2359 0x30e2: (0x001f, None, None, 4, None, None, "UserInformationShardProvisionedByProtocolType"),

2360 0x30e3: (0x000b, None, None, 4, None, None, "UserInformationIsShadowMailboxProvisioningComplete"),

2361 0x30e4: (0x001f, None, None, 4, None, None, "UserInformationShadowRemoteEmailAddress"),

2362 0x30e5: (0x0003, None, None, 4, None, None, "UserInformationShadowScope"),

2363 0x30e6: (0x001f, None, None, 4, None, None, "UserInformationShadowUserName"),

2364 0x30e7: (0x0003, None, None, 4, None, None, "UserInformationShadowProvider"),

2365 0x30e8: (0x000b, None, None, 4, None, None, "UserInformationIsShadowMailbox"),

2366 0x30e9: (0x0003, None, None, 4, None, None, "UserInformationPersistedMservNameVersion"),

2367 0x30ea: (0x0040, None, None, 4, None, None, "UserInformationLastPersistedMservNameVersionUpdateTime"),

2368 0x30eb: (0x0014, None, None, 4, None, None, "UserInformationPremiumAccountOffers"),

2369 0x30ec: (0x101f, None, None, 4, None, None, "UserInformationLegacyCustomDomainAddresses"),

2370 0x30ed: (0x000b, None, None, 4, None, None, "UserInformationActiveSyncSuppressReadReceipt"),

2371 0x30ee: (0x101f, None, None, 4, None, None, "UserInformationAcceptMessagesOnlyFrom"),

2372 0x30ef: (0x101f, None, None, 4, None, None, "UserInformationAcceptMessagesOnlyFromBL"),

2373 0x30f0: (0x101f, None, None, 4, None, None, "UserInformationAcceptMessagesOnlyFromDLMembers"),

2374 0x30f1: (0x101f, None, None, 4, None, None, "UserInformationAcceptMessagesOnlyFromDLMembersBL"),

2375 0x30f2: (0x001f, None, None, 4, None, None, "UserInformationActiveSyncMailboxPolicy"),

2376 0x30f3: (0x000b, None, None, 4, None, None, "UserInformationActiveSyncMailboxPolicyIsDefaulted"),

2377 0x30f4: (0x0003, None, None, 4, None, None, "UserInformationAddressBookFlags"),

2378 0x30f5: (0x001f, None, None, 4, None, None, "UserInformationAddressBookPolicy"),

2379 0x30f6: (0x101f, None, None, 4, None, None, "UserInformationAddressListMembership"),

2380 0x30f7: (0x101f, None, None, 4, None, None, "UserInformationAdministrativeUnits"),

2381 0x30f8: (0x101f, None, None, 4, None, None, "UserInformationAggregatedMailboxGuidsRaw"),

2382 0x30f9: (0x001f, None, None, 4, None, None, "UserInformationAlias"),

2383 0x30fa: (0x000b, None, None, 4, None, None, "UserInformationAllowAddGuests"),

2384 0x30fb: (0x101f, None, None, 4, None, None, "UserInformationAllowedAttributesEffective"),

2385 0x30fc: (0x0003, None, None, 4, None, None, "UserInformationAllowUMCallsFromNonUsers"),

2386 0x30fd: (0x101f, None, None, 4, None, None, "UserInformationAltSecurityIdentities"),

2387 0x30fe: (0x101f, None, None, 4, None, None, "UserInformationApprovalApplications"),

2388 0x30ff: (0x001f, None, None, 4, None, None, "UserInformationArbitrationMailbox"),

2389 0x3100: (0x001f, None, None, 4, None, None, "UserInformationArchiveDatabaseRaw"),

2390 0x3101: (0x1102, None, None, 4, None, None, "UserInformationAttributeMetadata"),

2391 0x3102: (0x0003, None, None, 4, None, None, "UserInformationAuditAdminFlags"),

2392 0x3103: (0x000b, None, None, 4, None, None, "UserInformationAuditBypassEnabled"),

2393 0x3104: (0x0003, None, None, 4, None, None, "UserInformationAuditDelegateAdminFlags"),

2394 0x3105: (0x0003, None, None, 4, None, None, "UserInformationAuditDelegateFlags"),

2395 0x3106: (0x000b, None, None, 4, None, None, "UserInformationAuditEnabled"),

2396 0x3107: (0x0040, None, None, 4, None, None, "UserInformationAuditLastAdminAccess"),

2397 0x3108: (0x0040, None, None, 4, None, None, "UserInformationAuditLastDelegateAccess"),

2398 0x3109: (0x0040, None, None, 4, None, None, "UserInformationAuditLastExternalAccess"),

2399 0x310a: (0x0014, None, None, 4, None, None, "UserInformationAuditLogAgeLimit"),

2400 0x310b: (0x0003, None, None, 4, None, None, "UserInformationAuditOwnerFlags"),

2401 0x310c: (0x0003, None, None, 4, None, None, "UserInformationAuditStorageState"),

2402 0x310d: (0x001f, None, None, 4, None, None, "UserInformationAuxMailboxParentObjectId"),

2403 0x310e: (0x001f, None, None, 4, None, None, "UserInformationAuxMailboxParentObjectIdBL"),

2404 0x310f: (0x001f, None, None, 4, None, None, "UserInformationAuthenticationPolicy"),

2405 0x3110: (0x0102, None, None, 4, None, None, "UserInformationBlockedSendersHash"),

2406 0x3111: (0x101f, None, None, 4, None, None, "UserInformationBypassModerationFrom"),

2407 0x3112: (0x101f, None, None, 4, None, None, "UserInformationBypassModerationFromBL"),

2408 0x3113: (0x101f, None, None, 4, None, None, "UserInformationBypassModerationFromDLMembers"),

2409 0x3114: (0x101f, None, None, 4, None, None, "UserInformationBypassModerationFromDLMembersBL"),

2410 0x3115: (0x0003, None, None, 4, None, None, "UserInformationCallAnsweringAudioCodecLegacy"),

2411 0x3116: (0x0003, None, None, 4, None, None, "UserInformationCallAnsweringAudioCodec2"),

2412 0x3117: (0x101f, None, None, 4, None, None, "UserInformationCatchAllRecipientBL"),

2413 0x3118: (0x1102, None, None, 4, None, None, "UserInformationCertificate"),

2414 0x3119: (0x001f, None, None, 4, None, None, "UserInformationClassification"),

2415 0x311a: (0x001f, None, None, 4, None, None, "UserInformationCo"),

2416 0x311b: (0x101f, None, None, 4, None, None, "UserInformationCoManagedBy"),

2417 0x311c: (0x101f, None, None, 4, None, None, "UserInformationCoManagedObjectsBL"),

2418 0x311d: (0x001f, None, None, 4, None, None, "UserInformationCompany"),

2419 0x311e: (0x001f, None, None, 4, None, None, "UserInformationConfigurationUnit"),

2420 0x311f: (0x001f, None, None, 4, None, None, "UserInformationConfigurationXMLRaw"),

2421 0x3120: (0x0048, None, None, 4, None, None, "UserInformationCorrelationIdRaw"),

2422 0x3121: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute1"),

2423 0x3122: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute10"),

2424 0x3123: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute11"),

2425 0x3124: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute12"),

2426 0x3125: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute13"),

2427 0x3126: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute14"),

2428 0x3127: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute15"),

2429 0x3128: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute2"),

2430 0x3129: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute3"),

2431 0x312a: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute4"),

2432 0x312b: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute5"),

2433 0x312c: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute6"),

2434 0x312d: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute7"),

2435 0x312e: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute8"),

2436 0x312f: (0x001f, None, None, 4, None, None, "UserInformationCustomAttribute9"),

2437 0x3130: (0x001f, None, None, 4, None, None, "UserInformationDatabase"),

2438 0x3131: (0x001f, None, None, 4, None, None, "UserInformationDataEncryptionPolicy"),

2439 0x3132: (0x001f, None, None, 4, None, None, "UserInformationDefaultPublicFolderMailbox"),

2440 0x3133: (0x001f, None, None, 4, None, None, "UserInformationDefaultPublicFolderMailboxSmtpAddress"),

2441 0x3134: (0x101f, None, None, 4, None, None, "UserInformationDelegateListBL"),

2442 0x3135: (0x101f, None, None, 4, None, None, "UserInformationDelegateListLink"),

2443 0x3136: (0x0003, None, None, 4, None, None, "UserInformationDeletedItemFlags"),

2444 0x3137: (0x0003, None, None, 4, None, None, "UserInformationDeliveryMechanism"),

2445 0x3138: (0x001f, None, None, 4, None, None, "UserInformationDepartment"),

2446 0x3139: (0x101f, None, None, 4, None, None, "UserInformationDirectReports"),

2447 0x313a: (0x101f, None, None, 4, None, None, "UserInformationDirSyncAuthorityMetadata"),

2448 0x313b: (0x001f, None, None, 4, None, None, "UserInformationDirSyncId"),

2449 0x313c: (0x001f, None, None, 4, None, None, "UserInformationDisabledArchiveDatabase"),

2450 0x313d: (0x1102, None, None, 4, None, None, "UserInformationDLSupervisionList"),

2451 0x313e: (0x0040, None, None, 4, None, None, "UserInformationElcExpirationSuspensionEndDate"),

2452 0x313f: (0x0040, None, None, 4, None, None, "UserInformationElcExpirationSuspensionStartDate"),

2453 0x3140: (0x0003, None, None, 4, None, None, "UserInformationElcMailboxFlags"),

2454 0x3141: (0x001f, None, None, 4, None, None, "UserInformationElcPolicyTemplate"),

2455 0x3142: (0x001f, None, None, 4, None, None, "UserInformationEntryId"),

2456 0x3143: (0x0048, None, None, 4, None, None, "UserInformationExchangeObjectIdRaw"),

2457 0x3144: (0x0102, None, None, 4, None, None, "UserInformationExchangeSecurityDescriptorRaw"),

2458 0x3145: (0x001f, None, None, 4, None, None, "UserInformationExchangeVersion"),

2459 0x3146: (0x0003, None, None, 4, None, None, "UserInformationExchangeUserAccountControl"),

2460 0x3147: (0x001f, None, None, 4, None, None, "UserInformationExpansionServer"),

2461 0x3148: (0x101f, None, None, 4, None, None, "UserInformationExtensionCustomAttribute1"),

2462 0x3149: (0x101f, None, None, 4, None, None, "UserInformationExtensionCustomAttribute2"),

2463 0x314a: (0x101f, None, None, 4, None, None, "UserInformationExtensionCustomAttribute3"),

2464 0x314b: (0x101f, None, None, 4, None, None, "UserInformationExtensionCustomAttribute4"),

2465 0x314c: (0x101f, None, None, 4, None, None, "UserInformationExtensionCustomAttribute5"),

2466 0x314d: (0x001f, None, None, 4, None, None, "UserInformationExternalDirectoryObjectId"),

2467 0x314e: (0x0102, None, None, 4, None, None, "UserInformationExternalSyncState"),

2468 0x314f: (0x001f, None, None, 4, None, None, "UserInformationFax"),

2469 0x3150: (0x000b, None, None, 4, None, None, "UserInformationFblEnabled"),

2470 0x3151: (0x001f, None, None, 4, None, None, "UserInformationForwardingAddress"),

2471 0x3152: (0x101f, None, None, 4, None, None, "UserInformationForwardingAddressBL"),

2472 0x3153: (0x001f, None, None, 4, None, None, "UserInformationForeignGroupSid"),

2473 0x3154: (0x101f, None, None, 4, None, None, "UserInformationGeneratedOfflineAddressBooks"),

2474 0x3155: (0x001f, None, None, 4, None, None, "UserInformationGroupPersonification"),

2475 0x3156: (0x101f, None, None, 4, None, None, "UserInformationGrantSendOnBehalfTo"),

2476 0x3157: (0x101f, None, None, 4, None, None, "UserInformationGrantSendOnBehalfToBL"),

2477 0x3158: (0x001f, None, None, 4, None, None, "UserInformationGroupSubtypeName"),

2478 0x3159: (0x0003, None, None, 4, None, None, "UserInformationGroupType"),

2479 0x315a: (0x0003, None, None, 4, None, None, "UserInformationGroupExternalMemberCount"),

2480 0x315b: (0x0003, None, None, 4, None, None, "UserInformationGroupMemberCount"),

2481 0x315c: (0x001f, None, None, 4, None, None, "UserInformationGuestHint"),

2482 0x315d: (0x101f, None, None, 4, None, None, "UserInformationHABShowInDepartments"),

2483 0x315e: (0x0003, None, None, 4, None, None, "UserInformationHeuristics"),

2484 0x315f: (0x000b, None, None, 4, None, None, "UserInformationHiddenGroupMembershipEnabled"),

2485 0x3160: (0x001f, None, None, 4, None, None, "UserInformationHomeMTA"),

2486 0x3161: (0x001f, None, None, 4, None, None, "UserInformationId"),

2487 0x3162: (0x001f, None, None, 4, None, None, "UserInformationImmutableId"),

2488 0x3163: (0x101f, None, None, 4, None, None, "UserInformationInPlaceHoldsRaw"),

2489 0x3164: (0x001f, None, None, 4, None, None, "UserInformationIntendedMailboxPlan"),

2490 0x3165: (0x1102, None, None, 4, None, None, "UserInformationInternalRecipientSupervisionList"),

2491 0x3166: (0x000b, None, None, 4, None, None, "UserInformationIsDirSynced"),

2492 0x3167: (0x000b, None, None, 4, None, None, "UserInformationIsInactive"),

2493 0x3168: (0x000b, None, None, 4, None, None, "UserInformationIsOrganizationalGroup"),

2494 0x3169: (0x001f, None, None, 4, None, None, "UserInformationLdapRecipientFilter"),

2495 0x316a: (0x001f, None, None, 4, None, None, "UserInformationLanguagesRaw"),

2496 0x316b: (0x001f, None, None, 4, None, None, "UserInformationLegacyExchangeDN"),

2497 0x316c: (0x001f, None, None, 4, None, None, "UserInformationLinkedPartnerGroupAndOrganizationId"),

2498 0x316d: (0x1102, None, None, 4, None, None, "UserInformationLinkMetadata"),

2499 0x316e: (0x0040, None, None, 4, None, None, "UserInformationLitigationHoldDate"),

2500 0x316f: (0x001f, None, None, 4, None, None, "UserInformationLitigationHoldOwner"),

2501 0x3170: (0x0003, None, None, 4, None, None, "UserInformationLocalizationFlags"),

2502 0x3171: (0x1102, None, None, 4, None, None, "UserInformationMailboxDatabasesRaw"),

2503 0x3172: (0x1048, None, None, 4, None, None, "UserInformationMailboxGuidsRaw"),

2504 0x3173: (0x1102, None, None, 4, None, None, "UserInformationMailboxLocationsRaw"),

2505 0x3174: (0x001f, None, None, 4, None, None, "UserInformationMailboxPlan"),

2506 0x3175: (0x001f, None, None, 4, None, None, "UserInformationMailboxPlanIndex"),

2507 0x3176: (0x001f, None, None, 4, None, None, "UserInformationMailboxRegion"),

2508 0x3177: (0x001f, None, None, 4, None, None, "UserInformationMailboxMoveSourceArchiveMDB"),

2509 0x3178: (0x001f, None, None, 4, None, None, "UserInformationMailboxMoveTargetArchiveMDB"),

2510 0x3179: (0x000b, None, None, 4, None, None, "UserInformationMbxGuidEnabled"),

2511 0x317a: (0x001f, None, None, 4, None, None, "UserInformationManager"),

2512 0x317b: (0x001f, None, None, 4, None, None, "UserInformationMasterAccountSid"),

2513 0x317c: (0x001f, None, None, 4, None, None, "UserInformationMasterDirectoryObjectIdRaw"),

2514 0x317d: (0x0003, None, None, 4, None, None, "UserInformationMemberDepartRestriction"),

2515 0x317e: (0x0003, None, None, 4, None, None, "UserInformationMemberJoinRestriction"),

2516 0x317f: (0x101f, None, None, 4, None, None, "UserInformationMemberOfGroup"),

2517 0x3180: (0x101f, None, None, 4, None, None, "UserInformationMembers"),

2518 0x3181: (0x0003, None, None, 4, None, None, "UserInformationMessageHygieneFlags"),

2519 0x3182: (0x000b, None, None, 4, None, None, "UserInformationMigrationToUnifiedGroupInProgress"),

2520 0x3183: (0x101f, None, None, 4, None, None, "UserInformationMobileAdminExtendedSettings"),

2521 0x3184: (0x0003, None, None, 4, None, None, "UserInformationMobileMailboxFlags"),

2522 0x3185: (0x101f, None, None, 4, None, None, "UserInformationModeratedBy"),

2523 0x3186: (0x000b, None, None, 4, None, None, "UserInformationModerationEnabled"),

2524 0x3187: (0x101f, None, None, 4, None, None, "UserInformationModeratedObjectsBL"),

2525 0x3188: (0x0003, None, None, 4, None, None, "UserInformationMservNameVersion"),

2526 0x3189: (0x0014, None, None, 4, None, None, "UserInformationMservNetID"),

2527 0x318a: (0x0102, None, None, 4, None, None, "UserInformationNTSecurityDescriptor"),

2528 0x318b: (0x001f, None, None, 4, None, None, "UserInformationObjectCategory"),

2529 0x318c: (0x101f, None, None, 4, None, None, "UserInformationObjectClass"),

2530 0x318d: (0x001f, None, None, 4, None, None, "UserInformationOffice"),

2531 0x318e: (0x001f, None, None, 4, None, None, "UserInformationOfflineAddressBook"),

2532 0x318f: (0x1102, None, None, 4, None, None, "UserInformationOneOffSupervisionList"),

2533 0x3190: (0x001f, None, None, 4, None, None, "UserInformationOrganizationalUnitRoot"),

2534 0x3191: (0x101f, None, None, 4, None, None, "UserInformationOrgLeaders"),

2535 0x3192: (0x001f, None, None, 4, None, None, "UserInformationOriginatingServer"),

2536 0x3193: (0x101f, None, None, 4, None, None, "UserInformationOtherDisplayNames"),

2537 0x3194: (0x101f, None, None, 4, None, None, "UserInformationOtherFax"),

2538 0x3195: (0x001f, None, None, 4, None, None, "UserInformationOwaMailboxPolicy"),

2539 0x3196: (0x101f, None, None, 4, None, None, "UserInformationOwners"),

2540 0x3197: (0x001f, None, None, 4, None, None, "UserInformationPreviousDatabase"),

2541 0x3198: (0x101f, None, None, 4, None, None, "UserInformationPublicFolderContacts"),

2542 0x3199: (0x000b, None, None, 4, None, None, "UserInformationPuidEmailAddressEnabled"),

2543 0x319a: (0x101f, None, None, 4, None, None, "UserInformationPurportedSearchUI"),

2544 0x319b: (0x0014, None, None, 4, None, None, "UserInformationPasswordLastSetRaw"),

2545 0x319c: (0x001f, None, None, 4, None, None, "UserInformationPhoneticCompany"),

2546 0x319d: (0x001f, None, None, 4, None, None, "UserInformationPhoneticDisplayName"),

2547 0x319e: (0x001f, None, None, 4, None, None, "UserInformationPhoneticDepartment"),

2548 0x319f: (0x001f, None, None, 4, None, None, "UserInformationPhoneticFirstName"),

2549 0x31a0: (0x001f, None, None, 4, None, None, "UserInformationPhoneticLastName"),

2550 0x31a1: (0x101f, None, None, 4, None, None, "UserInformationPoliciesExcluded"),

2551 0x31a2: (0x101f, None, None, 4, None, None, "UserInformationPoliciesIncluded"),

2552 0x31a3: (0x0003, None, None, 4, None, None, "UserInformationPrimaryGroupId"),

2553 0x31a4: (0x101f, None, None, 4, None, None, "UserInformationProtocolSettings"),

2554 0x31a5: (0x0003, None, None, 4, None, None, "UserInformationProvisioningFlags"),

2555 0x31a6: (0x001f, None, None, 4, None, None, "UserInformationQueryBaseDN"),

2556 0x31a7: (0x101f, None, None, 4, None, None, "UserInformationRawCanonicalName"),

2557 0x31a8: (0x1003, None, None, 4, None, None, "UserInformationRawCapabilities"),

2558 0x31a9: (0x001f, None, None, 4, None, None, "UserInformationRawExternalEmailAddress"),

2559 0x31aa: (0x001f, None, None, 4, None, None, "UserInformationRawManagedBy"),

2560 0x31ab: (0x001f, None, None, 4, None, None, "UserInformationRawName"),

2561 0x31ac: (0x001f, None, None, 4, None, None, "UserInformationRawDisplayName"),

2562 0x31ad: (0x0102, None, None, 4, None, None, "UserInformationRawOnPremisesObjectId"),

2563 0x31ae: (0x001f, None, None, 4, None, None, "UserInformationRecipientContainer"),

2564 0x31af: (0x001f, None, None, 4, None, None, "UserInformationRecipientFilter"),

2565 0x31b0: (0x101f, None, None, 4, None, None, "UserInformationRecipientFilterMetadata"),

2566 0x31b1: (0x0003, None, None, 4, None, None, "UserInformationRecipientTypeDetailsValue"),

2567 0x31b2: (0x0102, None, None, 4, None, None, "UserInformationReplicationSignature"),

2568 0x31b3: (0x101f, None, None, 4, None, None, "UserInformationRejectMessagesFrom"),

2569 0x31b4: (0x101f, None, None, 4, None, None, "UserInformationRejectMessagesFromBL"),

2570 0x31b5: (0x101f, None, None, 4, None, None, "UserInformationRejectMessagesFromDLMembers"),

2571 0x31b6: (0x101f, None, None, 4, None, None, "UserInformationRejectMessagesFromDLMembersBL"),

2572 0x31b7: (0x0003, None, None, 4, None, None, "UserInformationReleaseTrack"),

2573 0x31b8: (0x001f, None, None, 4, None, None, "UserInformationRemoteAccountPolicy"),

2574 0x31b9: (0x000b, None, None, 4, None, None, "UserInformationReportToManagerEnabled"),

2575 0x31ba: (0x000b, None, None, 4, None, None, "UserInformationReportToOriginatorEnabled"),

2576 0x31bb: (0x0003, None, None, 4, None, None, "UserInformationResourceCapacity"),

2577 0x31bc: (0x101f, None, None, 4, None, None, "UserInformationResourceMetaData"),

2578 0x31bd: (0x001f, None, None, 4, None, None, "UserInformationResourcePropertiesDisplay"),

2579 0x31be: (0x101f, None, None, 4, None, None, "UserInformationResourceSearchProperties"),

2580 0x31bf: (0x001f, None, None, 4, None, None, "UserInformationRetentionComment"),

2581 0x31c0: (0x001f, None, None, 4, None, None, "UserInformationRetentionUrl"),

2582 0x31c1: (0x101f, None, None, 4, None, None, "UserInformationRMSComputerAccounts"),

2583 0x31c2: (0x001f, None, None, 4, None, None, "UserInformationRoleAssignmentPolicy"),

2584 0x31c3: (0x0003, None, None, 4, None, None, "UserInformationRoleGroupTypeId"),

2585 0x31c4: (0x001f, None, None, 4, None, None, "UserInformationRTCSIPPrimaryUserAddress"),

2586 0x31c5: (0x001f, None, None, 4, None, None, "UserInformationRtcSipLine"),

2587 0x31c6: (0x0102, None, None, 4, None, None, "UserInformationSafeRecipientsHash"),

2588 0x31c7: (0x0102, None, None, 4, None, None, "UserInformationSafeSendersHash"),

2589 0x31c8: (0x001f, None, None, 4, None, None, "UserInformationSamAccountName"),

2590 0x31c9: (0x001f, None, None, 4, None, None, "UserInformationSatchmoClusterIp"),

2591 0x31ca: (0x0003, None, None, 4, None, None, "UserInformationSatchmoDGroup"),

2592 0x31cb: (0x0003, None, None, 4, None, None, "UserInformationSCLDeleteThresholdInt"),

2593 0x31cc: (0x0003, None, None, 4, None, None, "UserInformationSCLJunkThresholdInt"),

2594 0x31cd: (0x0003, None, None, 4, None, None, "UserInformationSCLQuarantineThresholdInt"),

2595 0x31ce: (0x0003, None, None, 4, None, None, "UserInformationSCLRejectThresholdInt"),

2596 0x31cf: (0x1102, None, None, 4, None, None, "UserInformationSecurityProtocol"),

2597 0x31d0: (0x000b, None, None, 4, None, None, "UserInformationSendOofMessageToOriginatorEnabled"),

2598 0x31d1: (0x001f, None, None, 4, None, None, "UserInformationServerLegacyDN"),

2599 0x31d2: (0x001f, None, None, 4, None, None, "UserInformationSharePointLinkedBy"),

2600 0x31d3: (0x101f, None, None, 4, None, None, "UserInformationSharePointResources"),

2601 0x31d4: (0x001f, None, None, 4, None, None, "UserInformationSharePointSiteInfo"),

2602 0x31d5: (0x001f, None, None, 4, None, None, "UserInformationSharePointUrl"),

2603 0x31d6: (0x101f, None, None, 4, None, None, "UserInformationSharingPartnerIdentitiesRaw"),

2604 0x31d7: (0x001f, None, None, 4, None, None, "UserInformationSharingPolicy"),

2605 0x31d8: (0x001f, None, None, 4, None, None, "UserInformationSid"),

2606 0x31d9: (0x101f, None, None, 4, None, None, "UserInformationSidHistory"),

2607 0x31da: (0x001f, None, None, 4, None, None, "UserInformationSiloName"),

2608 0x31db: (0x001f, None, None, 4, None, None, "UserInformationSkypeId"),

2609 0x31dc: (0x1102, None, None, 4, None, None, "UserInformationSMimeCertificate"),

2610 0x31dd: (0x001f, None, None, 4, None, None, "UserInformationSourceAnchor"),

2611 0x31de: (0x0040, None, None, 4, None, None, "UserInformationStsRefreshTokensValidFrom"),

2612 0x31df: (0x0014, None, None, 4, None, None, "UserInformationSystemMailboxRetainDeletedItemsFor"),

2613 0x31e0: (0x001f, None, None, 4, None, None, "UserInformationSystemMailboxRulesQuota"),

2614 0x31e1: (0x0040, None, None, 4, None, None, "UserInformationTeamMailboxExpiration"),

2615 0x31e2: (0x101f, None, None, 4, None, None, "UserInformationTeamMailboxShowInClientList"),

2616 0x31e3: (0x001f, None, None, 4, None, None, "UserInformationTelephoneAssistant"),

2617 0x31e4: (0x001f, None, None, 4, None, None, "UserInformationThrottlingPolicy"),

2618 0x31e5: (0x0102, None, None, 4, None, None, "UserInformationThumbnailPhoto"),

2619 0x31e6: (0x001f, None, None, 4, None, None, "UserInformationTitle"),

2620 0x31e7: (0x101f, None, None, 4, None, None, "UserInformationTokenGroupsGlobalAndUniversal"),

2621 0x31e8: (0x0003, None, None, 4, None, None, "UserInformationTransportSettingFlags"),

2622 0x31e9: (0x101f, None, None, 4, None, None, "UserInformationUMAddresses"),

2623 0x31ea: (0x101f, None, None, 4, None, None, "UserInformationUMCallingLineIds"),

2624 0x31eb: (0x101f, None, None, 4, None, None, "UserInformationUMDtmfMap"),

2625 0x31ec: (0x0003, None, None, 4, None, None, "UserInformationUMEnabledFlags"),

2626 0x31ed: (0x0003, None, None, 4, None, None, "UserInformationUMEnabledFlags2"),

2627 0x31ee: (0x001f, None, None, 4, None, None, "UserInformationUMMailboxPolicy"),

2628 0x31ef: (0x0102, None, None, 4, None, None, "UserInformationUMPinChecksum"),

2629 0x31f0: (0x001f, None, None, 4, None, None, "UserInformationUMRecipientDialPlanId"),

2630 0x31f1: (0x0003, None, None, 4, None, None, "UserInformationUMServerWritableFlags"),

2631 0x31f2: (0x0102, None, None, 4, None, None, "UserInformationUMSpokenName"),

2632 0x31f3: (0x101f, None, None, 4, None, None, "UserInformationUnifiedGroupEventSubscriptionBL"),

2633 0x31f4: (0x101f, None, None, 4, None, None, "UserInformationUnifiedGroupEventSubscriptionLink"),

2634 0x31f5: (0x001f, None, None, 4, None, None, "UserInformationUnifiedGroupFileNotificationsSettings"),

2635 0x31f6: (0x101f, None, None, 4, None, None, "UserInformationUnifiedGroupMembersBL"),

2636 0x31f7: (0x101f, None, None, 4, None, None, "UserInformationUnifiedGroupMembersLink"),

2637 0x31f8: (0x001f, None, None, 4, None, None, "UserInformationUnifiedGroupProvisioningOption"),

2638 0x31f9: (0x0003, None, None, 4, None, None, "UserInformationUnifiedGroupSecurityFlags"),

2639 0x31fa: (0x0003, None, None, 4, None, None, "UserInformationUnifiedGroupSKU"),

2640 0x31fb: (0x0102, None, None, 4, None, None, "UserInformationUnifiedMailboxAccount"),

2641 0x31fc: (0x0003, None, None, 4, None, None, "UserInformationUserAccountControl"),

2642 0x31fd: (0x001f, None, None, 4, None, None, "UserInformationUserPrincipalNameRaw"),

2643 0x31fe: (0x000b, None, None, 4, None, None, "UserInformationUseDatabaseQuotaDefaults"),

2644 0x31ff: (0x0014, None, None, 4, None, None, "UserInformationUsnChanged"),

2645 0x3200: (0x0014, None, None, 4, None, None, "UserInformationUsnCreated"),

2646 0x3201: (0x0002, None, None, 4, None, None, "UserInformationUserState"),

2647 0x3202: (0x101f, None, None, 4, None, None, "UserInformationVoiceMailSettings"),

2648 0x3203: (0x001f, None, None, 4, None, None, "UserInformationWhenChangedRaw"),

2649 0x3204: (0x001f, None, None, 4, None, None, "UserInformationWhenCreatedRaw"),

2650 0x3205: (0x001f, None, None, 4, None, None, "UserInformationWindowsEmailAddress"),

2651 0x3206: (0x001f, None, None, 4, None, None, "UserInformationWindowsLiveID"),

2652 0x3207: (0x001f, None, None, 4, None, None, "UserInformationYammerGroupAddress"),

2653 0x3208: (0x001f, None, None, 4, None, None, "UserInformationOperatorNumber"),

2654 0x3209: (0x0040, None, None, 4, None, None, "UserInformationWhenReadUTC"),

2655 0x320a: (0x0003, None, None, 4, None, None, "UserInformationPreviousRecipientTypeDetailsHigh"),

2656 0x320b: (0x0003, None, None, 4, None, None, "UserInformationRemoteRecipientTypeHigh"),

2657 0x320c: (0x0003, None, None, 4, None, None, "UserInformationRecipientTypeDetailsValueHigh"),

2658 0x320d: (0x0040, None, None, 4, None, None, "UserInformationFamilyMembersUpdateInProgressStartTime"),

2659 0x320e: (0x000b, None, None, 4, None, None, "UserInformationIsFamilyMailbox"),

2660 0x320f: (0x0040, None, None, 4, None, None, "UserInformationMailboxRegionLastUpdateTime"),

2661 0x3210: (0x0003, None, None, 4, None, None, "UserInformationSubscribeExistingGroupMembersStatus"),

2662 0x3211: (0x101f, None, None, 4, None, None, "UserInformationGroupMembers"),

2663 0x3212: (0x0003, None, None, 4, None, None, "UserInformationRecipientDisplayTypeRaw"),

2664 0x3213: (0x001f, None, None, 4, None, None, "UserInformationUITEntryVersion"),

2665 0x3214: (0x001f, None, None, 4, None, None, "UserInformationLastRefreshedFrom"),

2666 0x3215: (0x000b, None, None, 4, None, None, "UserInformationIsGroupMailBox"),

2667 0x3216: (0x0003, None, None, 4, None, None, "UserInformationMailboxFolderSet"),

2668 0x3217: (0x000b, None, None, 4, None, None, "UserInformationWasInactiveMailbox"),

2669 0x3218: (0x0040, None, None, 4, None, None, "UserInformationInactiveMailboxRetireTime"),

2670 0x3219: (0x0040, None, None, 4, None, None, "UserInformationOrphanSoftDeleteTrackingTime"),

2671 0x321a: (0x0014, None, None, 4, None, None, "UserInformationSubscriptions"),

2672 0x321b: (0x001f, None, None, 4, None, None, "UserInformationOtherMail"),

2673 0x321c: (0x000b, None, None, 4, None, None, "UserInformationIsCIDAddedToMserv"),

2674 0x321d: (0x0003, None, None, 4, None, None, "UserInformationMailboxWorkloads"),

2675 0x321e: (0x0040, None, None, 4, None, None, "UserInformationCacheLastAccessTime"),

2676 0x3233: (0x000b, None, None, 4, None, None, "UserInformationPublicFolderClientAccess"),

2677 0x330b: (0x0003, None, None, 4, None, None, "BigFunnelLargePOITableTotalPages"),

2678 0x330c: (0x0003, None, None, 4, None, None, "BigFunnelLargePOITableAvailablePages"),

2679 0x330d: (0x0014, None, None, 4, None, None, "BigFunnelPOISize"),

2680 0x330e: (0x0003, None, None, 4, None, None, "BigFunnelMessageCount"),

2681 0x330f: (0x000b, None, None, 4, None, None, "FastIsEnabled"),

2682 0x3310: (0x0003, None, None, 4, None, None, "NeedsToMove"),

2683 0x3311: (0x0003, None, None, 4, None, None, "MCDBMessageTableTotalPages"),

2684 0x3312: (0x0003, None, None, 4, None, None, "MCDBMessageTableAvailablePages"),

2685 0x3313: (0x0003, None, None, 4, None, None, "MCDBOtherTablesTotalPages"),

2686 0x3314: (0x0003, None, None, 4, None, None, "MCDBOtherTablesAvailablePages"),

2687 0x3315: (0x0003, None, None, 4, None, None, "MCDBBigFunnelFilterTableTotalPages"),

2688 0x3316: (0x0003, None, None, 4, None, None, "MCDBBigFunnelFilterTableAvailablePages"),

2689 0x3317: (0x0003, None, None, 4, None, None, "MCDBBigFunnelLargePOITableTotalPages"),

2690 0x3318: (0x0003, None, None, 4, None, None, "MCDBBigFunnelLargePOITableAvailablePages"),

2691 0x3319: (0x0014, None, None, 4, None, None, "MCDBSize"),

2692 0x3320: (0x0014, None, None, 4, None, None, "MCDBAvailableSpace"),

2693 0x3321: (0x0003, None, None, 4, None, None, "MCDBBigFunnelPostingListTableTotalPages"),

2694 0x3322: (0x0003, None, None, 4, None, None, "MCDBBigFunnelPostingListTableAvailablePages"),

2695 0x3323: (0x0005, None, None, 4, None, None, "MCDBMessageTablePercentReplicated"),

2696 0x3324: (0x0005, None, None, 4, None, None, "MCDBBigFunnelFilterTablePercentReplicated"),

2697 0x3325: (0x0005, None, None, 4, None, None, "MCDBBigFunnelLargePOITablePercentReplicated"),

2698 0x3326: (0x0005, None, None, 4, None, None, "MCDBBigFunnelPostingListTablePercentReplicated"),

2699 0x3327: (0x0003, None, None, 4, None, None, "BigFunnelMailboxCreationVersion"),

2700 0x3328: (0x0003, None, None, 4, None, None, "BigFunnelAttributeVectorCommonVersion"),

2701 0x3329: (0x0003, None, None, 4, None, None, "BigFunnelAttributeVectorSharePointVersion"),

2702 0x3330: (0x0014, None, None, 4, None, None, "BigFunnelIndexedSize"),

2703 0x3331: (0x0014, None, None, 4, None, None, "BigFunnelPartiallyIndexedSize"),

2704 0x3332: (0x0014, None, None, 4, None, None, "BigFunnelNotIndexedSize"),

2705 0x3333: (0x0014, None, None, 4, None, None, "BigFunnelCorruptedSize"),

2706 0x3334: (0x0014, None, None, 4, None, None, "BigFunnelStaleSize"),

2707 0x3335: (0x0014, None, None, 4, None, None, "BigFunnelShouldNotBeIndexedSize"),

2708 0x3336: (0x0003, None, None, 4, None, None, "BigFunnelIndexedCount"),

2709 0x3337: (0x0003, None, None, 4, None, None, "BigFunnelPartiallyIndexedCount"),

2710 0x3338: (0x0003, None, None, 4, None, None, "BigFunnelNotIndexedCount"),

2711 0x3339: (0x0003, None, None, 4, None, None, "BigFunnelCorruptedCount"),

2712 0x333a: (0x0003, None, None, 4, None, None, "BigFunnelStaleCount"),

2713 0x333b: (0x0003, None, None, 4, None, None, "BigFunnelShouldNotBeIndexedCount"),

2714 0x333c: (0x0005, None, None, 4, None, None, "BigFunnelL1Rank"),

2715 0x333d: (0x0002, None, None, 4, None, None, "BigFunnelResultSets"),

2716 0x333e: (0x000b, None, None, 4, None, None, "BigFunnelMaintainRefiners"),

2717 0x333f: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTableBuckets"),

2718 0x3340: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTargetTableBuckets"),

2719 0x3341: (0x101f, None, None, 4, None, None, "BigFunnelL1FeatureNames"),

2720 0x3342: (0x1003, None, None, 4, None, None, "BigFunnelL1FeatureValues"),

2721 0x3343: (0x0003, None, None, 4, None, None, "MCDBLogonScenarioTotalPages"),

2722 0x3344: (0x0003, None, None, 4, None, None, "MCDBLogonScenarioAvailablePages"),

2723 0x3345: (0x0003, None, None, 4, None, None, "BigFunnelMasterIndexVersion"),

2724 0x33f0: (0x0102, None, None, 4, None, None, "ControlDataForRecordReviewNotificationTBA"),

2725 0x33fe: (0x0102, None, None, 4, None, None, "ControlDataForBigFunnelQueryParityAssistant"),

2726 0x33ff: (0x0003, None, None, 4, None, None, "BigFunnelQueryParityAssistantVersion"),

2727 0x3401: (0x0003, None, None, 4, None, None, "MessageTableTotalPages"),

2728 0x3402: (0x0003, None, None, 4, None, None, "MessageTableAvailablePages"),

2729 0x3403: (0x0003, None, None, 4, None, None, "OtherTablesTotalPages"),

2730 0x3404: (0x0003, None, None, 4, None, None, "OtherTablesAvailablePages"),

2731 0x3405: (0x0003, None, None, 4, None, None, "AttachmentTableTotalPages"),

2732 0x3406: (0x0003, None, None, 4, None, None, "AttachmentTableAvailablePages"),

2733 0x3407: (0x0003, None, None, 4, None, None, "MailboxTypeVersion"),

2734 0x3408: (0x1048, None, None, 4, None, None, "MailboxPartitionMailboxGuids"),

2735 0x3409: (0x0003, None, None, 4, None, None, "BigFunnelFilterTableTotalPages"),

2736 0x340a: (0x0003, None, None, 4, None, None, "BigFunnelFilterTableAvailablePages"),

2737 0x340b: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTableTotalPages"),

2738 0x340c: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTableAvailablePages"),

2739 0x3417: (0x001f, None, None, 4, None, None, "ProviderDisplayIcon"),

2740 0x3418: (0x001f, None, None, 4, None, None, "ProviderDisplayName"),

2741 0x3432: (0x0102, None, None, 4, None, None, "ControlDataForDirectoryProcessorAssistant"),

2742 0x3433: (0x000b, None, None, 4, None, None, "NeedsDirectoryProcessor"),

2743 0x3434: (0x101f, None, None, 4, None, None, "RetentionQueryIds"),

2744 0x3435: (0x0014, None, None, 4, None, None, "RetentionQueryInfo"),

2745 0x3436: (0x0040, None, None, 4, None, None, "MailboxLastProcessedTimestamp"),

2746 0x3437: (0x0102, None, None, 4, None, None, "ControlDataForPublicFolderAssistant"),

2747 0x3438: (0x0102, None, None, 4, None, None, "ControlDataForInferenceTrainingAssistant"),

2748 0x3439: (0x000b, None, None, 4, None, None, "InferenceEnabled"),

2749 0x343b: (0x0003, None, None, 4, None, None, "ContactLinking"),

2750 0x343c: (0x0102, None, None, 4, None, None, "ControlDataForOABGeneratorAssistant"),

2751 0x343d: (0x0003, None, None, 4, None, None, "ContactSaveVersion"),

2752 0x3440: (0x0102, None, None, 4, None, None, "PushNotificationSubscriptionType"),

2753 0x3442: (0x0102, None, None, 4, None, None, "ControlDataForInferenceDataCollectionAssistant"),

2754 0x3443: (0x0102, None, None, 4, None, None, "InferenceDataCollectionProcessingState"),

2755 0x3444: (0x0102, None, None, 4, None, None, "ControlDataForPeopleRelevanceAssistant"),

2756 0x3445: (0x0003, None, None, 4, None, None, "SiteMailboxInternalState"),

2757 0x3446: (0x0102, None, None, 4, None, None, "ControlDataForSiteMailboxAssistant"),

2758 0x3447: (0x0003, None, None, 4, None, None, "InferenceTrainingLastContentCount"),

2759 0x3448: (0x0040, None, None, 4, None, None, "InferenceTrainingLastAttemptTimestamp"),

2760 0x3449: (0x0040, None, None, 4, None, None, "InferenceTrainingLastSuccessTimestamp"),

2761 0x344a: (0x0003, None, None, 4, None, None, "InferenceUserCapabilityFlags"),

2762 0x344b: (0x0102, None, None, 4, None, None, "ControlDataForMailboxAssociationReplicationAssistant"),

2763 0x344c: (0x0040, None, None, 4, None, None, "MailboxAssociationNextReplicationTime"),

2764 0x344d: (0x0003, None, None, 4, None, None, "MailboxAssociationProcessingFlags"),

2765 0x344e: (0x0102, None, None, 4, None, None, "ControlDataForSharePointSignalStoreAssistant"),

2766 0x344f: (0x0102, None, None, 4, None, None, "ControlDataForPeopleCentricTriageAssistant"),

2767 0x3450: (0x0003, None, None, 4, None, None, "NotificationBrokerSubscriptions"),

2768 0x3452: (0x0014, None, None, 4, None, None, "ElcLastRunTotalProcessingTime"),

2769 0x3453: (0x0014, None, None, 4, None, None, "ElcLastRunSubAssistantProcessingTime"),

2770 0x3454: (0x0014, None, None, 4, None, None, "ElcLastRunUpdatedFolderCount"),

2771 0x3455: (0x0014, None, None, 4, None, None, "ElcLastRunTaggedFolderCount"),

2772 0x3456: (0x0014, None, None, 4, None, None, "ElcLastRunUpdatedItemCount"),

2773 0x3457: (0x0014, None, None, 4, None, None, "ElcLastRunTaggedWithArchiveItemCount"),

2774 0x3458: (0x0014, None, None, 4, None, None, "ElcLastRunTaggedWithExpiryItemCount"),

2775 0x3459: (0x0014, None, None, 4, None, None, "ElcLastRunDeletedFromRootItemCount"),

2776 0x345a: (0x0014, None, None, 4, None, None, "ElcLastRunDeletedFromDumpsterItemCount"),

2777 0x345b: (0x0014, None, None, 4, None, None, "ElcLastRunArchivedFromRootItemCount"),

2778 0x345c: (0x0014, None, None, 4, None, None, "ElcLastRunArchivedFromDumpsterItemCount"),

2779 0x345d: (0x0040, None, None, 4, None, None, "ScheduledISIntegLastFinished"),

2780 0x345f: (0x0040, None, None, 4, None, None, "ELCLastSuccessTimestamp"),

2781 0x3460: (0x0040, None, None, 4, None, None, "EventEmailReminderTimer"),

2782 0x3463: (0x0102, None, None, 4, None, None, "ControlDataForGroupMailboxAssistant"),

2783 0x3464: (0x0003, None, None, 4, None, None, "ItemsPendingUpgrade"),

2784 0x3465: (0x0003, None, None, 4, None, None, "ConsumerSharingCalendarSubscriptionCount"),

2785 0x3466: (0x0003, None, None, 4, None, None, "GroupMailboxGeneratedPhotoVersion"),

2786 0x3467: (0x0102, None, None, 4, None, None, "GroupMailboxGeneratedPhotoSignature"),

2787 0x3468: (0x0003, None, None, 4, None, None, "AadGroupPublishedVersion"),

2788 0x3469: (0x001f, None, None, 4, None, None, "ElcFaiSaveStatus"),

2789 0x346a: (0x001f, None, None, 4, None, None, "ElcFaiDeleteStatus"),

2790 0x346b: (0x0102, None, None, 4, None, None, "ControlDataForCleanupActionsAssistant"),

2791 0x346c: (0x1003, None, None, 4, None, None, "HolidayCalendarVersionInfo"),

2792 0x346d: (0x0003, None, None, 4, None, None, "HolidayCalendarSubscriptionCount"),

2793 0x346e: (0x0003, None, None, 4, None, None, "HolidayCalendarHierarchyVersion"),

2794 0x346f: (0x0003, None, None, 4, None, None, "CalendarVersion"),

2795 0x3470: (0x0102, None, None, 4, None, None, "ControlDataForDefaultViewIndexAssistant"),

2796 0x3471: (0x0040, None, None, 4, None, None, "DefaultViewAssistantLastIndexTime"),

2797 0x3472: (0x0102, None, None, 4, None, None, "ControlDataForAuditTimeBasedAssitantAssistant"),

2798 0x3473: (0x0040, None, None, 4, None, None, "SystemCategoriesViewLastIndexTime"),

2799 0x3474: (0x0102, None, None, 4, None, None, "ControlDataForComplianceJobAssistant"),

2800 0x3475: (0x0102, None, None, 4, None, None, "ControlDataForGoLocalAssistant"),

2801 0x3476: (0x0102, None, None, 4, None, None, "ControlDataForUserGroupsRelevanceAssistant"),

2802 0x3477: (0x0040, None, None, 4, None, None, "GroupMailboxLastUsageCollectionTime"),

2803 0x3478: (0x0040, None, None, 4, None, None, "EventPushReminderTimer"),

2804 0x3479: (0x000b, None, None, 4, None, None, "PushReminderSubscriptionType"),

2805 0x347a: (0x0102, None, None, 4, None, None, "ControlDataForHashtagsRelevanceAssistant"),

2806 0x347b: (0x0102, None, None, 4, None, None, "ControlDataForSearchFeatureExtractionAssistant"),

2807 0x347c: (0x0040, None, None, 4, None, None, "EventMeetingConflictTimer"),

2808 0x347d: (0x0040, None, None, 4, None, None, "MentionsViewLastIndexTime"),

2809 0x347e: (0x0102, None, None, 4, None, None, "O365SuiteNotificationType"),

2810 0x347f: (0x0102, None, None, 4, None, None, "ControlDataForResourceUsageLoggingTimeBasedAssistant"),

2811 0x3480: (0x0102, None, None, 4, None, None, "ControlDataForConferenceRoomUsageAssistant"),

2812 0x3481: (0x0102, None, None, 4, None, None, "ControlDataForRetrospectiveFeaturizationAssistant"),

2813 0x3482: (0x000b, None, None, 4, None, None, "ConferenceRoomUsageUpdateNeeded"),

2814 0x3483: (0x0102, None, None, 4, None, None, "ControlDataForGriffinTimeBasedAssistant"),

2815 0x3484: (0x0102, None, None, 4, None, None, "FeaturizerExperimentId"),

2816 0x3485: (0x0102, None, None, 4, None, None, "ControlDataForPeopleInsightsTimeBasedAssistant"),

2817 0x3486: (0x001f, None, None, 4, None, None, "MailboxPreferredLocation"),

2818 0x3487: (0x0102, None, None, 4, None, None, "ControlDataForContentSubmissionAssistant"),

2819 0x3489: (0x0102, None, None, 4, None, None, "ControlDataForPublicFolderHierarchySyncAssistant"),

2820 0x348a: (0x0102, None, None, 4, None, None, "LastActiveParentEntryId"),

2821 0x348b: (0x000b, None, None, 4, None, None, "WasParentDeletedItems"),

2822 0x348c: (0x0003, None, None, 4, None, None, "PushSyncProcessingFlags"),

2823 0x348d: (0x0102, None, None, 4, None, None, "ControlDataForSuggestedUserGroupAssociationsAssistant"),

2824 0x348e: (0x0102, None, None, 4, None, None, "ControlDataForReminderSettingsAssistant"),

2825 0x348f: (0x0102, None, None, 4, None, None, "ControlDataForFileExtractionTimeBasedAssistant"),

2826 0x3490: (0x0102, None, None, 4, None, None, "ControlDataForMailboxDataExportAssistant"),

2827 0x3491: (0x0102, None, None, 4, None, None, "ControlDataForXrmActivityStreamMaintenanceAssistant"),

2828 0x3492: (0x0003, None, None, 4, None, None, "GroupMailboxSegmentationVersion"),

2829 0x3493: (0x0102, None, None, 4, None, None, "ControlDataForTimeProfileTimeBasedAssistant"),

2830 0x3494: (0x000b, None, None, 4, None, None, "ReactorSubscriptionCreationNeeded"),

2831 0x3495: (0x0102, None, None, 4, None, None, "ControlDataForMailboxUsageAnalysisAssistant"),

2832 0x3496: (0x0102, None, None, 4, None, None, "ControlDataForContactCleanUpAssistant"),

2833 0x3497: (0x0102, None, None, 4, None, None, "ControlDataForGroupCalendarSubscriptionAssistant"),

2834 0x3498: (0x0102, None, None, 4, None, None, "ControlDataForGriffinLightweightTimeBasedAssistant"),

2835 0x3499: (0x0102, None, None, 4, None, None, "ControlDataForXrmAutoTaggingMaintenanceAssistant"),

2836 0x349a: (0x0102, None, None, 4, None, None, "ControlDataForCalculatedValueTimeBasedAssistant"),

2837 0x349b: (0x0102, None, None, 4, None, None, "ControlDataForSkypeContactCleanUpAssistant"),

2838 0x349c: (0x0102, None, None, 4, None, None, "ControlDataForShardRelevancyAssistant"),

2839 0x349d: (0x0003, None, None, 4, None, None, "MeetingLocationCacheVersion"),

2840 0x349e: (0x0040, None, None, 4, None, None, "SuperFocusedViewLastIndexTime"),

2841 0x34a0: (0x0102, None, None, 4, None, None, "ControlDataForCalendarFeaturizationAssistant"),

2842 0x34a1: (0x0102, None, None, 4, None, None, "ControlDataForBigFunnelRetryFeederTimeBasedAssistant"),

2843 0x34a2: (0x0003, None, None, 4, None, None, "MeetingLocationCacheVersionV3"),

2844 0x34a3: (0x0102, None, None, 4, None, None, "ControlDataForSharingMigrationTimeBasedAssistant"),

2845 0x34a4: (0x0102, None, None, 4, None, None, "ControlDataForDynamicAttachmentTimeBasedAssistant"),

2846 0x34a5: (0x0102, None, None, 4, None, None, "ControlDataForSharingSyncAssistant"),

2847 0x34a6: (0x0040, None, None, 4, None, None, "TailoredPropertiesViewLastIndexTime"),

2848 0x34a7: (0x000b, None, None, 4, None, None, "AtpDynamicAttachmentEnabled"),

2849 0x34a8: (0x0003, None, None, 4, None, None, "MailboxAssociationVersion"),

2850 0x34af: (0x0102, None, None, 4, None, None, "ResourceUsageAggregate"),

2851 0x34b0: (0x000b, None, None, 4, None, None, "ResourceUsageDataReady"),

2852 0x34b1: (0x0040, None, None, 4, None, None, "ResourceUsageMinDateTime"),

2853 0x34b2: (0x0040, None, None, 4, None, None, "ResourceUsageMaxDateTime"),

2854 0x34b3: (0x0003, None, None, 4, None, None, "ResourceUsageNumberOfActivities"),

2855 0x34b4: (0x0003, None, None, 4, None, None, "ResourceUsageNumberOfCallsSlow"),

2856 0x34b5: (0x0003, None, None, 4, None, None, "ResourceUsageTotalCalls"),

2857 0x34b6: (0x0003, None, None, 4, None, None, "ResourceUsageTotalChunks"),

2858 0x34b7: (0x0003, None, None, 4, None, None, "ResourceUsageTotalCpuTimeKernel"),

2859 0x34b8: (0x0003, None, None, 4, None, None, "ResourceUsageTotalCpuTimeUser"),

2860 0x34b9: (0x0003, None, None, 4, None, None, "ResourceUsageTotalDatabaseReadWaitTime"),

2861 0x34ba: (0x0003, None, None, 4, None, None, "ResourceUsageTotalDatabaseTime"),

2862 0x34bb: (0x0014, None, None, 4, None, None, "ResourceUsageTotalLogBytes"),

2863 0x34bc: (0x0003, None, None, 4, None, None, "ResourceUsageTotalPagesDirtied"),

2864 0x34bd: (0x0003, None, None, 4, None, None, "ResourceUsageTotalPagesPreread"),

2865 0x34be: (0x0003, None, None, 4, None, None, "ResourceUsageTotalPagesRead"),

2866 0x34bf: (0x0003, None, None, 4, None, None, "ResourceUsageTotalPagesRedirtied"),

2867 0x34c0: (0x0003, None, None, 4, None, None, "ResourceUsageTotalTime"),

2868 0x34c1: (0x0102, None, None, 4, None, None, "ControlDataForPicwAssistant"),

2869 0x34c2: (0x0014, None, None, 4, None, None, "ResourceUsageClientTypeBitmap"),

2870 0x34c3: (0x0003, None, None, 4, None, None, "ConnectorConfigurationCount"),

2871 0x34c4: (0x0102, None, None, 4, None, None, "ResourceUsageRollingAvgRopAggregate"),

2872 0x34c5: (0x0003, None, None, 4, None, None, "ResourceUsageRollingAvgRop"),

2873 0x34c6: (0x0014, None, None, 4, None, None, "ResourceUsageRollingClientTypes"),

2874 0x34c7: (0x0102, None, None, 4, None, None, "ControlDataForComposeGroupSuggestionTimeBasedAssistant"),

2875 0x34c8: (0x000b, None, None, 4, None, None, "HasSubstrateData"),

2876 0x34c9: (0x0102, None, None, 4, None, None, "ControlDataForAddressListIndexAssistant"),

2877 0x34ca: (0x0102, None, None, 4, None, None, "ControlDataForActivitySharingTimeBasedAssistant"),

2878 0x34cb: (0x0102, None, None, 4, None, None, "ControlDataForShardRelevancyMultiStepAssistant"),

2879 0x34cc: (0x0102, None, None, 4, None, None, "ControlDataForXrmProvisioningTimeBasedAssistant"),

2880 0x34cd: (0x0102, None, None, 4, None, None, "ControlDataForSmbTenantProvisioningAssistant"),

2881 0x34ce: (0x0102, None, None, 4, None, None, "ControlDataForSupervisoryReviewTimeBasedAssistant"),

2882 0x34cf: (0x0102, None, None, 4, None, None, "ControlDataForMailboxQuotaAssistant"),

2883 0x34d0: (0x000b, None, None, 4, None, None, "IsQuotaSetByMailboxQuotaAssistant"),

2884 0x34d1: (0x0040, None, None, 4, None, None, "SuperReactClientViewLastIndexTime"),

2885 0x34d2: (0x0003, None, None, 4, None, None, "FileFolderFlags"),

2886 0x3500: (0x0102, None, None, 4, None, None, "ControlDataForBookingsTimeBasedAssistant"),

2887 0x35d8: (0x0102, None, None, 4, None, None, "RootEntryId"),

2888 0x35e1: (0x0102, None, None, 4, None, None, "IpmInboxEntryId"),

2889 0x35e8: (0x0102, None, None, 4, None, None, "SpoolerQueueEntryId"),

2890 0x35e9: (0x0102, None, None, 4, None, None, "ProtectedMailboxKey"),

2891 0x35ea: (0x0102, None, None, 4, None, None, "SyncRootFolderEntryId"),

2892 0x35eb: (0x0102, None, None, 4, None, None, "UMVoicemailFolderEntryId"),

2893 0x35ed: (0x0102, None, None, 4, None, None, "EHAMigrationFolderEntryId"),

2894 0x35f6: (0x0102, None, None, 4, None, None, "DeletionsFolderEntryId"),

2895 0x35f7: (0x0102, None, None, 4, None, None, "PurgesFolderEntryId"),

2896 0x35f8: (0x0102, None, None, 4, None, None, "DiscoveryHoldsFolderEntryId"),

2897 0x35f9: (0x0102, None, None, 4, None, None, "VersionsFolderEntryId"),

2898 0x35fa: (0x0102, None, None, 4, None, None, "ControlDataForBigFunnelMetricsCollectionAssistant"),

2899 0x35fb: (0x0003, None, None, 4, None, None, "BigFunnelMetricsCollectionAssistantVersion"),

2900 0x35fc: (0x0102, None, None, 4, None, None, "PublicFolderDiscoveryHoldsEntryId"),

2901 0x35fd: (0x0102, None, None, 4, None, None, "SystemFolderEntryId"),

2902 0x35ff: (0x0102, None, None, 4, None, None, "ArchiveFolderEntryId"),

2903 0x361c: (0x0102, None, None, 4, None, None, "PackedNamedProps"),

2904 0x3645: (0x000b, None, None, 4, None, None, "PartOfContentIndexing"),

2905 0x3647: (0x0003, None, None, 4, None, None, "SearchFolderAgeOutTimeout"),

2906 0x3648: (0x0003, None, None, 4, None, None, "SearchFolderPopulationResult"),

2907 0x3649: (0x0102, None, None, 4, None, None, "SearchFolderPopulationDiagnostics"),

2908 0x364a: (0x0003, None, None, 4, None, None, "FolderDatabaseVersion"),

2909 0x364b: (0x0014, None, None, 4, None, None, "SystemMessageCount"),

2910 0x364c: (0x0014, None, None, 4, None, None, "SystemMessageSize"),

2911 0x364d: (0x0014, None, None, 4, None, None, "SystemMessageSizeWarningQuota"),

2912 0x364e: (0x0014, None, None, 4, None, None, "SystemMessageSizeShutoffQuota"),

2913 0x364f: (0x0003, None, None, 4, None, None, "TotalPages"),

2914 0x3651: (0x000b, None, None, 4, None, None, "ClusterMessages"),

2915 0x3652: (0x0102, None, None, 4, None, None, "MessageTenantPartitionHintForValidation"),

2916 0x3653: (0x0102, None, None, 4, None, None, "BigFunnelPOIUncompressed"),

2917 0x3655: (0x000b, None, None, 4, None, None, "BigFunnelPOIIsUpToDate"),

2918 0x3656: (0x000b, None, None, 4, None, None, "AggressiveOportunisticPromotionForMessages"),

2919 0x3657: (0x0102, None, None, 4, None, None, "BigFunnelPartialPOIUncompressed"),

2920 0x3658: (0x0048, None, None, 4, None, None, "MessageMailboxGuidForValidation"),

2921 0x3659: (0x0003, None, None, 4, None, None, "DatabaseSchemaVersion"),

2922 0x365a: (0x0003, None, None, 4, None, None, "BigFunnelPoiNotNeededReason"),

2923 0x365b: (0x000b, None, None, 4, None, None, "PerUserTrackingBasedOnImmutableId"),

2924 0x365c: (0x0003, None, None, 4, None, None, "SetSearchCriteriaFlags"),

2925 0x365d: (0x000b, None, None, 4, None, None, "LargeOnPageThreshold"),

2926 0x3661: (0x000b, None, None, 4, None, None, "SecondaryKeyConstraintEnabled"),

2927 0x3662: (0x001f, None, None, 4, None, None, "SecondaryKey"),

2928 0x3663: (0x0003, None, None, 4, None, None, "BigFunnelPOIContentFlags"),

2929 0x3664: (0x0102, None, None, 4, None, None, "ControlDataForInferenceClutterCleanUpAssistant"),

2930 0x3665: (0x0003, None, None, 4, None, None, "BigFunnelMailboxPOIVersion"),

2931 0x3666: (0x0003, None, None, 4, None, None, "BigFunnelMessageUncompressedPOIVersion"),

2932 0x3669: (0x0102, None, None, 4, None, None, "ControlDataForInferenceTimeModelAssistant"),

2933 0x366a: (0x0003, None, None, 4, None, None, "MailCategorizerProcessedVersion"),

2934 0x368e: (0x0102, None, None, 4, None, None, "BigFunnelPOI"),

2935 0x368f: (0x0003, None, None, 4, None, None, "ContentAggregationFlags"),

2936 0x36bf: (0x0102, None, None, 4, None, None, "UMFaxFolderEntryId"),

2937 0x36cc: (0x001f, None, None, 4, None, None, "RecoveredPublicFolderOriginalPath"),

2938 0x36cd: (0x0102, None, None, 4, None, None, "PerMailboxRecoveryContainerEntryId"),

2939 0x36ce: (0x0102, None, None, 4, None, None, "LostAndFoundFolderEntryId"),

2940 0x36cf: (0x0102, None, None, 4, None, None, "CurrentIPMWasteBasketContainerEntryId"),

2941 0x36d6: (0x0102, None, None, 4, None, None, "RemindersSearchOfflineFolderEntryId"),

2942 0x36db: (0x0040, None, None, 4, None, None, "ContainerTimestamp"),

2943 0x36dc: (0x0102, None, None, 4, None, None, "AppointmentColorName"),

2944 0x36dd: (0x0003, None, None, 4, None, None, "INetUnread"),

2945 0x36de: (0x0003, None, None, 4, None, None, "NetFolderFlags"),

2946 0x36df: (0x0102, None, None, 4, None, None, "FolderWebViewInfo"),

2947 0x36e0: (0x0102, None, None, 4, None, None, "FolderWebViewInfoExtended"),

2948 0x36e1: (0x0003, None, None, 4, None, None, "FolderViewFlags"),

2949 0x36e6: (0x001f, None, None, 4, None, None, "DefaultPostDisplayName"),

2950 0x36eb: (0x0102, None, None, 4, None, None, "FolderViewList"),

2951 0x36ec: (0x0003, None, None, 4, None, None, "AgingPeriod"),

2952 0x36ee: (0x0003, None, None, 4, None, None, "AgingGranularity"),

2953 0x36f0: (0x0003, None, None, 4, None, None, "DefaultFoldersLocaleId"),

2954 0x36f1: (0x000b, None, None, 4, None, None, "InternalAccess"),

2955 0x36f2: (0x0102, None, None, 4, None, None, "PublicFolderSplitStateBinary"),

2956 0x36f3: (0x0102, None, None, 4, None, None, "PublicFolderHierarchySyncNotificationsFolderEntryId"),

2957 0x36f4: (0x000b, None, None, 4, None, None, "IncludeInContentIndex"),

2958 0x36f5: (0x0102, None, None, 4, None, None, "PublicFolderProcessorsStateBinary"),

2959 0x36f6: (0x000b, None, None, 4, None, None, "SystemUse"),

2960 0x36f7: (0x0048, None, None, 4, None, None, "LowLatencyContainerId"),

2961 0x36f8: (0x0003, None, None, 4, None, None, "LowLatencyContainerQuota"),

2962 0x3710: (0x0003, None, None, 4, None, None, "AttachmentMimeSequence"),

2963 0x371c: (0x000b, None, None, 4, None, None, "FailedInboundICalAsAttachment"),

2964 0x3720: (0x001f, None, None, 4, None, None, "AttachmentOriginalUrl"),

2965 0x3880: (0x0102, None, None, 4, None, None, "SyncEventSuppressGuid"),

2966 0x39fd: (0x101f, None, None, 4, None, None, "ListOfContactPhoneNumbersAndEmails"),

2967 0x3a3f: (0x000b, None, None, 4, None, None, "SkipSynchronousDelivery"),

2968 0x3a76: (0x001f, None, None, 4, None, None, "PartnerNetworkId"),

2969 0x3a77: (0x001f, None, None, 4, None, None, "PartnerNetworkUserId"),

2970 0x3a78: (0x001f, None, None, 4, None, None, "PartnerNetworkThumbnailPhotoUrl"),

2971 0x3a79: (0x001f, None, None, 4, None, None, "PartnerNetworkProfilePhotoUrl"),

2972 0x3a7a: (0x001f, None, None, 4, None, None, "PartnerNetworkContactType"),

2973 0x3a7b: (0x0003, None, None, 4, None, None, "RelevanceScore"),

2974 0x3a7c: (0x000b, None, None, 4, None, None, "IsDistributionListContact"),

2975 0x3a7d: (0x000b, None, None, 4, None, None, "IsPromotedContact"),

2976 0x3bfa: (0x101f, None, None, 4, None, None, "UserConfiguredConnectedAccounts"),

2977 0x3bfe: (0x001f, None, None, 4, None, None, "OrgUnitName"),

2978 0x3bff: (0x001f, None, None, 4, None, None, "OrganizationName"),

2979 0x3d0b: (0x001f, None, None, 4, None, None, "ServiceEntryName"),

2980 0x3d22: (0x0102, None, None, 4, None, None, "Win32NTSecurityDescriptor"),

2981 0x3d23: (0x000b, None, None, 4, None, None, "NonWin32ACL"),

2982 0x3d24: (0x000b, None, None, 4, None, None, "ItemLevelACL"),

2983 0x3d2e: (0x0102, None, None, 4, None, None, "ICSGid"),

2984 0x3d87: (0x0003, None, None, 4, None, None, "BigFunnelPostingReplicationScavengedBucketsWatermark"),

2985 0x3d88: (0x0003, None, None, 4, None, None, "BigFunnelPostingListReplicationScavengedBucketsAllowed"),

2986 0x3d89: (0x0040, None, None, 4, None, None, "BigFunnelLastCleanupMaintenance"),

2987 0x3d8b: (0x0040, None, None, 4, None, None, "BigFunnelPostingListLastCompactionMerge"),

2988 0x3d8c: (0x0102, None, None, 4, None, None, "BigFunnelAttributeVectorSharePointDataV1"),

2989 0x3d8d: (0x0014, None, None, 4, None, None, "BigFunnelL1PropertyLengths2V1"),

2990 0x3d8e: (0x0014, None, None, 4, None, None, "BigFunnelL1PropertyLengths1V1Rebuild"),

2991 0x3d8f: (0x000b, None, None, 4, None, None, "MessageSubmittedByOutlook"),

2992 0x3d90: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTargetTableVersion"),

2993 0x3d91: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTargetTableChunkSize"),

2994 0x3d92: (0x0014, None, None, 4, None, None, "BigFunnelL1PropertyLengths1V1"),

2995 0x3d93: (0x0003, None, None, 4, None, None, "ScopeKeyTokenType"),

2996 0x3d94: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTableVersion"),

2997 0x3d95: (0x0003, None, None, 4, None, None, "BigFunnelPostingListTableChunkSize"),

2998 0x3d96: (0x0040, None, None, 4, None, None, "LastTableSizeStatisticsUpdate"),

2999 0x3d97: (0x000b, None, None, 4, None, None, "IcsRestrictionMatch"),

3000 0x3d98: (0x0102, None, None, 4, None, None, "BigFunnelPartialPOI"),

3001 0x3d99: (0x0102, None, None, 4, None, None, "LargeReservedDocIdRanges"),

3002 0x3d9a: (0x0048, None, None, 4, None, None, "DocIdAsImmutableIdGuid"),

3003 0x3d9b: (0x0040, None, None, 4, None, None, "MoveCompletionTime"),

3004 0x3d9c: (0x0102, None, None, 4, None, None, "MaterializedRestrictionSearchRoot"),

3005 0x3d9d: (0x0003, None, None, 4, None, None, "ScheduledISIntegCorruptionCount"),

3006 0x3d9e: (0x0003, None, None, 4, None, None, "ScheduledISIntegExecutionTime"),

3007 0x3da1: (0x0102, None, None, 4, None, None, "QueryCriteriaInternal"),

3008 0x3da2: (0x0040, None, None, 4, None, None, "LastQuotaNotificationTime"),

3009 0x3da3: (0x000b, None, None, 4, None, None, "PropertyPromotionInProgressHiddenItems"),

3010 0x3da4: (0x000b, None, None, 4, None, None, "PropertyPromotionInProgressNormalItems"),

3011 0x3da5: (0x001f, None, None, 4, None, None, "VirtualParentDisplay"),

3012 0x3da6: (0x0003, None, None, 4, None, None, "MailboxTypeDetail"),

3013 0x3da7: (0x0102, None, None, 4, None, None, "InternalTenantHint"),

3014 0x3da8: (0x000b, None, None, 4, None, None, "InternalConversationIndexTracking"),

3015 0x3da9: (0x0102, None, None, 4, None, None, "InternalConversationIndex"),

3016 0x3daa: (0x0102, None, None, 4, None, None, "ConversationItemConversationId"),

3017 0x3dab: (0x0014, None, None, 4, None, None, "VirtualUnreadMessageCount"),

3018 0x3dac: (0x000b, None, None, 4, None, None, "VirtualIsRead"),

3019 0x3dad: (0x000b, None, None, 4, None, None, "IsReadColumn"),

3020 0x3dae: (0x0102, None, None, 4, None, None, "PersistableTenantPartitionHint"),

3021 0x3daf: (0x0102, None, None, 4, None, None, "Internal9ByteChangeNumber"),

3022 0x3db0: (0x0102, None, None, 4, None, None, "Internal9ByteReadCnNew"),

3023 0x3db1: (0x000b, None, None, 4, None, None, "CategoryHeaderLevelStub1"),

3024 0x3db2: (0x000b, None, None, 4, None, None, "CategoryHeaderLevelStub2"),

3025 0x3db3: (0x000b, None, None, 4, None, None, "CategoryHeaderLevelStub3"),

3026 0x3db4: (0x0102, None, None, 4, None, None, "CategoryHeaderAggregateProp0"),

3027 0x3db5: (0x0102, None, None, 4, None, None, "CategoryHeaderAggregateProp1"),

3028 0x3db6: (0x0102, None, None, 4, None, None, "CategoryHeaderAggregateProp2"),

3029 0x3db7: (0x0102, None, None, 4, None, None, "CategoryHeaderAggregateProp3"),

3030 0x3db8: (0x0003, None, None, 4, None, None, "MailboxMoveExtendedFlags"),

3031 0x3dbb: (0x0048, None, None, 4, None, None, "MaintenanceId"),

3032 0x3dbc: (0x0003, None, None, 4, None, None, "MailboxType"),

3033 0x3dbd: (0x0003, None, None, 4, None, None, "MessageFlagsActual"),

3034 0x3dbe: (0x0102, None, None, 4, None, None, "InternalChangeKey"),

3035 0x3dbf: (0x0102, None, None, 4, None, None, "InternalSourceKey"),

3036 0x3dd1: (0x0048, None, None, 4, None, None, "CorrelationId"),

3037 0x3e00: (0x001f, None, None, 4, None, None, "IdentityDisplay"),

3038 0x3e01: (0x0102, None, None, 4, None, None, "IdentityEntryId"),

3039 0x3e02: (0x0003, None, None, 4, None, None, "ResourceMethods"),

3040 0x3e03: (0x0003, None, None, 4, None, None, "ResourceType"),

3041 0x3e04: (0x0003, None, None, 4, None, None, "StatusCode"),

3042 0x3e05: (0x0102, None, None, 4, None, None, "IdentitySearchKey"),

3043 0x3e06: (0x0102, None, None, 4, None, None, "OwnStoreEntryId"),

3044 0x3e07: (0x001f, None, None, 4, None, None, "ResourcePath"),

3045 0x3e08: (0x001f, None, None, 4, None, None, "StatusString"),

3046 0x3e0b: (0x0003, None, None, 4, None, None, "RemoteProgress"),

3047 0x3e0c: (0x001f, None, None, 4, None, None, "RemoteProgressText"),

3048 0x3e0d: (0x000b, None, None, 4, None, None, "RemoteValidateOK"),

3049 0x3f00: (0x0003, None, None, 4, None, None, "ControlFlags"),

3050 0x3f01: (0x0102, None, None, 4, None, None, "ControlStructure"),

3051 0x3f02: (0x0003, None, None, 4, None, None, "ControlType"),

3052 0x3f03: (0x0003, None, None, 4, None, None, "DeltaX"),

3053 0x3f04: (0x0003, None, None, 4, None, None, "DeltaY"),

3054 0x3f05: (0x0003, None, None, 4, None, None, "XPos"),

3055 0x3f06: (0x0003, None, None, 4, None, None, "YPos"),

3056 0x3f07: (0x0102, None, None, 4, None, None, "ControlId"),

3057 0x3f88: (0x0014, None, None, 4, None, None, "AttachmentId"),

3058 0x3f89: (0x0102, None, None, 4, None, None, "GVid"),

3059 0x3f8a: (0x0102, None, None, 4, None, None, "GDID"),

3060 0x3f95: (0x0102, None, None, 4, None, None, "XVid"),

3061 0x3f96: (0x0102, None, None, 4, None, None, "GDefVid"),

3062 0x3fc8: (0x0102, None, None, 4, None, None, "ReplicaChangeNumber"),

3063 0x3fc9: (0x0102, None, None, 4, None, None, "LastConflict"),

3064 0x3fd4: (0x0102, None, None, 4, None, None, "RMI"),

3065 0x3fd5: (0x0102, None, None, 4, None, None, "InternalPostReply"),

3066 0x3fd6: (0x0040, None, None, 4, None, None, "NTSDModificationTime"),

3067 0x3fd7: (0x0003, None, None, 4, None, None, "ACLDataChecksum"),

3068 0x3fd8: (0x001f, None, None, 4, None, None, "PreviewUnread"),

3069 0x3fe4: (0x000b, None, None, 4, None, None, "DesignInProgress"),

3070 0x3fe5: (0x000b, None, None, 4, None, None, "SecureOrigination"),

3071 0x3fe8: (0x001f, None, None, 4, None, None, "AddressBookDisplayName"),

3072 0x3ff2: (0x0102, None, None, 4, None, None, "RuleTriggerHistory"),

3073 0x3ff3: (0x0102, None, None, 4, None, None, "MoveToStoreEntryId"),

3074 0x3ff4: (0x0102, None, None, 4, None, None, "MoveToFolderEntryId"),

3075 0x3ffe: (0x0003, None, None, 4, None, None, "QuotaType"),

3076 0x4000: (0x0003, None, None, 4, None, None, "NewAttachment"),

3077 0x4001: (0x0003, None, None, 4, None, None, "StartEmbed"),

3078 0x4002: (0x0003, None, None, 4, None, None, "EndEmbed"),

3079 0x4003: (0x0003, None, None, 4, None, None, "StartRecip"),

3080 0x4004: (0x0003, None, None, 4, None, None, "EndRecip"),

3081 0x4005: (0x0003, None, None, 4, None, None, "EndCcRecip"),

3082 0x4006: (0x0003, None, None, 4, None, None, "EndBccRecip"),

3083 0x4007: (0x0003, None, None, 4, None, None, "EndP1Recip"),

3084 0x4008: (0x001f, None, None, 4, None, None, "DNPrefix"),

3085 0x4009: (0x0003, None, None, 4, None, None, "StartTopFolder"),

3086 0x400a: (0x0003, None, None, 4, None, None, "StartSubFolder"),

3087 0x400b: (0x0003, None, None, 4, None, None, "EndFolder"),

3088 0x400c: (0x0003, None, None, 4, None, None, "StartMessage"),

3089 0x400d: (0x0003, None, None, 4, None, None, "EndMessage"),

3090 0x400e: (0x0003, None, None, 4, None, None, "EndAttachment"),

3091 0x400f: (0x0003, None, None, 4, None, None, "EcWarning"),

3092 0x4010: (0x0003, None, None, 4, None, None, "StartFAIMessage"),

3093 0x4011: (0x0102, None, None, 4, None, None, "NewFXFolder"),

3094 0x4012: (0x0003, None, None, 4, None, None, "IncrSyncChange"),

3095 0x4013: (0x0003, None, None, 4, None, None, "IncrSyncDelete"),

3096 0x4014: (0x0003, None, None, 4, None, None, "IncrSyncEnd"),

3097 0x4015: (0x0003, None, None, 4, None, None, "IncrSyncMessage"),

3098 0x4016: (0x0003, None, None, 4, None, None, "FastTransferDelProp"),

3099 0x4017: (0x0102, None, None, 4, None, None, "IdsetGiven"),

3100 0x4018: (0x0003, None, None, 4, None, None, "FastTransferErrorInfo"),

3101 0x4019: (0x0003, None, None, 4, None, None, "SenderFlags"),

3102 0x401b: (0x0003, None, None, 4, None, None, "ReceivedByFlags"),

3103 0x401c: (0x0003, None, None, 4, None, None, "ReceivedRepresentingFlags"),

3104 0x401d: (0x0003, None, None, 4, None, None, "OriginalSenderFlags"),

3105 0x401e: (0x0003, None, None, 4, None, None, "OriginalSentRepresentingFlags"),

3106 0x401f: (0x0003, None, None, 4, None, None, "ReportFlags"),

3107 0x4020: (0x0003, None, None, 4, None, None, "ReadReceiptFlags"),

3108 0x4021: (0x0102, None, None, 4, None, None, "SoftDeletes"),

3109 0x4022: (0x001f, None, None, 4, None, None, "CreatorAddressType"),

3110 0x4023: (0x001f, None, None, 4, None, None, "CreatorEmailAddress"),

3111 0x4024: (0x001f, None, None, 4, None, None, "LastModifierAddressType"),

3112 0x4025: (0x001f, None, None, 4, None, None, "LastModifierEmailAddress"),

3113 0x4026: (0x001f, None, None, 4, None, None, "ReportAddressType"),

3114 0x4027: (0x001f, None, None, 4, None, None, "ReportEmailAddress"),

3115 0x4028: (0x001f, None, None, 4, None, None, "ReportDisplayName"),

3116 0x402d: (0x0102, None, None, 4, None, None, "IdsetRead"),

3117 0x402e: (0x0102, None, None, 4, None, None, "IdsetUnread"),

3118 0x402f: (0x0003, None, None, 4, None, None, "IncrSyncRead"),

3119 0x4037: (0x001f, None, None, 4, None, None, "ReportSimpleDisplayName"),

3120 0x4038: (0x001f, None, None, 4, None, None, "CreatorSimpleDisplayName"),

3121 0x4039: (0x001f, None, None, 4, None, None, "LastModifierSimpleDisplayName"),

3122 0x403a: (0x0003, None, None, 4, None, None, "IncrSyncStateBegin"),

3123 0x403b: (0x0003, None, None, 4, None, None, "IncrSyncStateEnd"),

3124 0x403c: (0x0003, None, None, 4, None, None, "IncrSyncImailStream"),

3125 0x403f: (0x001f, None, None, 4, None, None, "SenderOriginalAddressType"),

3126 0x4040: (0x001f, None, None, 4, None, None, "SenderOriginalEmailAddress"),

3127 0x4041: (0x001f, None, None, 4, None, None, "SentRepresentingOriginalAddressType"),

3128 0x4042: (0x001f, None, None, 4, None, None, "SentRepresentingOriginalEmailAddress"),

3129 0x4043: (0x001f, None, None, 4, None, None, "OriginalSenderOriginalAddressType"),

3130 0x4044: (0x001f, None, None, 4, None, None, "OriginalSenderOriginalEmailAddress"),

3131 0x4045: (0x001f, None, None, 4, None, None, "OriginalSentRepresentingOriginalAddressType"),

3132 0x4046: (0x001f, None, None, 4, None, None, "OriginalSentRepresentingOriginalEmailAddress"),

3133 0x4047: (0x001f, None, None, 4, None, None, "ReceivedByOriginalAddressType"),

3134 0x4048: (0x001f, None, None, 4, None, None, "ReceivedByOriginalEmailAddress"),

3135 0x4049: (0x001f, None, None, 4, None, None, "ReceivedRepresentingOriginalAddressType"),

3136 0x404a: (0x001f, None, None, 4, None, None, "ReceivedRepresentingOriginalEmailAddress"),

3137 0x404b: (0x001f, None, None, 4, None, None, "ReadReceiptOriginalAddressType"),

3138 0x404c: (0x001f, None, None, 4, None, None, "ReadReceiptOriginalEmailAddress"),

3139 0x404d: (0x001f, None, None, 4, None, None, "ReportOriginalAddressType"),

3140 0x404e: (0x001f, None, None, 4, None, None, "ReportOriginalEmailAddress"),

3141 0x404f: (0x001f, None, None, 4, None, None, "CreatorOriginalAddressType"),

3142 0x4050: (0x001f, None, None, 4, None, None, "CreatorOriginalEmailAddress"),

3143 0x4051: (0x001f, None, None, 4, None, None, "LastModifierOriginalAddressType"),

3144 0x4052: (0x001f, None, None, 4, None, None, "LastModifierOriginalEmailAddress"),

3145 0x4053: (0x001f, None, None, 4, None, None, "OriginatorOriginalAddressType"),

3146 0x4054: (0x001f, None, None, 4, None, None, "OriginatorOriginalEmailAddress"),

3147 0x4055: (0x001f, None, None, 4, None, None, "ReportDestinationOriginalAddressType"),

3148 0x4056: (0x001f, None, None, 4, None, None, "ReportDestinationOriginalEmailAddress"),

3149 0x4057: (0x001f, None, None, 4, None, None, "OriginalAuthorOriginalAddressType"),

3150 0x4058: (0x001f, None, None, 4, None, None, "OriginalAuthorOriginalEmailAddress"),

3151 0x4059: (0x0003, None, None, 4, None, None, "CreatorFlags"),

3152 0x405a: (0x0003, None, None, 4, None, None, "LastModifierFlags"),

3153 0x405b: (0x0003, None, None, 4, None, None, "OriginatorFlags"),

3154 0x405c: (0x0003, None, None, 4, None, None, "ReportDestinationFlags"),

3155 0x405d: (0x0003, None, None, 4, None, None, "OriginalAuthorFlags"),

3156 0x405e: (0x001f, None, None, 4, None, None, "OriginatorSimpleDisplayName"),

3157 0x405f: (0x001f, None, None, 4, None, None, "ReportDestinationSimpleDisplayName"),

3158 0x4061: (0x0102, None, None, 4, None, None, "OriginatorSearchKey"),

3159 0x4062: (0x001f, None, None, 4, None, None, "ReportDestinationAddressType"),

3160 0x4063: (0x001f, None, None, 4, None, None, "ReportDestinationEmailAddress"),

3161 0x4064: (0x0102, None, None, 4, None, None, "ReportDestinationSearchKey"),

3162 0x4066: (0x0003, None, None, 4, None, None, "IncrSyncImailStreamContinue"),

3163 0x4067: (0x0003, None, None, 4, None, None, "IncrSyncImailStreamCancel"),

3164 0x4071: (0x0003, None, None, 4, None, None, "IncrSyncImailStream2Continue"),

3165 0x4074: (0x000b, None, None, 4, None, None, "IncrSyncProgressMode"),

3166 0x4075: (0x000b, None, None, 4, None, None, "SyncProgressPerMsg"),

3167 0x407a: (0x0003, None, None, 4, None, None, "IncrSyncMsgPartial"),

3168 0x407b: (0x0003, None, None, 4, None, None, "IncrSyncGroupInfo"),

3169 0x407c: (0x0003, None, None, 4, None, None, "IncrSyncGroupId"),

3170 0x407d: (0x0003, None, None, 4, None, None, "IncrSyncChangePartial"),

3171 0x4084: (0x0003, None, None, 4, None, None, "ContentFilterPCL"),

3172 0x4085: (0x0040, None, None, 4, None, None, "PeopleInsightsLastAccessTime"),

3173 0x4086: (0x0040, None, None, 4, None, None, "EmailUsageLastActivityTime"),

3174 0x4087: (0x0003, None, None, 4, None, None, "PdpProfileDataMigrationFlags"),

3175 0x4088: (0x0102, None, None, 4, None, None, "ControlDataForPdpDataMigrationAssistant"),

3176 0x5500: (0x000b, None, None, 4, None, None, "IsInterestingForFileExtraction"),

3177 0x5d03: (0x001f, None, None, 4, None, None, "OriginalSenderSMTPAddress"),

3178 0x5d04: (0x001f, None, None, 4, None, None, "OriginalSentRepresentingSMTPAddress"),

3179 0x5d06: (0x001f, None, None, 4, None, None, "OriginalAuthorSMTPAddress"),

3180 0x5d09: (0x0102, None, None, 4, None, None, "MessageUsageData"),

3181 0x5d0a: (0x001f, None, None, 4, None, None, "CreatorSMTPAddress"),

3182 0x5d0b: (0x001f, None, None, 4, None, None, "LastModifierSMTPAddress"),

3183 0x5d0c: (0x001f, None, None, 4, None, None, "ReportSMTPAddress"),

3184 0x5d0d: (0x001f, None, None, 4, None, None, "OriginatorSMTPAddress"),

3185 0x5d0e: (0x001f, None, None, 4, None, None, "ReportDestinationSMTPAddress"),

3186 0x5fe5: (0x001f, None, None, 4, None, None, "RecipientSipUri"),

3187 0x6000: (0x0003, None, None, 4, None, None, "RssServerLockStartTime"),

3188 0x6001: (0x001f, None, None, 4, None, None, "DotStuffState"),

3189 0x6002: (0x001f, None, None, 4, None, None, "RssServerLockClientName"),

3190 0x61af: (0x0102, None, None, 4, None, None, "ScheduleData"),

3191 0x65ef: (0x0102, None, None, 4, None, None, "RuleMsgActions"),

3192 0x65f0: (0x0102, None, None, 4, None, None, "RuleMsgCondition"),

3193 0x65f1: (0x0003, None, None, 4, None, None, "RuleMsgConditionLCID"),

3194 0x65f4: (0x000b, None, None, 4, None, None, "PreventMsgCreate"),

3195 0x65f9: (0x0102, None, None, 4, None, None, "LISSD"),

3196 0x65fa: (0x101f, None, None, 4, None, None, "IMAPUnsubscribeList"),

3197 0x6607: (0x001f, None, None, 4, None, None, "ProfileUnresolvedName"),

3198 0x660d: (0x0003, None, None, 4, None, None, "ProfileMaxRestrict"),

3199 0x660e: (0x001f, None, None, 4, None, None, "ProfileABFilesPath"),

3200 0x660f: (0x001f, None, None, 4, None, None, "ProfileFavFolderDisplayName"),

3201 0x6613: (0x101f, None, None, 4, None, None, "ProfileHomeServerAddrs"),

3202 0x662b: (0x0102, None, None, 4, None, None, "TestLineSpeed"),

3203 0x6630: (0x0102, None, None, 4, None, None, "LegacyShortcutsFolderEntryId"),

3204 0x6635: (0x001f, None, None, 4, None, None, "FavoritesDefaultName"),

3205 0x6641: (0x0003, None, None, 4, None, None, "DeletedFolderCount"),

3206 0x6643: (0x0003, None, None, 4, None, None, "DeletedAssociatedMessageCount32"),

3207 0x6644: (0x001f, None, None, 4, None, None, "ReplicaServer"),

3208 0x664c: (0x0102, None, None, 4, None, None, "FidMid"),

3209 0x6652: (0x0102, None, None, 4, None, None, "ActiveUserEntryId"),

3210 0x6655: (0x0102, None, None, 4, None, None, "ICSChangeKey"),

3211 0x6657: (0x0102, None, None, 4, None, None, "SetPropsCondition"),

3212 0x6659: (0x0102, None, None, 4, None, None, "InternetContent"),

3213 0x665b: (0x001f, None, None, 4, None, None, "OriginatorName"),

3214 0x665c: (0x001f, None, None, 4, None, None, "OriginatorEmailAddress"),

3215 0x665d: (0x001f, None, None, 4, None, None, "OriginatorAddressType"),

3216 0x665e: (0x0102, None, None, 4, None, None, "OriginatorEntryId"),

3217 0x6662: (0x0003, None, None, 4, None, None, "RecipientNumber"),

3218 0x6664: (0x001f, None, None, 4, None, None, "ReportDestinationName"),

3219 0x6665: (0x0102, None, None, 4, None, None, "ReportDestinationEntryId"),

3220 0x6692: (0x0003, None, None, 4, None, None, "ReplicationMsgPriority"),

3221 0x6697: (0x0003, None, None, 4, None, None, "WorkerProcessId"),

3222 0x669a: (0x0003, None, None, 4, None, None, "CurrentDatabaseSchemaVersion"),

3223 0x669e: (0x000b, None, None, 4, None, None, "SecureInSite"),

3224 0x66a7: (0x0003, None, None, 4, None, None, "MailboxFlags"),

3225 0x66ab: (0x0003, None, None, 4, None, None, "MailboxMessagesPerFolderCountWarningQuota"),

3226 0x66ac: (0x0003, None, None, 4, None, None, "MailboxMessagesPerFolderCountReceiveQuota"),

3227 0x66ad: (0x0003, None, None, 4, None, None, "NormalMessagesWithAttachmentsCount32"),

3228 0x66ae: (0x0003, None, None, 4, None, None, "AssociatedMessagesWithAttachmentsCount32"),

3229 0x66af: (0x0003, None, None, 4, None, None, "FolderHierarchyChildrenCountWarningQuota"),

3230 0x66b0: (0x0003, None, None, 4, None, None, "FolderHierarchyChildrenCountReceiveQuota"),

3231 0x66b1: (0x0003, None, None, 4, None, None, "AttachmentsOnNormalMessagesCount32"),

3232 0x66b2: (0x0003, None, None, 4, None, None, "AttachmentsOnAssociatedMessagesCount32"),

3233 0x66b3: (0x0014, None, None, 4, None, None, "NormalMessageSize64"),

3234 0x66e0: (0x001f, None, None, 4, None, None, "ServerDN"),

3235 0x66e1: (0x0003, None, None, 4, None, None, "BackfillRanking"),

3236 0x66e2: (0x0003, None, None, 4, None, None, "LastTransmissionTime"),

3237 0x66e3: (0x0040, None, None, 4, None, None, "StatusSendTime"),

3238 0x66e4: (0x0003, None, None, 4, None, None, "BackfillEntryCount"),

3239 0x66e5: (0x0040, None, None, 4, None, None, "NextBroadcastTime"),

3240 0x66e6: (0x0040, None, None, 4, None, None, "NextBackfillTime"),

3241 0x66e7: (0x0102, None, None, 4, None, None, "LastCNBroadcast"),

3242 0x66eb: (0x0102, None, None, 4, None, None, "BackfillId"),

3243 0x66f4: (0x0102, None, None, 4, None, None, "LastShortCNBroadcast"),

3244 0x66fb: (0x0040, None, None, 4, None, None, "AverageTransmissionTime"),

3245 0x66fc: (0x0014, None, None, 4, None, None, "ReplicationStatus"),

3246 0x66fd: (0x0040, None, None, 4, None, None, "LastDataReceivalTime"),

3247 0x670c: (0x1048, None, None, 4, None, None, "AutoReset"),

3248 0x6712: (0x0102, None, None, 4, None, None, "ScopeFIDs"),

3249 0x671e: (0x000b, None, None, 4, None, None, "PFPlatinumHomeMdb"),

3250 0x673f: (0x0102, None, None, 4, None, None, "ReadCnNewExport"),

3251 0x6745: (0x0102, None, None, 4, None, None, "LocallyDelivered"),

3252 0x6746: (0x0014, None, None, 4, None, None, "MimeSize"),

3253 0x6747: (0x0014, None, None, 4, None, None, "FileSize"),

3254 0x674b: (0x0014, None, None, 4, None, None, "CategID"),

3255 0x674c: (0x0014, None, None, 4, None, None, "ParentCategID"),

3256 0x6750: (0x0002, None, None, 4, None, None, "ChangeType"),

3257 0x6753: (0x000b, None, None, 4, None, None, "Not822Renderable"),

3258 0x6758: (0x0102, None, None, 4, None, None, "LTID"),

3259 0x6759: (0x0102, None, None, 4, None, None, "CnExport"),

3260 0x675a: (0x0102, None, None, 4, None, None, "PclExport"),

3261 0x675b: (0x0102, None, None, 4, None, None, "CnMvExport"),

3262 0x675c: (0x0102, None, None, 4, None, None, "MidsetDeletedExport"),

3263 0x675d: (0x0003, None, None, 4, None, None, "ArticleNumMic"),

3264 0x675e: (0x0003, None, None, 4, None, None, "ArticleNumMost"),

3265 0x6760: (0x0003, None, None, 4, None, None, "RulesSync"),

3266 0x6762: (0x0102, None, None, 4, None, None, "ReplicaListRC"),

3267 0x6763: (0x0102, None, None, 4, None, None, "ReplicaListRBUG"),

3268 0x6766: (0x0102, None, None, 4, None, None, "FIDC"),

3269 0x676b: (0x001f, None, None, 4, None, None, "MailboxOwnerDN"),

3270 0x676d: (0x0102, None, None, 4, None, None, "IMAPCachedBodystructure"),

3271 0x676f: (0x001f, None, None, 4, None, None, "AltRecipientDN"),

3272 0x6770: (0x000b, None, None, 4, None, None, "NoLocalDelivery"),

3273 0x6771: (0x0003, None, None, 4, None, None, "DeliveryContentLength"),

3274 0x6772: (0x000b, None, None, 4, None, None, "AutoReply"),

3275 0x6773: (0x001f, None, None, 4, None, None, "MailboxOwnerDisplayName"),

3276 0x6774: (0x0040, None, None, 4, None, None, "MailboxLastUpdated"),

3277 0x6775: (0x001f, None, None, 4, None, None, "AdminSurName"),

3278 0x6776: (0x001f, None, None, 4, None, None, "AdminGivenName"),

3279 0x6777: (0x0003, None, None, 4, None, None, "ActiveSearchCount"),

3280 0x677a: (0x0003, None, None, 4, None, None, "OverQuotaLimit"),

3281 0x677c: (0x0003, None, None, 4, None, None, "SubmitContentLength"),

3282 0x677d: (0x0003, None, None, 4, None, None, "LogonRightsOnMailbox"),

3283 0x677e: (0x0014, None, None, 4, None, None, "ReservedIdCounterRangeUpperLimit"),

3284 0x677f: (0x0014, None, None, 4, None, None, "ReservedCnCounterRangeUpperLimit"),

3285 0x6780: (0x0003, None, None, 4, None, None, "SetReceiveCount"),

3286 0x6781: (0x000b, None, None, 4, None, None, "BigFunnelIsEnabled"),

3287 0x6782: (0x0003, None, None, 4, None, None, "SubmittedCount"),

3288 0x6783: (0x0102, None, None, 4, None, None, "CreatorToken"),

3289 0x6785: (0x0102, None, None, 4, None, None, "SearchFIDs"),

3290 0x6786: (0x0102, None, None, 4, None, None, "RecursiveSearchFIDs"),

3291 0x678a: (0x0102, None, None, 4, None, None, "CategFIDs"),

3292 0x6791: (0x0014, None, None, 4, None, None, "MidSegmentStart"),

3293 0x6792: (0x0102, None, None, 4, None, None, "MidsetDeleted"),

3294 0x6793: (0x0102, None, None, 4, None, None, "MidsetExpired"),

3295 0x6794: (0x0102, None, None, 4, None, None, "CnsetIn"),

3296 0x6796: (0x0102, None, None, 4, None, None, "CnsetBackfill"),

3297 0x6798: (0x0102, None, None, 4, None, None, "MidsetTombstones"),

3298 0x679a: (0x000b, None, None, 4, None, None, "GWFolder"),

3299 0x679b: (0x000b, None, None, 4, None, None, "IPMFolder"),

3300 0x679c: (0x001f, None, None, 4, None, None, "PublicFolderPath"),

3301 0x679f: (0x0002, None, None, 4, None, None, "MidSegmentIndex"),

3302 0x67a0: (0x0002, None, None, 4, None, None, "MidSegmentSize"),

3303 0x67a1: (0x0002, None, None, 4, None, None, "CnSegmentStart"),

3304 0x67a2: (0x0002, None, None, 4, None, None, "CnSegmentIndex"),

3305 0x67a3: (0x0002, None, None, 4, None, None, "CnSegmentSize"),

3306 0x67a5: (0x0102, None, None, 4, None, None, "PCL"),

3307 0x67a6: (0x1014, None, None, 4, None, None, "CnMv"),

3308 0x67a7: (0x0014, None, None, 4, None, None, "FolderTreeRootFID"),

3309 0x67a8: (0x0102, None, None, 4, None, None, "SourceEntryId"),

3310 0x67a9: (0x0002, None, None, 4, None, None, "MailFlags"),

3311 0x67ab: (0x0003, None, None, 4, None, None, "SubmitResponsibility"),

3312 0x67ad: (0x000b, None, None, 4, None, None, "SharedReceiptHandling"),

3313 0x67b3: (0x0102, None, None, 4, None, None, "MessageAttachmentList"),

3314 0x67b5: (0x0102, None, None, 4, None, None, "SenderCAI"),

3315 0x67b6: (0x0102, None, None, 4, None, None, "SentRepresentingCAI"),

3316 0x67b7: (0x0102, None, None, 4, None, None, "OriginalSenderCAI"),

3317 0x67b8: (0x0102, None, None, 4, None, None, "OriginalSentRepresentingCAI"),

3318 0x67b9: (0x0102, None, None, 4, None, None, "ReceivedByCAI"),

3319 0x67ba: (0x0102, None, None, 4, None, None, "ReceivedRepresentingCAI"),

3320 0x67bb: (0x0102, None, None, 4, None, None, "ReadReceiptCAI"),

3321 0x67bc: (0x0102, None, None, 4, None, None, "ReportCAI"),

3322 0x67bd: (0x0102, None, None, 4, None, None, "CreatorCAI"),

3323 0x67be: (0x0102, None, None, 4, None, None, "LastModifierCAI"),

3324 0x67c4: (0x0002, None, None, 4, None, None, "AnonymousRights"),

3325 0x67ce: (0x0102, None, None, 4, None, None, "SearchGUID"),

3326 0x67d2: (0x0102, None, None, 4, None, None, "CnsetRead"),

3327 0x67da: (0x0102, None, None, 4, None, None, "CnsetBackfillFAI"),

3328 0x67de: (0x0003, None, None, 4, None, None, "ReplMsgVersion"),

3329 0x67e5: (0x0102, None, None, 4, None, None, "IdSetDeleted"),

3330 0x67e6: (0x0102, None, None, 4, None, None, "FolderMessages"),

3331 0x67e7: (0x0102, None, None, 4, None, None, "SenderReplid"),

3332 0x67e8: (0x0014, None, None, 4, None, None, "CnMin"),

3333 0x67e9: (0x0014, None, None, 4, None, None, "CnMax"),

3334 0x67ea: (0x0003, None, None, 4, None, None, "ReplMsgType"),

3335 0x67eb: (0x0102, None, None, 4, None, None, "RgszDNResponders"),

3336 0x67f2: (0x1003, None, None, 4, None, None, "ViewCoveringPropertyTags"),

3337 0x67f4: (0x000b, None, None, 4, None, None, "ICSViewFilter"),

3338 0x67f8: (0x0102, None, None, 4, None, None, "OriginatorCAI"),

3339 0x67f9: (0x0102, None, None, 4, None, None, "ReportDestinationCAI"),

3340 0x67fa: (0x0102, None, None, 4, None, None, "OriginalAuthorCAI"),

3341 0x6807: (0x0014, None, None, 4, None, None, "EventCounter"),

3342 0x6809: (0x0102, None, None, 4, None, None, "EventFid"),

3343 0x680a: (0x0102, None, None, 4, None, None, "EventMid"),

3344 0x680b: (0x0102, None, None, 4, None, None, "EventFidParent"),

3345 0x680c: (0x0102, None, None, 4, None, None, "EventFidOld"),

3346 0x680e: (0x0102, None, None, 4, None, None, "EventFidOldParent"),

3347 0x680f: (0x0040, None, None, 4, None, None, "EventCreatedTime"),

3348 0x6811: (0x0003, None, None, 4, None, None, "EventItemCount"),

3349 0x6812: (0x0102, None, None, 4, None, None, "EventFidRoot"),

3350 0x6818: (0x0014, None, None, 4, None, None, "EventExtendedFlags"),

3351 0x681c: (0x0102, None, None, 4, None, None, "EventImmutableid"),

3352 0x681d: (0x0040, None, None, 4, None, None, "MailboxQuarantineEnd"),

3353 0x681e: (0x0003, None, None, 4, None, None, "EventOldParentDefaultFolderType"),

3354 0x681f: (0x0003, None, None, 4, None, None, "MailboxNumber"),

3355 0x6821: (0x0003, None, None, 4, None, None, "InferenceClientId"),

3356 0x6822: (0x0102, None, None, 4, None, None, "InferenceItemId"),

3357 0x6823: (0x0040, None, None, 4, None, None, "InferenceCreateTime"),

3358 0x6824: (0x0048, None, None, 4, None, None, "InferenceWindowId"),

3359 0x6825: (0x0048, None, None, 4, None, None, "InferenceSessionId"),

3360 0x6826: (0x0102, None, None, 4, None, None, "InferenceFolderId"),

3361 0x682e: (0x001f, None, None, 4, None, None, "InferenceTimeZone"),

3362 0x682f: (0x001f, None, None, 4, None, None, "InferenceCategory"),

3363 0x6832: (0x0003, None, None, 4, None, None, "InferenceModuleSelected"),

3364 0x6833: (0x001f, None, None, 4, None, None, "InferenceLayoutType"),

3365 0x6835: (0x0040, None, None, 4, None, None, "InferenceTimeStamp"),

3366 0x6836: (0x000b, None, None, 4, None, None, "InferenceOLKUserActivityLoggingEnabled"),

3367 0x6837: (0x001f, None, None, 4, None, None, "InferenceClientVersion"),

3368 0x6838: (0x000b, None, None, 4, None, None, "InferenceSSISource"),

3369 0x6839: (0x0003, None, None, 4, None, None, "ActivityWorkload"),

3370 0x683b: (0x0003, None, None, 4, None, None, "ActivityItemType"),

3371 0x683c: (0x0048, None, None, 4, None, None, "ActivityContainerMailbox"),

3372 0x683d: (0x001f, None, None, 4, None, None, "ActivityContainerId"),

3373 0x683e: (0x001f, None, None, 4, None, None, "ActivityNonExoItemId"),

3374 0x683f: (0x0048, None, None, 4, None, None, "ActivityClientInstanceId"),

3375 0x6840: (0x0102, None, None, 4, None, None, "ActivityImmutableItemId"),

3376 0x6857: (0x000b, None, None, 4, None, None, "AgingAgeFolder"),

3377 0x6858: (0x000b, None, None, 4, None, None, "AgingDontAgeMe"),

3378 0x6859: (0x001f, None, None, 4, None, None, "AgingFileNameAfter9"),

3379 0x685b: (0x000b, None, None, 4, None, None, "AgingWhenDeletedOnServer"),

3380 0x685c: (0x000b, None, None, 4, None, None, "AgingWaitUntilExpired"),

3381 0x685f: (0x0102, None, None, 4, None, None, "ActivityImmutableEntryId"),

3382 0x6870: (0x1102, None, None, 4, None, None, "DelegateEntryIds2"),

3383 0x6871: (0x1003, None, None, 4, None, None, "DelegateFlags2"),

3384 0x6873: (0x0102, None, None, 4, None, None, "InferenceTrainedModelVersionBreadCrumb"),

3385 0x6874: (0x001f, None, None, 4, None, None, "FolderPathFullName"),

3386 0x6875: (0x0102, None, None, 4, None, None, "ImmutableIdExport"),

3387 0x6876: (0x0102, None, None, 4, None, None, "ControlDataForTrendingAroundMeAssistant"),

3388 0x6877: (0x101f, None, None, 4, None, None, "RestrictionAnnotationWordBreakingTokens"),

3389 0x6878: (0x1003, None, None, 4, None, None, "RestrictionAnnotationWordBreakingTokenLengths"),

3390 0x6879: (0x0102, None, None, 4, None, None, "ControlDataForCalendarInsightsAssistant"),

3391 0x687a: (0x0102, None, None, 4, None, None, "ControlDataForFreeBusyPublishingTimeBasedAssistant"),

3392 0x687b: (0x0003, None, None, 4, None, None, "RestrictionAnnotationIndexPropertyTag"),

3393 0x687c: (0x000b, None, None, 4, None, None, "IsAbandonedMoveDestination"),

3394 0x687d: (0x0102, None, None, 4, None, None, "ImmutableId26Bytes"),

3395 0x687e: (0x0102, None, None, 4, None, None, "ImmutableIdSetIn"),

3396 0x687f: (0x0102, None, None, 4, None, None, "SearchFolderLargeRestriction"),

3397 0x689f: (0x0040, None, None, 4, None, None, "ConversationMsgSentTime"),

3398 0x68a4: (0x001f, None, None, 4, None, None, "PersonCompanyNameMailboxWide"),

3399 0x68a5: (0x001f, None, None, 4, None, None, "PersonDisplayNameMailboxWide"),

3400 0x68a6: (0x001f, None, None, 4, None, None, "PersonGivenNameMailboxWide"),

3401 0x68a7: (0x001f, None, None, 4, None, None, "PersonSurnameMailboxWide"),

3402 0x68a8: (0x0102, None, None, 4, None, None, "PersonPhotoContactEntryIdMailboxWide"),

3403 0x68b0: (0x001f, None, None, 4, None, None, "PersonFileAsMailboxWide"),

3404 0x68b1: (0x0003, None, None, 4, None, None, "PersonRelevanceScoreMailboxWide"),

3405 0x68b2: (0x000b, None, None, 4, None, None, "PersonIsDistributionListMailboxWide"),

3406 0x68b3: (0x001f, None, None, 4, None, None, "PersonHomeCityMailboxWide"),

3407 0x68b4: (0x0040, None, None, 4, None, None, "PersonCreationTimeMailboxWide"),

3408 0x68b7: (0x0048, None, None, 4, None, None, "PersonGALLinkIDMailboxWide"),

3409 0x68ba: (0x101f, None, None, 4, None, None, "PersonMvEmailAddressMailboxWide"),

3410 0x68bb: (0x101f, None, None, 4, None, None, "PersonMvEmailDisplayNameMailboxWide"),

3411 0x68bc: (0x101f, None, None, 4, None, None, "PersonMvEmailRoutingTypeMailboxWide"),

3412 0x68bd: (0x001f, None, None, 4, None, None, "PersonImAddressMailboxWide"),

3413 0x68be: (0x001f, None, None, 4, None, None, "PersonWorkCityMailboxWide"),

3414 0x68bf: (0x001f, None, None, 4, None, None, "PersonDisplayNameFirstLastMailboxWide"),

3415 0x68c0: (0x001f, None, None, 4, None, None, "PersonDisplayNameLastFirstMailboxWide"),

3416 0x68c2: (0x000b, None, None, 4, None, None, "ConversationHasClutter"),

3417 0x68c3: (0x000b, None, None, 4, None, None, "ConversationHasClutterMailboxWide"),

3418 0x68c4: (0x0102, None, None, 4, None, None, "ExchangeObjectId"),

3419 0x68c5: (0x0102, None, None, 4, None, None, "ViewLargeRestriction"),

3420 0x68c6: (0x0003, None, None, 4, None, None, "ClientDiagnosticLevel"),

3421 0x68c7: (0x0102, None, None, 4, None, None, "ClientDiagnosticData"),

3422 0x6900: (0x0003, None, None, 4, None, None, "ConversationLastMemberDocumentId"),

3423 0x6901: (0x001f, None, None, 4, None, None, "ConversationPreview"),

3424 0x6902: (0x0003, None, None, 4, None, None, "ConversationLastMemberDocumentIdMailboxWide"),

3425 0x6903: (0x0003, None, None, 4, None, None, "ConversationInitialMemberDocumentId"),

3426 0x6904: (0x1003, None, None, 4, None, None, "ConversationMemberDocumentIds"),

3427 0x6905: (0x0040, None, None, 4, None, None, "ConversationMessageDeliveryOrRenewTimeMailboxWide"),

3428 0x6907: (0x1002, None, None, 4, None, None, "ConversationMessageRichContentMailboxWide"),

3429 0x6908: (0x001f, None, None, 4, None, None, "ConversationPreviewMailboxWide"),

3430 0x6909: (0x0040, None, None, 4, None, None, "ConversationMessageDeliveryOrRenewTime"),

3431 0x690a: (0x001f, None, None, 4, None, None, "ConversationWorkingSetSourcePartition"),

3432 0x690b: (0x1003, None, None, 4, None, None, "ConversationSystemCategories"),

3433 0x690c: (0x1003, None, None, 4, None, None, "ConversationSystemCategoriesMailboxWide"),

3434 0x690d: (0x0003, None, None, 4, None, None, "ConversationExchangeApplicationFlagsMailboxWide"),

3435 0x690e: (0x101f, None, None, 4, None, None, "ConversationMvMentionsMailboxWide"),

3436 0x690f: (0x101f, None, None, 4, None, None, "ConversationMvMentions"),

3437 0x6910: (0x1102, None, None, 4, None, None, "ConversationMvThreadIds"),

3438 0x6911: (0x1102, None, None, 4, None, None, "ConversationMvThreadIdsMailboxWide"),

3439 0x6912: (0x0003, None, None, 4, None, None, "ConversationLikeCountMailboxWide"),

3440 0x6913: (0x0040, None, None, 4, None, None, "ConversationReturnTime"),

3441 0x6914: (0x0040, None, None, 4, None, None, "ConversationReturnTimeMailboxWide"),

3442 0x6915: (0x0003, None, None, 4, None, None, "UserActivityPayloadVersion"),

3443 0x6916: (0x000b, None, None, 4, None, None, "ConversationAtAllMention"),

3444 0x6917: (0x000b, None, None, 4, None, None, "ConversationAtAllMentionMailboxWide"),

3445 0x6918: (0x0003, None, None, 4, None, None, "ConversationInferenceClassification"),

3446 0x6919: (0x0003, None, None, 4, None, None, "ConversationCharm"),

3447 0x691a: (0x0003, None, None, 4, None, None, "ConversationCharmMailboxWide"),

3448 0x691b: (0x0003, None, None, 4, None, None, "SignalTypeId"),

3449 0x691c: (0x0048, None, None, 4, None, None, "SignalAppId"),

3450 0x691d: (0x001f, None, None, 4, None, None, "SignalActorId"),

3451 0x691e: (0x001f, None, None, 4, None, None, "SignalClientVersion"),

3452 0x691f: (0x0048, None, None, 4, None, None, "SignalAadTenantId"),

3453 0x6920: (0x0003, None, None, 4, None, None, "SignalActorIdType"),

3454 0x6921: (0x0003, None, None, 4, None, None, "SignalOS"),

3455 0x6922: (0x001f, None, None, 4, None, None, "SignalOSVersion"),

3456 0x6923: (0x0005, None, None, 4, None, None, "SignalLatitude"),

3457 0x6924: (0x001f, None, None, 4, None, None, "SignalCv"),

3458 0x6925: (0x001f, None, None, 4, None, None, "SignalClientIp"),

3459 0x6926: (0x001f, None, None, 4, None, None, "SignalUserAgent"),

3460 0x6927: (0x001f, None, None, 4, None, None, "SignalDeviceId"),

3461 0x6928: (0x001f, None, None, 4, None, None, "SignalSchemaVersion"),

3462 0x6929: (0x0003, None, None, 4, None, None, "SignalAppWorkload"),

3463 0x692a: (0x0003, None, None, 4, None, None, "SignalCompliance"),

3464 0x692b: (0x0003, None, None, 4, None, None, "SignalItemType"),

3465 0x692c: (0x001f, None, None, 4, None, None, "SignalContainerId"),

3466 0x692d: (0x001f, None, None, 4, None, None, "SignalContainerType"),

3467 0x692e: (0x0005, None, None, 4, None, None, "SignalLongitude"),

3468 0x6930: (0x0003, None, None, 4, None, None, "SignalLocationType"),

3469 0x6931: (0x0005, None, None, 4, None, None, "SignalPrecision"),

3470 0x6932: (0x0003, None, None, 4, None, None, "SignalLocaleId"),

3471 0x6933: (0x001f, None, None, 4, None, None, "SignalTargetItemId"),

3472 0x6935: (0x0040, None, None, 4, None, None, "SignalTimeStamp"),

3473 0x6938: (0x000b, None, None, 4, None, None, "SignalIsClient"),

3474 0x693a: (0x001f, None, None, 4, None, None, "ConversationSenderName"),

3475 0x693b: (0x001f, None, None, 4, None, None, "ConversationSenderNameMailboxWide"),

3476 0x693c: (0x001f, None, None, 4, None, None, "ConversationSenderSmtpAddress"),

3477 0x693d: (0x001f, None, None, 4, None, None, "ConversationSenderSmtpAddressMailboxWide"),

3478 0x693e: (0x0102, None, None, 4, None, None, "ConversationMemberCnSet"),

3479 0x693f: (0x0102, None, None, 4, None, None, "ConversationMemberCnSetMailboxWide"),

3480 0x6940: (0x0102, None, None, 4, None, None, "ConversationMemberImmutableIdSet"),

3481 0x6941: (0x0102, None, None, 4, None, None, "ConversationMemberImmutableIdSetMailboxWide"),

3482 0x6942: (0x0040, None, None, 4, None, None, "ConversationLastAttachmentsProcessedTime"),

3483 0x6943: (0x0040, None, None, 4, None, None, "ConversationLastAttachmentsProcessedTimeMailboxWide"),

3484 0x694a: (0x001f, None, None, 4, None, None, "SignalAppName"),

3485 0x694b: (0x0014, None, None, 4, None, None, "SignalTimeStampOffset"),

3486 0x6e01: (0x0003, None, None, 4, None, None, "SecurityFlags"),

3487 0x6e04: (0x000b, None, None, 4, None, None, "SecurityReceiptRequestProcessed"),

3488 0x7000: (0x0040, None, None, 4, None, None, "UserInformationInstanceCreationTime"),

3489 0x7018: (0x001f, None, None, 4, None, None, "RemoteFolderDisplayName"),

3490 0x7019: (0x0102, None, None, 4, None, None, "AssistantFilterResult"),

3491 0x701a: (0x0102, None, None, 4, None, None, "ControlDataForTimerBrokerAssistant"),

3492 0x701b: (0x000b, None, None, 4, None, None, "ContainsScheduledTimers"),

3493 0x701c: (0x0102, None, None, 4, None, None, "LastScheduledTimerChangeToken"),

3494 0x701d: (0x0102, None, None, 4, None, None, "ControlDataForBigFunnelStoreIndexAssistant"),

3495 0x701e: (0x0003, None, None, 4, None, None, "BigFunnelStoreIndexAssistantProcessedVersion"),

3496 0x701f: (0x0003, None, None, 4, None, None, "BigFunnelStoreIndexAssistantRequestedVersion"),

3497 0x7020: (0x0003, None, None, 4, None, None, "PeopleRelevanceMailEventCount"),

3498 0x7021: (0x0003, None, None, 4, None, None, "PeopleRelevanceCalendarEventCount"),

3499 0x7022: (0x0003, None, None, 4, None, None, "PeopleRelevanceContactEventCount"),

3500 0x7023: (0x0040, None, None, 4, None, None, "PeopleRelevanceLastSuccessfulRunTime"),

3501 0x702a: (0x0102, None, None, 4, None, None, "MailboxFeatureStorageProperty"),

3502 0x702b: (0x0040, None, None, 4, None, None, "LastUserActionTime"),

3503 0x7c00: (0x001f, None, None, 4, None, None, "FavoriteDisplayName"),

3504 0x7c02: (0x0102, None, None, 4, None, None, "FavPublicSourceKey"),

3505 0x7c03: (0x0102, None, None, 4, None, None, "SyncFolderSourceKey"),

3506 0x7c04: (0x0102, None, None, 4, None, None, "SyncFolderChangeKey"),

3507 0x7c09: (0x0102, None, None, 4, None, None, "UserConfigurationStream"),

3508 0x7c0a: (0x0102, None, None, 4, None, None, "SyncStateBlob"),

3509 0x7c0b: (0x001f, None, None, 4, None, None, "ReplyForwardStatus"),

3510 0x7c0c: (0x001f, None, None, 4, None, None, "PopImapPoisonMessageStamp"),

3511 0x7c14: (0x0102, None, None, 4, None, None, "ControlDataForSystemCleanupFolderAssistant"),

3512 0x7c1a: (0x0003, None, None, 4, None, None, "UserPhotoCacheId"),

3513 0x7c1b: (0x0003, None, None, 4, None, None, "UserPhotoPreviewCacheId"),

3514 0x7c1c: (0x0003, None, None, 4, None, None, "ProfileHeaderPhotoCacheId"),

3515 0x7c1d: (0x0003, None, None, 4, None, None, "ProfileHeaderPhotoPreviewCacheId"),

3516 0x7d03: (0x0003, None, None, 4, None, None, "FavLevelMask"),

3517 0x7d0e: (0x0014, None, None, 4, None, None, "ImmutableId"),

3518 0x7d0f: (0x0102, None, None, 4, None, None, "ControlDataForWeveMessageAssistant"),

3519 0x7d10: (0x0102, None, None, 4, None, None, "WeveMessageAssistantLastMessageSentTime"),

3520 0x7d11: (0x0102, None, None, 4, None, None, "WeveMessageAssistantLastNotificationMessageSentTime"),

3521 0x7d12: (0x0102, None, None, 4, None, None, "ControlDataForMailboxLifecycleAssistant"),

3522 0x7d13: (0x0102, None, None, 4, None, None, "WeveMessageAssistantLastLicenseCheckTime"),

3523 0x7d14: (0x000b, None, None, 4, None, None, "WeveMessageAssistantLicenseExists"),

3524 0x7d15: (0x0102, None, None, 4, None, None, "ReplacedImmutableIdBin"),

3525 0x7d16: (0x000b, None, None, 4, None, None, "IsCloudCacheCrawlingComplete"),

3526 0x7d17: (0x0003, None, None, 4, None, None, "CloudCacheItemSyncStatus"),

3527 0x7d18: (0x0102, None, None, 4, None, None, "ControlDataForRecordReviewAssistant"),

3528 0x7d19: (0x0040, None, None, 4, None, None, "LastRecordIdentifiedTime"),

3529 0x7d20: (0x0102, None, None, 4, None, None, "ControlDataForPeopleRelevanceMultiStepAssistant"),

3530 0x7d21: (0x0102, None, None, 4, None, None, "ControlDataForXrmSharingMaintenanceAssistant"),

3531 0x7d23: (0x0102, None, None, 4, None, None, "ItemAssistantCrawlVersionBlob"),

3532 0x7d24: (0x0102, None, None, 4, None, None, "ControlDataForDynamicTba0"),

3533 0x7d25: (0x0102, None, None, 4, None, None, "ControlDataForDynamicTba1"),

3534 0x7d26: (0x0102, None, None, 4, None, None, "ControlDataForDynamicTba2"),

3535 0x7d27: (0x0102, None, None, 4, None, None, "ControlDataForDynamicTba3"),

3536 0x7d28: (0x0102, None, None, 4, None, None, "ControlDataForDynamicTba4"),

3537 0x7d29: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba0"),

3538 0x7d2a: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba1"),

3539 0x7d2b: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba2"),

3540 0x7d2c: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba3"),

3541 0x7d2d: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba4"),

3542 0x7d2e: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba5"),

3543 0x7d2f: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba6"),

3544 0x7d30: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba7"),

3545 0x7d31: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba8"),

3546 0x7d32: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba9"),

3547 0x7d33: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba10"),

3548 0x7d34: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba11"),

3549 0x7d35: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba12"),

3550 0x7d36: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba13"),

3551 0x7d37: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba14"),

3552 0x7d38: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba15"),

3553 0x7d39: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba16"),

3554 0x7d3a: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba17"),

3555 0x7d3b: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba18"),

3556 0x7d3c: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba19"),

3557 0x7d3d: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba20"),

3558 0x7d3e: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba21"),

3559 0x7d3f: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba22"),

3560 0x7d40: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba23"),

3561 0x7d41: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba24"),

3562 0x7d42: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba25"),

3563 0x7d43: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba26"),

3564 0x7d44: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba27"),

3565 0x7d45: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba28"),

3566 0x7d46: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba29"),

3567 0x7d47: (0x0102, None, None, 4, None, None, "ControlDataForDynamicGriffinTba30"),

3568 0x7d48: (0x0102, None, None, 4, None, None, "ControlDataForContentClassificationAssistant"),

3569 0x7d49: (0x0102, None, None, 4, None, None, "ControlDataForOfficeGraphSecondaryCopyQuotaTimeBasedAssistant"),

3570 0x7d4a: (0x0102, None, None, 4, None, None, "ControlDataForOfficeGraphConvertFilesToWorkingSetAndSpoolsSubFoldersTimeBasedAssistant"),

3571 0x7d4b: (0x0102, None, None, 4, None, None, "ControlDataForOfficeGraphSpoolsScaleOutTimeBasedAssistant"),

3572 0x7d7f: (0x0102, None, None, 4, None, None, "ControlDataForDynamicTba6"),

3573 0x7d80: (0x0003, None, None, 4, None, None, "MailboxTenantSizeEstimate"),

3574 0x7d81: (0x0102, None, None, 4, None, None, "ControlDataForMailboxTenantDataAssistant"),

3575 0x7ff7: (0x000b, None, None, 4, None, None, "IsATPEncrypted"),

3576 0x7ff8: (0x001f, None, None, 4, None, None, "HasDlpDetectedAttachmentClassifications"),

3577 0x8d0d: (0x001f, None, None, 4, None, None, "ExternalDirectoryObjectId"),

3578}